/*
 *
 * Automatically generated file; DO NOT EDIT.
 * Linux/x86_64 3.10.0-514.16.1.el7.x86_64 Kernel Configuration
 *
 */
#define CONFIG_IP6_NF_MATCH_AH_MODULE 1
#define CONFIG_NLS_CODEPAGE_861_MODULE 1
#define CONFIG_RING_BUFFER 1
#define CONFIG_UWB_HWA_MODULE 1
#define CONFIG_NF_CONNTRACK_H323_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP_FILTER 1
#define CONFIG_IP6_NF_SECURITY_MODULE 1
#define CONFIG_SND_PROC_FS 1
#define CONFIG_VFIO_PCI_MMAP 1
#define CONFIG_SCSI_DMA 1
#define CONFIG_INTEL_IDLE 1
#define CONFIG_TCP_MD5SIG 1
#define CONFIG_KERNEL_GZIP 1
#define CONFIG_MICROCODE 1
#define CONFIG_RTLBTCOEXIST_MODULE 1
#define CONFIG_NFT_NAT_MODULE 1
#define CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK 1
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_KPROBE_EVENT 1
#define CONFIG_SENSORS_ABITUGURU_MODULE 1
#define CONFIG_ARCH_SUPPORTS_INT128 1
#define CONFIG_IP_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_MEMORY_ISOLATION 1
#define CONFIG_RFS_ACCEL 1
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#define CONFIG_SERIO_ALTERA_PS2_MODULE 1
#define CONFIG_DRM_GMA500_MODULE 1
#define CONFIG_CRC32 1
#define CONFIG_I2C_BOARDINFO 1
#define CONFIG_DMI_SYSFS 1
#define CONFIG_NF_NAT_PROTO_SCTP_MODULE 1
#define CONFIG_USB_ALI_M5632 1
#define CONFIG_DM_SNAPSHOT_MODULE 1
#define CONFIG_PNFS_FLEXFILE_LAYOUT_MODULE 1
#define CONFIG_IR_JVC_DECODER_MODULE 1
#define CONFIG_X86_MCE 1
#define CONFIG_SIGNED_PE_FILE_VERIFICATION 1
#define CONFIG_DRM_NOUVEAU_MODULE 1
#define CONFIG_FSCACHE_MODULE 1
#define CONFIG_PARPORT_NOT_PC 1
#define CONFIG_NETFILTER_XT_MATCH_CPU_MODULE 1
#define CONFIG_DVB_ISL6405_MODULE 1
#define CONFIG_SENSORS_MAX1668_MODULE 1
#define CONFIG_FB_TILEBLITTING 1
#define CONFIG_IR_MCE_KBD_DECODER_MODULE 1
#define CONFIG_IXGBE_DCB 1
#define CONFIG_CPU_FREQ_GOV_CONSERVATIVE 1
#define CONFIG_SECCOMP 1
#define CONFIG_HIGH_RES_TIMERS 1
#define CONFIG_VIDEO_WM8739_MODULE 1
#define CONFIG_BLK_DEV_DM_MODULE 1
#define CONFIG_VLAN_8021Q_MODULE 1
#define CONFIG_IP_MULTIPLE_TABLES 1
#define CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT 1
#define CONFIG_ACPI_BGRT 1
#define CONFIG_FIRMWARE_MEMMAP 1
#define CONFIG_SSB_SDIOHOST 1
#define CONFIG_FIX_EARLYCON_MEM 1
#define CONFIG_BT_RFCOMM_MODULE 1
#define CONFIG_LEDS_TRIGGER_HEARTBEAT_MODULE 1
#define CONFIG_ND_PFN_MODULE 1
#define CONFIG_SCSI_INITIO_MODULE 1
#define CONFIG_DVB_TDA1004X_MODULE 1
#define CONFIG_DVB_BCM3510_MODULE 1
#define CONFIG_EFI_SECURE_BOOT_SECURELEVEL 1
#define CONFIG_INOTIFY_USER 1
#define CONFIG_SND_SOC_RT286_MODULE 1
#define CONFIG_I7300_IDLE_MODULE 1
#define CONFIG_SECURITY_NETWORK_XFRM 1
#define CONFIG_NF_CONNTRACK_NETBIOS_NS_MODULE 1
#define CONFIG_HDMI 1
#define CONFIG_SCSI_DH 1
#define CONFIG_SCSI_LOGGING 1
#define CONFIG_BRIDGE_EBT_T_FILTER_MODULE 1
#define CONFIG_NETWORK_FILESYSTEMS 1
#define CONFIG_IRQ_POLL 1
#define CONFIG_CRYPTO_FIPS 1
#define CONFIG_KVM_INTEL_MODULE 1
#define CONFIG_ASUS_LAPTOP_MODULE 1
#define CONFIG_CRYPTO_MD4_MODULE 1
#define CONFIG_BCMA_HOST_PCI 1
#define CONFIG_SATA_AHCI_PLATFORM_MODULE 1
#define CONFIG_X86_MINIMUM_CPU_FAMILY 64
#define CONFIG_SCSI_BFA_FC_MODULE 1
#define CONFIG_CPU_FREQ_GOV_ONDEMAND 1
#define CONFIG_AMD_IOMMU_STATS 1
#define CONFIG_SENSORS_LM95245_MODULE 1
#define CONFIG_USB_GSPCA_JL2005BCD_MODULE 1
#define CONFIG_AMD_PHY_MODULE 1
#define CONFIG_VIDEO_CX18_ALSA_MODULE 1
#define CONFIG_BT_HCIBFUSB_MODULE 1
#define CONFIG_PARAVIRT_SPINLOCKS 1
#define CONFIG_CGROUP_DEVICE 1
#define CONFIG_X86_TSC 1
#define CONFIG_PPP_SYNC_TTY_MODULE 1
#define CONFIG_ARCH_SUSPEND_POSSIBLE 1
#define CONFIG_COMPAT_NETLINK_MESSAGES 1
#define CONFIG_INLINE_WRITE_UNLOCK_IRQ 1
#define CONFIG_NFT_CHAIN_NAT_IPV6_MODULE 1
#define CONFIG_RC_CORE_MODULE 1
#define CONFIG_MAC80211_STA_HASH_MAX_SIZE 0
#define CONFIG_NLS_MAC_TURKISH_MODULE 1
#define CONFIG_IP_VS_NQ_MODULE 1
#define CONFIG_DVB_DRXD_MODULE 1
#define CONFIG_SENSORS_LTC4245_MODULE 1
#define CONFIG_HID_SPEEDLINK_MODULE 1
#define CONFIG_HIBERNATION 1
#define CONFIG_PNPACPI 1
#define CONFIG_USB_SERIAL_NAVMAN_MODULE 1
#define CONFIG_EDAC_I5400_MODULE 1
#define CONFIG_TCP_CONG_HTCP_MODULE 1
#define CONFIG_EXT4_FS_POSIX_ACL 1
#define CONFIG_SCSI_DEBUG_MODULE 1
#define CONFIG_DRM_I915_MODULE 1
#define CONFIG_BINFMT_MISC_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HELPER_MODULE 1
#define CONFIG_SSB_POSSIBLE 1
#define CONFIG_NFS_V4_2 1
#define CONFIG_BRIDGE_EBT_T_NAT_MODULE 1
#define CONFIG_VIDEO_SAA7134_MODULE 1
#define CONFIG_NF_NAT_SIP_MODULE 1
#define CONFIG_SENSORS_W83792D_MODULE 1
#define CONFIG_MMU_NOTIFIER 1
#define CONFIG_ASYMMETRIC_KEY_TYPE 1
#define CONFIG_DRM_RADEON_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATISTIC_MODULE 1
#define CONFIG_NLS_CODEPAGE_855_MODULE 1
#define CONFIG_NFT_CHAIN_ROUTE_IPV4_MODULE 1
#define CONFIG_VIDEO_SAA7127_MODULE 1
#define CONFIG_I2C_ISMT_MODULE 1
#define CONFIG_UHID_MODULE 1
#define CONFIG_NETCONSOLE_DYNAMIC 1
#define CONFIG_EDAC_I5100_MODULE 1
#define CONFIG_DVB_EC100_MODULE 1
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_TI_MODULE 1
#define CONFIG_SIGNATURE 1
#define CONFIG_HDLC_RAW_MODULE 1
#define CONFIG_USB_SERIAL_SAFE_MODULE 1
#define CONFIG_BRIDGE_NF_EBTABLES_MODULE 1
#define CONFIG_PATA_ARASAN_CF_MODULE 1
#define CONFIG_DVB_LG2160_MODULE 1
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_NET_SCH_FIFO 1
#define CONFIG_SATA_NV_MODULE 1
#define CONFIG_FSNOTIFY 1
#define CONFIG_CRYPTO_RMD128_MODULE 1
#define CONFIG_BLK_DEV_LOOP_MIN_COUNT 0
#define CONFIG_STP_MODULE 1
#define CONFIG_USB_GSPCA_SQ905_MODULE 1
#define CONFIG_DVB_AU8522_MODULE 1
#define CONFIG_INET6_TUNNEL_MODULE 1
#define CONFIG_INTEL_RAPL_MODULE 1
#define CONFIG_DVB_M88RS2000_MODULE 1
#define CONFIG_NF_CONNTRACK_SIP_MODULE 1
#define CONFIG_STACK_TRACER 1
#define CONFIG_MEDIA_ATTACH 1
#define CONFIG_HIDRAW 1
#define CONFIG_NET_SCH_FQ_CODEL_MODULE 1
#define CONFIG_WIL6210_ISR_COR 1
#define CONFIG_SENSORS_ADM1025_MODULE 1
#define CONFIG_HAVE_KERNEL_LZMA 1
#define CONFIG_HID_PRODIKEYS_MODULE 1
#define CONFIG_RT2X00_LIB_LEDS 1
#define CONFIG_UNIX_DIAG_MODULE 1
#define CONFIG_IP_VS_SED_MODULE 1
#define CONFIG_GENERIC_SMP_IDLE_THREAD 1
#define CONFIG_MOUSE_CYAPA_MODULE 1
#define CONFIG_DVB_DS3000_MODULE 1
#define CONFIG_ARCH_SUPPORTS_NUMA_BALANCING 1
#define CONFIG_DM_FLAKEY_MODULE 1
#define CONFIG_MACVTAP_MODULE 1
#define CONFIG_DYNAMIC_DEBUG 1
#define CONFIG_CHELSIO_T4VF_MODULE 1
#define CONFIG_HAVE_MEMORY_PRESENT 1
#define CONFIG_CPUMASK_OFFSTACK 1
#define CONFIG_USB_SERIAL_FTDI_SIO_MODULE 1
#define CONFIG_BRIDGE_EBT_REDIRECT_MODULE 1
#define CONFIG_XEN_COMPAT_XENFS 1
#define CONFIG_MEDIA_DIGITAL_TV_SUPPORT 1
#define CONFIG_8139CP_MODULE 1
#define CONFIG_SERIAL_8250_RSA 1
#define CONFIG_FIB_RULES 1
#define CONFIG_CRYPTO_CRCT10DIF_MODULE 1
#define CONFIG_DVB_FIREDTV_INPUT 1
#define CONFIG_SND_ES1968_INPUT 1
#define CONFIG_IP_VS_NFCT 1
#define CONFIG_RT_GROUP_SCHED 1
#define CONFIG_VLAN_8021Q_GVRP 1
#define CONFIG_IWLWIFI_DEBUGFS 1
#define CONFIG_IP_SET_HASH_NETIFACE_MODULE 1
#define CONFIG_IP6_NF_MANGLE_MODULE 1
#define CONFIG_SCSI_CONSTANTS 1
#define CONFIG_HAVE_IRQ_TIME_ACCOUNTING 1
#define CONFIG_CFAG12864B_MODULE 1
#define CONFIG_BT_MRVL_SDIO_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_REALM_MODULE 1
#define CONFIG_BRIDGE_EBT_ULOG_MODULE 1
#define CONFIG_BT_HCIBPA10X_MODULE 1
#define CONFIG_INTEL_TXT 1
#define CONFIG_SQUASHFS_XATTR 1
#define CONFIG_IP_VS_RR_MODULE 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_MAX98090_TI_MACH_MODULE 1
#define CONFIG_IPV6 1
#define CONFIG_USB_SERIAL_QUALCOMM_MODULE 1
#define CONFIG_INFINIBAND_HFI1_MODULE 1
#define CONFIG_CRYPTO_AEAD 1
#define CONFIG_AUDIT_ARCH 1
#define CONFIG_COMPAT 1
#define CONFIG_POWERCAP 1
#define CONFIG_BQL 1
#define CONFIG_HAVE_KERNEL_BZIP2 1
#define CONFIG_DEFAULT_TCP_CONG "cubic"
#define CONFIG_UEVENT_HELPER_PATH ""
#define CONFIG_USB_UAS_MODULE 1
#define CONFIG_NTB_NETDEV_MODULE 1
#define CONFIG_DEVTMPFS 1
#define CONFIG_NET_CLS_FLOW_MODULE 1
#define CONFIG_SENSORS_MAX8688_MODULE 1
#define CONFIG_SENSORS_PC87427_MODULE 1
#define CONFIG_PNFS_FILE_LAYOUT_MODULE 1
#define CONFIG_QED_SRIOV 1
#define CONFIG_NET_IPVTI_MODULE 1
#define CONFIG_SCSI_PMCRAID_MODULE 1
#define CONFIG_DVB_ISL6423_MODULE 1
#define CONFIG_USB_STORAGE_USBAT_MODULE 1
#define CONFIG_INFINIBAND_USER_MEM 1
#define CONFIG_APPLE_GMUX_MODULE 1
#define CONFIG_NF_NAT_PROTO_GRE_MODULE 1
#define CONFIG_YENTA_RICOH 1
#define CONFIG_SUNRPC_BACKCHANNEL 1
#define CONFIG_NLS_ISO8859_7_MODULE 1
#define CONFIG_CRYPTO_PCBC_MODULE 1
#define CONFIG_IP6_NF_TARGET_REJECT_MODULE 1
#define CONFIG_UPROBES 1
#define CONFIG_HISAX_FRITZPCI 1
#define CONFIG_HID_APPLEIR_MODULE 1
#define CONFIG_ASYNC_MEMCPY_MODULE 1
#define CONFIG_PCH_PHUB_MODULE 1
#define CONFIG_X86_POWERNOW_K8_MODULE 1
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_NF_NAT_REDIRECT_MODULE 1
#define CONFIG_DCDBAS_MODULE 1
#define CONFIG_IR_NEC_DECODER_MODULE 1
#define CONFIG_HOTPLUG_CPU 1
#define CONFIG_USB_SERIAL_MOS7840_MODULE 1
#define CONFIG_NLS_MAC_CYRILLIC_MODULE 1
#define CONFIG_SND_MAESTRO3_INPUT 1
#define CONFIG_MEDIA_PCI_SUPPORT 1
#define CONFIG_WLAN 1
#define CONFIG_NAMESPACES 1
#define CONFIG_CHELSIO_T4_UWIRE 1
#define CONFIG_L2TP_DEBUGFS_MODULE 1
#define CONFIG_HAVE_CMPXCHG_DOUBLE 1
#define CONFIG_USB_NET_INT51X1_MODULE 1
#define CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION_MODULE 1
#define CONFIG_DEFAULT_MESSAGE_LOGLEVEL 4
#define CONFIG_KGDB_SERIAL_CONSOLE 1
#define CONFIG_PATA_ATP867X_MODULE 1
#define CONFIG_SFI 1
#define CONFIG_HAVE_ARCH_HUGE_VMAP 1
#define CONFIG_FM10K_MODULE 1
#define CONFIG_IA32_EMULATION 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY 1
#define CONFIG_BLK_DEV_BSG 1
#define CONFIG_ENIC_MODULE 1
#define CONFIG_SCSI_ISCI_MODULE 1
#define CONFIG_SENSORS_MAX6697_MODULE 1
#define CONFIG_PATA_SERVERWORKS_MODULE 1
#define CONFIG_CONNECTOR 1
#define CONFIG_MEDIA_USB_SUPPORT 1
#define CONFIG_NETFILTER_XT_TARGET_RATEEST_MODULE 1
#define CONFIG_PCIEAER 1
#define CONFIG_EPIC100_MODULE 1
#define CONFIG_SCTP_COOKIE_HMAC_SHA1 1
#define CONFIG_BRIDGE_EBT_ARPREPLY_MODULE 1
#define CONFIG_BACKLIGHT_APPLE_MODULE 1
#define CONFIG_MEM_SOFT_DIRTY 1
#define CONFIG_INTEGRITY 1
#define CONFIG_DVB_MAX_ADAPTERS 8
#define CONFIG_SENSORS_SIS5595_MODULE 1
#define CONFIG_DM_MULTIPATH_QL_MODULE 1
#define CONFIG_CAN_EMS_USB_MODULE 1
#define CONFIG_XFRM_IPCOMP_MODULE 1
#define CONFIG_CRYPTO_DRBG_MENU_MODULE 1
#define CONFIG_CRYPTO_RNG2 1
#define CONFIG_UIO_CIF_MODULE 1
#define CONFIG_USB_PWC_INPUT_EVDEV 1
#define CONFIG_NETFILTER_NETLINK_QUEUE_MODULE 1
#define CONFIG_NET_ACT_CSUM_MODULE 1
#define CONFIG_RTLLIB_CRYPTO_CCMP_MODULE 1
#define CONFIG_CEPH_LIB_USE_DNS_RESOLVER 1
#define CONFIG_SCSI_MPT3SAS_MODULE 1
#define CONFIG_NETWORK_PHY_TIMESTAMPING 1
#define CONFIG_MSDOS_FS_MODULE 1
#define CONFIG_NET_CLS_CGROUP 1
#define CONFIG_XEN_MAX_DOMAIN_MEMORY 500
#define CONFIG_TUN_MODULE 1
#define CONFIG_USB_GSPCA_SUNPLUS_MODULE 1
#define CONFIG_ISDN_AUDIO 1
#define CONFIG_DVB_AU8522_V4L_MODULE 1
#define CONFIG_ENCLOSURE_SERVICES_MODULE 1
#define CONFIG_IPV6_PIMSM_V2 1
#define CONFIG_SENSORS_ADS1015_MODULE 1
#define CONFIG_BNX2_MODULE 1
#define CONFIG_CAN_MODULE 1
#define CONFIG_SND_VX222_MODULE 1
#define CONFIG_CFG80211_MODULE 1
#define CONFIG_MACSEC_MODULE 1
#define CONFIG_SND_AU8810_MODULE 1
#define CONFIG_NLS_CODEPAGE_1250_MODULE 1
#define CONFIG_DM_CRYPT_MODULE 1
#define CONFIG_REED_SOLOMON_ENC8 1
#define CONFIG_SERIAL_8250 1
#define CONFIG_RTC_DRV_ISL12022_MODULE 1
#define CONFIG_SENSORS_W83793_MODULE 1
#define CONFIG_LZO_DECOMPRESS 1
#define CONFIG_USB_EHCI_ROOT_HUB_TT 1
#define CONFIG_IP_VS_PROTO_AH 1
#define CONFIG_IOMMU_SUPPORT 1
#define CONFIG_HID_BELKIN 1
#define CONFIG_VIDEO_IR_I2C_MODULE 1
#define CONFIG_VFIO_IOMMU_TYPE1_MODULE 1
#define CONFIG_DVB_STV0367_MODULE 1
#define CONFIG_LEDS_TRIGGER_CAMERA_MODULE 1
#define CONFIG_ISDN_TTY_FAX 1
#define CONFIG_NLS_CODEPAGE_862_MODULE 1
#define CONFIG_NFSD_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_C4_MODULE 1
#define CONFIG_SENSORS_TSL2550_MODULE 1
#define CONFIG_COMPAT_BINFMT_ELF 1
#define CONFIG_VFIO_PCI_MODULE 1
#define CONFIG_PWM_LPSS_MODULE 1
#define CONFIG_USB_SERIAL_OPTION_MODULE 1
#define CONFIG_HID_ACRUX_MODULE 1
#define CONFIG_RD_LZMA 1
#define CONFIG_USB_GSPCA_SE401_MODULE 1
#define CONFIG_CRYPTO_SALSA20_MODULE 1
#define CONFIG_USB 1
#define CONFIG_PATA_SIL680_MODULE 1
#define CONFIG_ACPI_IPMI_MODULE 1
#define CONFIG_SND_SOC_RT5651_MODULE 1
#define CONFIG_MMC_SDHCI_PCI_MODULE 1
#define CONFIG_USB_SPEEDTOUCH_MODULE 1
#define CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK 1
#define CONFIG_ALIM7101_WDT_MODULE 1
#define CONFIG_ACPI_PCI_SLOT 1
#define CONFIG_MODULES_USE_ELF_RELA 1
#define CONFIG_SND_BCD2000_MODULE 1
#define CONFIG_CRYPTO_HMAC 1
#define CONFIG_WLAN_VENDOR_REALTEK 1
#define CONFIG_ETHERNET 1
#define CONFIG_VFIO_NOIOMMU 1
#define CONFIG_NET_SCH_CODEL_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE_ROTATION 1
#define CONFIG_USB_GSPCA_JEILINJ_MODULE 1
#define CONFIG_SCHED_OMIT_FRAME_POINTER 1
#define CONFIG_BRANCH_PROFILE_NONE 1
#define CONFIG_SCSI_SCAN_ASYNC 1
#define CONFIG_CRC_ITU_T_MODULE 1
#define CONFIG_NET_DROP_MONITOR 1
#define CONFIG_SND_HRTIMER_MODULE 1
#define CONFIG_DQL 1
#define CONFIG_VXLAN_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE 1
#define CONFIG_DM_ZERO_MODULE 1
#define CONFIG_DVB_DIB8000_MODULE 1
#define CONFIG_X86_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_SND_SEQUENCER_MODULE 1
#define CONFIG_TCP_CONG_LP_MODULE 1
#define CONFIG_PINCTRL_BAYTRAIL 1
#define CONFIG_INPUT_GP2A_MODULE 1
#define CONFIG_COREDUMP 1
#define CONFIG_USB_NET_GL620A_MODULE 1
#define CONFIG_MOVABLE_NODE 1
#define CONFIG_SND_OPL3_LIB_MODULE 1
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#define CONFIG_DVB_USB_GP8PSK_MODULE 1
#define CONFIG_USB_SERIAL_GENERIC 1
#define CONFIG_HID_CHERRY 1
#define CONFIG_USE_PERCPU_NUMA_NODE_ID 1
#define CONFIG_HID_SUNPLUS_MODULE 1
#define CONFIG_DRM_VMWGFX_FBCON 1
#define CONFIG_HID_PICOLCD_MODULE 1
#define CONFIG_BCMA_POSSIBLE 1
#define CONFIG_NF_LOG_IPV4_MODULE 1
#define CONFIG_NET_SCH_SFB_MODULE 1
#define CONFIG_LEDS_LP5521_MODULE 1
#define CONFIG_FUSION_CTL_MODULE 1
#define CONFIG_TULIP_MODULE 1
#define CONFIG_CIFS_ACL 1
#define CONFIG_ZRAM_MODULE 1
#define CONFIG_CRYPTO_CAST5_MODULE 1
#define CONFIG_VGA_ARB 1
#define CONFIG_SENSORS_CORETEMP_MODULE 1
#define CONFIG_NF_TABLES_ARP_MODULE 1
#define CONFIG_SND_SOC_MODULE 1
#define CONFIG_FIREWIRE_SBP2_MODULE 1
#define CONFIG_NET_IPGRE_DEMUX_MODULE 1
#define CONFIG_MEDIA_TUNER_XC5000_MODULE 1
#define CONFIG_NET_POLL_CONTROLLER 1
#define CONFIG_PRINTK 1
#define CONFIG_6LOWPAN_NHC_ROUTING_MODULE 1
#define CONFIG_SFC_MODULE 1
#define CONFIG_TULIP_MMIO 1
#define CONFIG_FB_SYS_FILLRECT_MODULE 1
#define CONFIG_TIMERFD 1
#define CONFIG_HID_THRUSTMASTER_MODULE 1
#define CONFIG_CRYPTO_MCRYPTD_MODULE 1
#define CONFIG_UIDGID_STRICT_TYPE_CHECKS 1
#define CONFIG_BLK_DEV_RAM_DAX 1
#define CONFIG_SENSORS_MAX16065_MODULE 1
#define CONFIG_SENSORS_I5K_AMB_MODULE 1
#define CONFIG_DNS_RESOLVER_MODULE 1
#define CONFIG_ITCO_VENDOR_SUPPORT 1
#define CONFIG_TRACEPOINTS 1
#define CONFIG_MTD_CFI_I2 1
#define CONFIG_CRYPTO_AUTHENC_MODULE 1
#define CONFIG_AT803X_PHY_MODULE 1
#define CONFIG_DVB_SP8870_MODULE 1
#define CONFIG_I6300ESB_WDT_MODULE 1
#define CONFIG_YENTA_MODULE 1
#define CONFIG_NET_EMATCH_STACK 32
#define CONFIG_CARL9170_LEDS 1
#define CONFIG_ATL1E_MODULE 1
#define CONFIG_USB_STORAGE_ENE_UB6250_MODULE 1
#define CONFIG_DVB_DDBRIDGE_MODULE 1
#define CONFIG_NLS_MAC_CENTEURO_MODULE 1
#define CONFIG_BRCMFMAC_SDIO 1
#define CONFIG_BOUNCE 1
#define CONFIG_NUMA_BALANCING 1
#define CONFIG_THINKPAD_ACPI_MODULE 1
#define CONFIG_SHMEM 1
#define CONFIG_ISDN_PPP 1
#define CONFIG_MTD_MODULE 1
#define CONFIG_MIGRATION 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL 1
#define CONFIG_IWLEGACY_DEBUG 1
#define CONFIG_VIDEO_BTCX_MODULE 1
#define CONFIG_MMC_BLOCK_MINORS 8
#define CONFIG_USB_HSO_MODULE 1
#define CONFIG_HID_PRIMAX_MODULE 1
#define CONFIG_DECOMPRESS_LZMA 1
#define CONFIG_PCI_IOV 1
#define CONFIG_WATCHDOG_SYSFS 1
#define CONFIG_HAVE_KVM_EVENTFD 1
#define CONFIG_GPIO_VIPERBOARD_MODULE 1
#define CONFIG_DEVTMPFS_MOUNT 1
#define CONFIG_SND_HDA_DSP_LOADER 1
#define CONFIG_SENSORS_AMC6821_MODULE 1
#define CONFIG_USB_IPHETH_MODULE 1
#define CONFIG_NLS_CODEPAGE_850_MODULE 1
#define CONFIG_DVB_CX22700_MODULE 1
#define CONFIG_DNOTIFY 1
#define CONFIG_CRYPTO_CTS_MODULE 1
#define CONFIG_SND_USB_PODHD_MODULE 1
#define CONFIG_EDD_MODULE 1
#define CONFIG_DVB_USB_UMT_010_MODULE 1
#define CONFIG_IMA_TRUSTED_KEYRING 1
#define CONFIG_SCSI_UFSHCD_MODULE 1
#define CONFIG_INPUT_MOUSEDEV 1
#define CONFIG_ATA_MODULE 1
#define CONFIG_CRYPTO_DES_MODULE 1
#define CONFIG_ENABLE_MUST_CHECK 1
#define CONFIG_CEPH_LIB_MODULE 1
#define CONFIG_MM_OWNER 1
#define CONFIG_SND_SOC_COMPRESS 1
#define CONFIG_ND_BTT_MODULE 1
#define CONFIG_NLS_CODEPAGE_437 1
#define CONFIG_HAVE_ARCH_SOFT_DIRTY 1
#define CONFIG_BT_HS 1
#define CONFIG_HYPERV_KEYBOARD_MODULE 1
#define CONFIG_ARCH_PROC_KCORE_TEXT 1
#define CONFIG_NET_CLS_U32_MODULE 1
#define CONFIG_MISDN_MODULE 1
#define CONFIG_EXPORTFS 1
#define CONFIG_MTD_UBI_WL_THRESHOLD 4096
#define CONFIG_MMC_RICOH_MMC 1
#define CONFIG_IP6_NF_MATCH_MH_MODULE 1
#define CONFIG_NFT_EXTHDR_MODULE 1
#define CONFIG_SCSI_OSD_INITIATOR_MODULE 1
#define CONFIG_DVB_S921_MODULE 1
#define CONFIG_SCSI_OSD_DPRINT_SENSE 1
#define CONFIG_MSI_WMI_MODULE 1
#define CONFIG_IT87_WDT_MODULE 1
#define CONFIG_SCSI_CXGB3_ISCSI_MODULE 1
#define CONFIG_SND_DARLA24_MODULE 1
#define CONFIG_SENSORS_MAX1619_MODULE 1
#define CONFIG_DVB_AF9013_MODULE 1
#define CONFIG_OLD_SIGSUSPEND3 1
#define CONFIG_INFINIBAND_MTHCA_DEBUG 1
#define CONFIG_SERIO 1
#define CONFIG_DVB_USB_DTV5100_MODULE 1
#define CONFIG_SCHEDSTATS 1
#define CONFIG_IBMASR_MODULE 1
#define CONFIG_INPUT_MOUSE 1
#define CONFIG_RTLWIFI_PCI_MODULE 1
#define CONFIG_INFINIBAND_ISER_MODULE 1
#define CONFIG_FB_SYS_IMAGEBLIT_MODULE 1
#define CONFIG_VIDEO_TVEEPROM_MODULE 1
#define CONFIG_X86 1
#define CONFIG_PPS_CLIENT_PARPORT_MODULE 1
#define CONFIG_SUNRPC_GSS_MODULE 1
#define CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS 1
#define CONFIG_TIGON3_MODULE 1
#define CONFIG_CRYPTO_CAST5_AVX_X86_64_MODULE 1
#define CONFIG_SENSORS_LM90_MODULE 1
#define CONFIG_NETCONSOLE_MODULE 1
#define CONFIG_RTC_INTF_SYSFS 1
#define CONFIG_MMC_SDHCI_ACPI_MODULE 1
#define CONFIG_BCMA_DRIVER_GPIO 1
#define CONFIG_RTC_DRV_RS5C372_MODULE 1
#define CONFIG_QED_MODULE 1
#define CONFIG_NET_EMATCH_U32_MODULE 1
#define CONFIG_CPU_FREQ_GOV_COMMON 1
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_USB_EMI62_MODULE 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTREMOVE 1
#define CONFIG_X86_MCE_AMD 1
#define CONFIG_DM_BUFIO_MODULE 1
#define CONFIG_I2C_ALGOPCA_MODULE 1
#define CONFIG_BT_ATH3K_MODULE 1
#define CONFIG_LEDS_TRIGGER_TIMER_MODULE 1
#define CONFIG_DRM_VIRTIO_GPU_MODULE 1
#define CONFIG_RTC_DRV_M48T59_MODULE 1
#define CONFIG_RT2800_LIB_MODULE 1
#define CONFIG_X86_X2APIC 1
#define CONFIG_FB_VESA 1
#define CONFIG_NFS_DEBUG 1
#define CONFIG_CRYPTO_BLOWFISH_COMMON_MODULE 1
#define CONFIG_BT_INTEL_MODULE 1
#define CONFIG_DRM_BOCHS_MODULE 1
#define CONFIG_DVB_USB_DW2102_MODULE 1
#define CONFIG_CRYPTO_DRBG_HASH 1
#define CONFIG_NF_CONNTRACK_SANE_MODULE 1
#define CONFIG_SND_OSSEMUL 1
#define CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL_MODULE 1
#define CONFIG_ARCH_CLOCKSOURCE_DATA 1
#define CONFIG_HAVE_BPF_JIT 1
#define CONFIG_USB_SERIAL_MOS7720_MODULE 1
#define CONFIG_PREEMPT_NOTIFIERS 1
#define CONFIG_XEN_PVHVM 1
#define CONFIG_NF_CT_PROTO_DCCP_MODULE 1
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_RTC_DRV_V3020_MODULE 1
#define CONFIG_DVB_TUA6100_MODULE 1
#define CONFIG_KVM_ASYNC_PF 1
#define CONFIG_MODULE_SIG_UEFI 1
#define CONFIG_CRC_T10DIF_MODULE 1
#define CONFIG_THERMAL_GOV_FAIR_SHARE 1
#define CONFIG_ENCRYPTED_KEYS 1
#define CONFIG_MEDIA_TUNER_QT1010_MODULE 1
#define CONFIG_DVB_DYNAMIC_MINORS 1
#define CONFIG_SSB_PCIHOST_POSSIBLE 1
#define CONFIG_DRM_AMD_POWERPLAY 1
#define CONFIG_PCI_IOAPIC 1
#define CONFIG_HWMON 1
#define CONFIG_INTEL_GTT 1
#define CONFIG_IMA_AUDIT 1
#define CONFIG_CRYPTO_TWOFISH_COMMON_MODULE 1
#define CONFIG_DLCI_MAX 8
#define CONFIG_AUDITSYSCALL 1
#define CONFIG_LOGO_LINUX_CLUT224 1
#define CONFIG_BT_HCIUART_3WIRE 1
#define CONFIG_HID_LENOVO_TPKBD_MODULE 1
#define CONFIG_X86_ACPI_CPUFREQ_CPB 1
#define CONFIG_NLS_ISO8859_2_MODULE 1
#define CONFIG_QEDE_MODULE 1
#define CONFIG_HID_PS3REMOTE_MODULE 1
#define CONFIG_SENSORS_LM63_MODULE 1
#define CONFIG_RC_DEVICES 1
#define CONFIG_CRYPTO_CRC32_PCLMUL_MODULE 1
#define CONFIG_USB_VIDEO_CLASS_MODULE 1
#define CONFIG_CLKBLD_I8253 1
#define CONFIG_RTC_INTF_PROC 1
#define CONFIG_HID_PICOLCD_FB 1
#define CONFIG_USB_SERIAL_TI_MODULE 1
#define CONFIG_NET_SCH_CBQ_MODULE 1
#define CONFIG_VIDEO_VP27SMPX_MODULE 1
#define CONFIG_PM_CLK 1
#define CONFIG_ARCH_USE_BUILTIN_BSWAP 1
#define CONFIG_ARCH_HAS_MMIO_FLUSH 1
#define CONFIG_USB_SERIAL_MOS7715_PARPORT 1
#define CONFIG_CRYPTO_SERPENT_MODULE 1
#define CONFIG_CPU_IDLE_GOV_MENU 1
#define CONFIG_ACPI_FAN 1
#define CONFIG_MOUSE_PS2_SENTELIC 1
#define CONFIG_HYSDN_CAPI 1
#define CONFIG_VIDEO_CS5345_MODULE 1
#define CONFIG_STACKTRACE_SUPPORT 1
#define CONFIG_B44_PCI_AUTOSELECT 1
#define CONFIG_DVB_USB_AF9035_MODULE 1
#define CONFIG_SENSORS_EMC1403_MODULE 1
#define CONFIG_BNA_MODULE 1
#define CONFIG_IP_DCCP_TFRC_LIB 1
#define CONFIG_MAXSMP 1
#define CONFIG_OUTPUT_FORMAT "elf64-x86-64"
#define CONFIG_VIDEO_M52790_MODULE 1
#define CONFIG_ACPI 1
#define CONFIG_SCSI_CXGB4_ISCSI_MODULE 1
#define CONFIG_SENSORS_SHT15_MODULE 1
#define CONFIG_USB_UHCI_HCD 1
#define CONFIG_NVRAM 1
#define CONFIG_LOCKD_MODULE 1
#define CONFIG_LEDS_INTEL_SS4200_MODULE 1
#define CONFIG_DRM_KMS_FB_HELPER 1
#define CONFIG_DVB_FIREDTV_MODULE 1
#define CONFIG_DVB_S5H1411_MODULE 1
#define CONFIG_NF_CT_NETLINK_TIMEOUT_MODULE 1
#define CONFIG_SOUND_OSS_CORE 1
#define CONFIG_RT2800USB_RT35XX 1
#define CONFIG_HPET_MMAP 1
#define CONFIG_WLAN_VENDOR_RALINK 1
#define CONFIG_USB_GSPCA_TV8532_MODULE 1
#define CONFIG_DRM_VMWGFX_MODULE 1
#define CONFIG_STE10XP_MODULE 1
#define CONFIG_NFT_REJECT_IPV6_MODULE 1
#define CONFIG_HID_SAITEK_MODULE 1
#define CONFIG_VIDEO_OUTPUT_CONTROL_MODULE 1
#define CONFIG_SCSI_DH_ALUA 1
#define CONFIG_KEXEC_VERIFY_SIG 1
#define CONFIG_MTRR 1
#define CONFIG_BT_RFCOMM_TTY 1
#define CONFIG_LIBFCOE_MODULE 1
#define CONFIG_NET_UDP_TUNNEL_MODULE 1
#define CONFIG_INTEGRITY_SIGNATURE 1
#define CONFIG_RPCSEC_GSS_KRB5_MODULE 1
#define CONFIG_VIDEOBUF_VMALLOC_MODULE 1
#define CONFIG_NLS_MAC_ROMANIAN_MODULE 1
#define CONFIG_SND_LX6464ES_MODULE 1
#define CONFIG_SENSORS_PCF8591_MODULE 1
#define CONFIG_DVB_STV0299_MODULE 1
#define CONFIG_ACER_WMI_MODULE 1
#define CONFIG_USB_AN2720 1
#define CONFIG_SENSORS_UCD9200_MODULE 1
#define CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING 1
#define CONFIG_MLX4_DEBUG 1
#define CONFIG_BSD_PROCESS_ACCT 1
#define CONFIG_NETFILTER_XT_MATCH_STRING_MODULE 1
#define CONFIG_SSB_DRIVER_PCICORE 1
#define CONFIG_INPUT_TABLET 1
#define CONFIG_SND_SST_MFLD_PLATFORM_MODULE 1
#define CONFIG_MEDIA_TUNER_MAX2165_MODULE 1
#define CONFIG_MDIO_MODULE 1
#define CONFIG_N_HDLC_MODULE 1
#define CONFIG_HISAX_NO_SENDCOMPLETE 1
#define CONFIG_CRYPTO_DRBG_HMAC 1
#define CONFIG_IR_WINBOND_CIR_MODULE 1
#define CONFIG_HPET_EMULATE_RTC 1
#define CONFIG_X86_MPPARSE 1
#define CONFIG_BNXT_MODULE 1
#define CONFIG_LOGO 1
#define CONFIG_SENSORS_UCD9000_MODULE 1
#define CONFIG_SND_OXYGEN_LIB_MODULE 1
#define CONFIG_DLM_MODULE 1
#define CONFIG_SND_SOC_MAX98357A_MODULE 1
#define CONFIG_SERIAL_ARC_MODULE 1
#define CONFIG_CAN_CC770_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_BPF_MODULE 1
#define CONFIG_EEEPC_LAPTOP_MODULE 1
#define CONFIG_USB_STORAGE_MODULE 1
#define CONFIG_NET_VENDOR_BROADCOM 1
#define CONFIG_PERCPU_RWSEM 1
#define CONFIG_DVB_USB_PCTV452E_MODULE 1
#define CONFIG_DVB_VES1820_MODULE 1
#define CONFIG_STANDALONE 1
#define CONFIG_CRYPTO_SEED_MODULE 1
#define CONFIG_SCHED_MC 1
#define CONFIG_DELL_RBU_MODULE 1
#define CONFIG_SCSI_SAS_ATA 1
#define CONFIG_PCIE_ECRC 1
#define CONFIG_CPU_FREQ_GOV_PERFORMANCE 1
#define CONFIG_IR_LIRC_CODEC_MODULE 1
#define CONFIG_GPIO_ICH_MODULE 1
#define CONFIG_EFI 1
#define CONFIG_SATA_MV_MODULE 1
#define CONFIG_DVB_TS2020_MODULE 1
#define CONFIG_AGP_AMD64 1
#define CONFIG_WLAN_VENDOR_INTEL 1
#define CONFIG_HAVE_SETUP_PER_CPU_AREA 1
#define CONFIG_DRM_I915_USERPTR 1
#define CONFIG_SYSTEM_TRUSTED_KEYRING 1
#define CONFIG_WATCHDOG_CORE 1
#define CONFIG_DVB_TUNER_DIB0090_MODULE 1
#define CONFIG_PCI_XEN 1
#define CONFIG_MFD_RTSX_PCI_MODULE 1
#define CONFIG_SND_USB_AUDIO_MODULE 1
#define CONFIG_VIDEO_CX231XX_MODULE 1
#define CONFIG_TCP_CONG_YEAH_MODULE 1
#define CONFIG_IEEE802154_MODULE 1
#define CONFIG_HISAX_NO_LLC 1
#define CONFIG_SCSI_QLA_FC_MODULE 1
#define CONFIG_TELCLOCK_MODULE 1
#define CONFIG_I40EVF_MODULE 1
#define CONFIG_IO_DELAY_TYPE_0XED 1
#define CONFIG_BLOCK 1
#define CONFIG_HAVE_IDE 1
#define CONFIG_IP_VS_LC_MODULE 1
#define CONFIG_HID_APPLE 1
#define CONFIG_CRYPTO_SERPENT_AVX2_X86_64_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA827X_MODULE 1
#define CONFIG_VMXNET3_MODULE 1
#define CONFIG_INIT_ENV_ARG_LIMIT 32
#define CONFIG_SND_RAWMIDI_SEQ_MODULE 1
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1
#define CONFIG_USB_WUSB_MODULE 1
#define CONFIG_DVB_USB_MODULE 1
#define CONFIG_SENSORS_MAX34440_MODULE 1
#define CONFIG_SENSORS_G760A_MODULE 1
#define CONFIG_DVB_ATBM8830_MODULE 1
#define CONFIG_CC_STACKPROTECTOR_STRONG 1
#define CONFIG_ATL2_MODULE 1
#define CONFIG_USER_NS 1
#define CONFIG_ARCH_WANT_BATCHED_UNMAP_TLB_FLUSH 1
#define CONFIG_CRYPTO_USER_MODULE 1
#define CONFIG_NF_CONNTRACK_PPTP_MODULE 1
#define CONFIG_CPU_SUP_INTEL 1
#define CONFIG_DVB_ZL10036_MODULE 1
#define CONFIG_VIDEO_CX231XX_ALSA_MODULE 1
#define CONFIG_TMPFS_POSIX_ACL 1
#define CONFIG_SENSORS_ADM9240_MODULE 1
#define CONFIG_DEBUG_SET_MODULE_RONX 1
#define CONFIG_PROVIDE_OHCI1394_DMA_INIT 1
#define CONFIG_SND_SOC_INTEL_SKL_RT286_MACH_MODULE 1
#define CONFIG_SND_USB_UA101_MODULE 1
#define CONFIG_ACPI_APEI_PCIEAER 1
#define CONFIG_NETLINK_DIAG_MODULE 1
#define CONFIG_BUG 1
#define CONFIG_KS0108_PORT 0x378
#define CONFIG_CONTEXT_SWITCH_TRACER 1
#define CONFIG_MAC80211_HAS_RC 1
#define CONFIG_KDB_KEYBOARD 1
#define CONFIG_SENSORS_INA209_MODULE 1
#define CONFIG_SCSI_FC_TGT_ATTRS 1
#define CONFIG_XEN 1
#define CONFIG_CRYPTO_CAST6_MODULE 1
#define CONFIG_6LOWPAN_NHC_UDP_MODULE 1
#define CONFIG_NET_EMATCH_META_MODULE 1
#define CONFIG_I7300_IDLE_IOAT_CHANNEL 1
#define CONFIG_I40E_DCB 1
#define CONFIG_I2C_DIOLAN_U2C_MODULE 1
#define CONFIG_PM 1
#define CONFIG_SND_CS46XX_NEW_DSP 1
#define CONFIG_PPS_MODULE 1
#define CONFIG_GENERIC_ISA_DMA 1
#define CONFIG_USB_LCD_MODULE 1
#define CONFIG_MEMCG 1
#define CONFIG_SPI 1
#define CONFIG_SENSORS_DS620_MODULE 1
#define CONFIG_HAVE_KVM_CPU_RELAX_INTERCEPT 1
#define CONFIG_NFT_HASH_MODULE 1
#define CONFIG_NF_CONNTRACK_IRC_MODULE 1
#define CONFIG_NOUVEAU_DEBUG_DEFAULT 3
#define CONFIG_L2TP_IP_MODULE 1
#define CONFIG_BOOTPARAM_HUNG_TASK_PANIC_VALUE 0
#define CONFIG_USB_STV06XX_MODULE 1
#define CONFIG_PPP_DEFLATE_MODULE 1
#define CONFIG_VGA_SWITCHEROO 1
#define CONFIG_STRIP_ASM_SYMS 1
#define CONFIG_IRQ_REMAP 1
#define CONFIG_TEXTSEARCH_KMP_MODULE 1
#define CONFIG_SND_MAESTRO3_MODULE 1
#define CONFIG_VT 1
#define CONFIG_USB_NET_NET1080_MODULE 1
#define CONFIG_SENSORS_F71805F_MODULE 1
#define CONFIG_SUNRPC_DEBUG 1
#define CONFIG_NETFILTER_XT_TARGET_CLASSIFY_MODULE 1
#define CONFIG_HID_TIVO_MODULE 1
#define CONFIG_HID_ICADE_MODULE 1
#define CONFIG_PCI_ATS 1
#define CONFIG_MISDN_IPAC_MODULE 1
#define CONFIG_MACB_MODULE 1
#define CONFIG_SND_HDA_CODEC_CIRRUS_MODULE 1
#define CONFIG_REGMAP_SPI_MODULE 1
#define CONFIG_BT_BREDR 1
#define CONFIG_DMA_ACPI 1
#define CONFIG_CB710_DEBUG_ASSUMPTIONS 1
#define CONFIG_SPLIT_PTLOCK_CPUS 4
#define CONFIG_EDAC_E752X_MODULE 1
#define CONFIG_MSPRO_BLOCK_MODULE 1
#define CONFIG_DVB_TUNER_ITD1000_MODULE 1
#define CONFIG_POWER_SUPPLY 1
#define CONFIG_DM_PERSISTENT_DATA_MODULE 1
#define CONFIG_PATA_VIA_MODULE 1
#define CONFIG_DAVICOM_PHY_MODULE 1
#define CONFIG_SCTP_COOKIE_HMAC_MD5 1
#define CONFIG_CIFS_XATTR 1
#define CONFIG_KEXEC_JUMP 1
#define CONFIG_SENSORS_ADM1275_MODULE 1
#define CONFIG_I2C_PCA_PLATFORM_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFQUEUE_MODULE 1
#define CONFIG_SECURITY_SELINUX_BOOTPARAM 1
#define CONFIG_CAN_8DEV_USB_MODULE 1
#define CONFIG_SND_HDA_INPUT_BEEP 1
#define CONFIG_WEXT_CORE 1
#define CONFIG_I2C_DESIGNWARE_CORE_MODULE 1
#define CONFIG_USB_GSPCA_MR97310A_MODULE 1
#define CONFIG_DVB_HOPPER_MODULE 1
#define CONFIG_NETLABEL 1
#define CONFIG_VIDEO_WM8775_MODULE 1
#define CONFIG_NLS 1
#define CONFIG_NF_CONNTRACK_TIMEOUT 1
#define CONFIG_SND_SOC_HDAC_HDMI_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORTNET_MODULE 1
#define CONFIG_CDROM_PKTCDVD_BUFFERS 8
#define CONFIG_SCHED_AUTOGROUP 1
#define CONFIG_CLS_U32_PERF 1
#define CONFIG_MEDIA_CAMERA_SUPPORT 1
#define CONFIG_HWPOISON_INJECT_MODULE 1
#define CONFIG_RTL8188EE_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_SECMARK_MODULE 1
#define CONFIG_HID_MAGICMOUSE 1
#define CONFIG_NFT_COUNTER_MODULE 1
#define CONFIG_INET_UDP_DIAG_MODULE 1
#define CONFIG_XEN_SAVE_RESTORE 1
#define CONFIG_DELL_LAPTOP_MODULE 1
#define CONFIG_PPPOE_MODULE 1
#define CONFIG_CRYPTO_CRCT10DIF_PCLMUL_MODULE 1
#define CONFIG_XFRM_MIGRATE 1
#define CONFIG_X86_INTEL_PSTATE 1
#define CONFIG_SND_LAYLA24_MODULE 1
#define CONFIG_ZONE_DMA 1
#define CONFIG_USB_GSPCA_SPCA508_MODULE 1
#define CONFIG_USB_LEGOTOWER_MODULE 1
#define CONFIG_NF_NAT_IPV6_MODULE 1
#define CONFIG_QLCNIC_HWMON 1
#define CONFIG_HISAX_TELESPCI 1
#define CONFIG_ISDN_DIVERSION_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MC_MODULE 1
#define CONFIG_DVB_USB_VP702X_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_OWNER_MODULE 1
#define CONFIG_SUN_PARTITION 1
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#define CONFIG_SND_GINA24_MODULE 1
#define CONFIG_MD_FAULTY_MODULE 1
#define CONFIG_SYN_COOKIES 1
#define CONFIG_REED_SOLOMON_DEC8 1
#define CONFIG_IRQ_WORK 1
#define CONFIG_ATH9K_MODULE 1
#define CONFIG_PCI_MSI 1
#define CONFIG_IP_ADVANCED_ROUTER 1
#define CONFIG_MISDN_NETJET_MODULE 1
#define CONFIG_VIDEO_USBVISION_MODULE 1
#define CONFIG_FB_SYS_COPYAREA_MODULE 1
#define CONFIG_X86_64_SMP 1
#define CONFIG_USB_EHCI_PCI 1
#define CONFIG_CLEANCACHE 1
#define CONFIG_MEDIA_TUNER_MT2063_MODULE 1
#define CONFIG_USB_STORAGE_ALAUDA_MODULE 1
#define CONFIG_SPARSEMEM_EXTREME 1
#define CONFIG_B44_PCICORE_AUTOSELECT 1
#define CONFIG_IWLWIFI_MODULE 1
#define CONFIG_USB_COMMON 1
#define CONFIG_CYPRESS_FIRMWARE_MODULE 1
#define CONFIG_SENSORS_ADM1031_MODULE 1
#define CONFIG_TASK_XACCT 1
#define CONFIG_MEDIA_TUNER_TDA18271_MODULE 1
#define CONFIG_IP_SET_BITMAP_PORT_MODULE 1
#define CONFIG_IP6_NF_IPTABLES_MODULE 1
#define CONFIG_KVM_VFIO 1
#define CONFIG_DEBUG_NX_TEST_MODULE 1
#define CONFIG_USB_HSIC_USB3503_MODULE 1
#define CONFIG_X86_PCC_CPUFREQ_MODULE 1
#define CONFIG_DVB_IX2505V_MODULE 1
#define CONFIG_FIXED_PHY 1
#define CONFIG_GPIO_ACPI 1
#define CONFIG_ARCH_DEFCONFIG "arch/x86/configs/x86_64_defconfig"
#define CONFIG_NLS_MAC_GAELIC_MODULE 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_FTRACE_SYSCALLS 1
#define CONFIG_SND_CA0106_MODULE 1
#define CONFIG_NF_DUP_IPV4_MODULE 1
#define CONFIG_BLK_DEV_DM_BUILTIN 1
#define CONFIG_USB_SERIAL_IPW_MODULE 1
#define CONFIG_I2C_PIIX4_MODULE 1
#define CONFIG_EDAC_I7300_MODULE 1
#define CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE 1
#define CONFIG_PCIEAER_INJECT_MODULE 1
#define CONFIG_INET_IPCOMP_MODULE 1
#define CONFIG_SENSORS_FSCHMD_MODULE 1
#define CONFIG_VGA_ARB_MAX_GPUS 64
#define CONFIG_DVB_USB_DIB0700_MODULE 1
#define CONFIG_HISAX_NICCY 1
#define CONFIG_CAN_PEAK_USB_MODULE 1
#define CONFIG_EVENT_TRACING 1
#define CONFIG_ISDN_DRV_AVMB1_VERBOSE_REASON 1
#define CONFIG_MFD_INTEL_LPSS 1
#define CONFIG_SND_ENS1370_MODULE 1
#define CONFIG_NET_CADENCE 1
#define CONFIG_ASYNC_PQ_MODULE 1
#define CONFIG_HID_KEYTOUCH_MODULE 1
#define CONFIG_HID_CYPRESS 1
#define CONFIG_N_GSM_MODULE 1
#define CONFIG_BRIDGE_EBT_LIMIT_MODULE 1
#define CONFIG_DRM_KMS_HELPER_MODULE 1
#define CONFIG_MLX4_EN_VXLAN 1
#define CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB 1
#define CONFIG_HYSDN_MODULE 1
#define CONFIG_ATA_OVER_ETH_MODULE 1
#define CONFIG_USB_NET_PLUSB_MODULE 1
#define CONFIG_VIDEO_SAA711X_MODULE 1
#define CONFIG_RTL8192C_COMMON_MODULE 1
#define CONFIG_SENSORS_LM95234_MODULE 1
#define CONFIG_PREEMPT_VOLUNTARY 1
#define CONFIG_DVB_BUDGET_CORE_MODULE 1
#define CONFIG_NLS_ISO8859_1_MODULE 1
#define CONFIG_CRYPTO_WORKQUEUE 1
#define CONFIG_MACINTOSH_DRIVERS 1
#define CONFIG_ALX_MODULE 1
#define CONFIG_R8169_MODULE 1
#define CONFIG_ATOMIC64_SELFTEST 1
#define CONFIG_TCP_CONG_HYBLA_MODULE 1
#define CONFIG_PCI_STUB 1
#define CONFIG_CRYPTO_DRBG_CTR 1
#define CONFIG_HID_KENSINGTON 1
#define CONFIG_USB_EHCI_HCD 1
#define CONFIG_TEXTSEARCH_BM_MODULE 1
#define CONFIG_FUJITSU_ES_MODULE 1
#define CONFIG_CIFS_SMB2 1
#define CONFIG_8139TOO_MODULE 1
#define CONFIG_NF_CONNTRACK_PROCFS 1
#define CONFIG_NLS_MAC_INUIT_MODULE 1
#define CONFIG_BT_HCIUART_LL 1
#define CONFIG_HID_ZYDACRON_MODULE 1
#define CONFIG_PPP_MPPE_MODULE 1
#define CONFIG_CAN_CALC_BITTIMING 1
#define CONFIG_DE2104X_MODULE 1
#define CONFIG_MEMORY_HOTPLUG 1
#define CONFIG_VMD 1
#define CONFIG_DVB_B2C2_FLEXCOP_MODULE 1
#define CONFIG_HOTPLUG_PCI_ACPI 1
#define CONFIG_RFKILL_MODULE 1
#define CONFIG_VIDEO_TVP5150_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0012_MODULE 1
#define CONFIG_NETDEVICES 1
#define CONFIG_NET_KEY_MODULE 1
#define CONFIG_SMS_SIANO_MDTV_MODULE 1
#define CONFIG_HAVE_CONTEXT_TRACKING 1
#define CONFIG_IP6_NF_TARGET_HL_MODULE 1
#define CONFIG_IOSCHED_DEADLINE 1
#define CONFIG_DLCI_MODULE 1
#define CONFIG_SND_OPL3_LIB_SEQ_MODULE 1
#define CONFIG_CGROUP_FREEZER 1
#define CONFIG_VIDEO_UPD64083_MODULE 1
#define CONFIG_EVENTFD 1
#define CONFIG_CRYPTO_DEV_PADLOCK_SHA_MODULE 1
#define CONFIG_RTL8192CE_MODULE 1
#define CONFIG_WAN 1
#define CONFIG_VLAN_8021Q_MVRP 1
#define CONFIG_RTL8821AE_MODULE 1
#define CONFIG_FS_POSIX_ACL 1
#define CONFIG_IPV6_SIT_MODULE 1
#define CONFIG_XFRM 1
#define CONFIG_SENSORS_K8TEMP_MODULE 1
#define CONFIG_DEFCONFIG_LIST "/lib/modules/$UNAME_RELEASE/.config"
#define CONFIG_ASYNC_TX_DMA 1
#define CONFIG_ARCH_HAS_PMEM_API 1
#define CONFIG_HAVE_KPROBES_ON_FTRACE 1
#define CONFIG_IP_SET_HASH_IP_MODULE 1
#define CONFIG_YENTA_TOSHIBA 1
#define CONFIG_MFD_VX855_MODULE 1
#define CONFIG_SERIAL_8250_CONSOLE 1
#define CONFIG_IPV6_MULTIPLE_TABLES 1
#define CONFIG_USB_ANNOUNCE_NEW_DEVICES 1
#define CONFIG_USB_SERIAL_WHITEHEAT_MODULE 1
#define CONFIG_NET_CLS_ROUTE4_MODULE 1
#define CONFIG_JUMP_LABEL 1
#define CONFIG_OVERLAY_FS_MODULE 1
#define CONFIG_IP_SET_HASH_NETPORT_MODULE 1
#define CONFIG_TCG_INFINEON_MODULE 1
#define CONFIG_ATH9K_HTC_MODULE 1
#define CONFIG_IP_VS_DH_MODULE 1
#define CONFIG_BRCMFMAC_PROTO_MSGBUF 1
#define CONFIG_RT2800PCI_RT3290 1
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_AIC79XX_RESET_DELAY_MS 15000
#define CONFIG_SECURITY_SELINUX_DISABLE 1
#define CONFIG_NF_CONNTRACK_BROADCAST_MODULE 1
#define CONFIG_IR_RC5_SZ_DECODER_MODULE 1
#define CONFIG_PROC_PAGE_MONITOR 1
#define CONFIG_SERIAL_8250_EXTENDED 1
#define CONFIG_RCU_FANOUT_LEAF 16
#define CONFIG_IGB_HWMON 1
#define CONFIG_DM_CACHE_MODULE 1
#define CONFIG_MEDIA_TUNER_R820T_MODULE 1
#define CONFIG_IPMI_DEVICE_INTERFACE_MODULE 1
#define CONFIG_NF_NAT_PROTO_DCCP_MODULE 1
#define CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV 1
#define CONFIG_SENSORS_ADM1021_MODULE 1
#define CONFIG_DM_DELAY_MODULE 1
#define CONFIG_X86_CMOV 1
#define CONFIG_USB_SERIAL_CH341_MODULE 1
#define CONFIG_USB_FTDI_ELAN_MODULE 1
#define CONFIG_ACPI_HOTPLUG_CPU 1
#define CONFIG_RD_LZO 1
#define CONFIG_DVB_USB_FRIIO_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORT_MODULE 1
#define CONFIG_SENSORS_SHT21_MODULE 1
#define CONFIG_USB_IOWARRIOR_MODULE 1
#define CONFIG_SND_HDSP_MODULE 1
#define CONFIG_OPENVSWITCH_GENEVE_MODULE 1
#define CONFIG_USBPCWATCHDOG_MODULE 1
#define CONFIG_MODULE_SIG_ALL 1
#define CONFIG_USB_EZUSB_FX2_MODULE 1
#define CONFIG_SND_USB_TONEPORT_MODULE 1
#define CONFIG_SND_USB_USX2Y_MODULE 1
#define CONFIG_SCSI_SPI_ATTRS_MODULE 1
#define CONFIG_BCMA_DRIVER_GMAC_CMN 1
#define CONFIG_SCSI_HPSA_MODULE 1
#define CONFIG_MICROCODE_AMD 1
#define CONFIG_SND_KORG1212_MODULE 1
#define CONFIG_SENSORS_VIA_CPUTEMP_MODULE 1
#define CONFIG_NF_CONNTRACK_SECMARK 1
#define CONFIG_ISDN_DRV_GIGASET_MODULE 1
#define CONFIG_CHELSIO_T3_MODULE 1
#define CONFIG_INSTRUCTION_DECODER 1
#define CONFIG_CRYPTO_SHA512_MODULE 1
#define CONFIG_MWIFIEX_PCIE_MODULE 1
#define CONFIG_CAN_C_CAN_PCI_MODULE 1
#define CONFIG_TRUSTED_KEYS 1
#define CONFIG_BACKLIGHT_CLASS_DEVICE 1
#define CONFIG_VHOST_MODULE 1
#define CONFIG_USB_M5602_MODULE 1
#define CONFIG_RT2X00_LIB_USB_MODULE 1
#define CONFIG_CRYPTO_NULL_MODULE 1
#define CONFIG_DVB_USB_AF9005_REMOTE_MODULE 1
#define CONFIG_NF_DEFRAG_IPV4_MODULE 1
#define CONFIG_USER_RETURN_NOTIFIER 1
#define CONFIG_INTEL_IOMMU_FLOPPY_WA 1
#define CONFIG_USB_IDMOUSE_MODULE 1
#define CONFIG_SELECT_MEMORY_MODEL 1
#define CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64_MODULE 1
#define CONFIG_MISDN_INFINEON_MODULE 1
#define CONFIG_INET_XFRM_MODE_BEET_MODULE 1
#define CONFIG_INFINIBAND_IPOIB_DEBUG 1
#define CONFIG_HID_LCPOWER_MODULE 1
#define CONFIG_VIRTIO_CONSOLE_MODULE 1
#define CONFIG_ACPI_APEI_EINJ_MODULE 1
#define CONFIG_PERSISTENT_KEYRINGS 1
#define CONFIG_DVB_BUDGET_AV_MODULE 1
#define CONFIG_IPV6_ROUTE_INFO 1
#define CONFIG_NETFILTER_ADVANCED 1
#define CONFIG_CRYPTO_DEFLATE_MODULE 1
#define CONFIG_GENERIC_STRNLEN_USER 1
#define CONFIG_USB_APPLEDISPLAY_MODULE 1
#define CONFIG_USB_SERIAL_KLSI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_TCPMSS_MODULE 1
#define CONFIG_IGB_MODULE 1
#define CONFIG_IPV6_ROUTER_PREF 1
#define CONFIG_BT_HCIBTSDIO_MODULE 1
#define CONFIG_DRM_QXL_MODULE 1
#define CONFIG_SLIP_COMPRESSED 1
#define CONFIG_SND_VX_LIB_MODULE 1
#define CONFIG_ARCH_ENABLE_HUGEPAGE_MIGRATION 1
#define CONFIG_DM_SWITCH_MODULE 1
#define CONFIG_CRYPTO_GCM_MODULE 1
#define CONFIG_SND_INDIGOIO_MODULE 1
#define CONFIG_MOUSE_SYNAPTICS_USB_MODULE 1
#define CONFIG_NET_SCTPPROBE_MODULE 1
#define CONFIG_NETFILTER_NETLINK_LOG_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE 1
#define CONFIG_NLS_ISO8859_14_MODULE 1
#define CONFIG_MAGIC_SYSRQ 1
#define CONFIG_IO_DELAY_0X80 1
#define CONFIG_DMI 1
#define CONFIG_IPV6_SIT_6RD 1
#define CONFIG_WIL6210_TRACING 1
#define CONFIG_PARPORT_SERIAL_MODULE 1
#define CONFIG_PNFS_BLOCK_MODULE 1
#define CONFIG_MACHZ_WDT_MODULE 1
#define CONFIG_CPUSETS 1
#define CONFIG_NETFILTER_XT_MATCH_MARK_MODULE 1
#define CONFIG_ISDN 1
#define CONFIG_VIDEO_PVRUSB2_SYSFS 1
#define CONFIG_FUNCTION_PROFILER 1
#define CONFIG_MAC80211_RC_DEFAULT_MINSTREL 1
#define CONFIG_SPARSE_IRQ 1
#define CONFIG_DVB_LGS8GXX_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP_MODULE 1
#define CONFIG_IP_NF_MANGLE_MODULE 1
#define CONFIG_TIFM_7XX1_MODULE 1
#define CONFIG_HID_PICOLCD_LEDS 1
#define CONFIG_RTC_DRV_DS1286_MODULE 1
#define CONFIG_FCOE_FNIC_MODULE 1
#define CONFIG_ATH10K_DEBUGFS 1
#define CONFIG_DVB_VES1X93_MODULE 1
#define CONFIG_DRM_UDL_MODULE 1
#define CONFIG_SECURITYFS 1
#define CONFIG_PARAVIRT_TIME_ACCOUNTING 1
#define CONFIG_RCU_STALL_COMMON 1
#define CONFIG_BT_DEBUGFS 1
#define CONFIG_CPU_SUP_AMD 1
#define CONFIG_INET6_XFRM_MODE_TUNNEL_MODULE 1
#define CONFIG_BRIDGE_EBT_VLAN_MODULE 1
#define CONFIG_PCIEPORTBUS 1
#define CONFIG_MEDIA_SUPPORT_MODULE 1
#define CONFIG_SENSORS_F75375S_MODULE 1
#define CONFIG_DEBUG_BUGVERBOSE 1
#define CONFIG_IP_NF_FILTER_MODULE 1
#define CONFIG_HID_ZEROPLUS_MODULE 1
#define CONFIG_SATA_SX4_MODULE 1
#define CONFIG_MAC802154_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_LENGTH_MODULE 1
#define CONFIG_BRIDGE_EBT_PKTTYPE_MODULE 1
#define CONFIG_FAT_FS_MODULE 1
#define CONFIG_SND_HDA_CODEC_CA0132_MODULE 1
#define CONFIG_FCOE_MODULE 1
#define CONFIG_CAN_SJA1000_MODULE 1
#define CONFIG_SND_HDA_INTEL_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_DH895xCCVF_MODULE 1
#define CONFIG_TEXTSEARCH_FSM_MODULE 1
#define CONFIG_MISDN_DSP_MODULE 1
#define CONFIG_SENSORS_LM75_MODULE 1
#define CONFIG_INFINIBAND_CXGB4_MODULE 1
#define CONFIG_LSI_ET1011C_PHY_MODULE 1
#define CONFIG_HISAX_SEDLBAUER 1
#define CONFIG_IP6_NF_RAW_MODULE 1
#define CONFIG_DVB_USB_EC168_MODULE 1
#define CONFIG_RTC_DRV_DS1742_MODULE 1
#define CONFIG_INET_TUNNEL_MODULE 1
#define CONFIG_X86_INTERNODE_CACHE_SHIFT 6
#define CONFIG_CRYPTO_SERPENT_SSE2_X86_64_MODULE 1
#define CONFIG_CRYPTO_DEV_PADLOCK_MODULE 1
#define CONFIG_SENSORS_PMBUS_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NOTRACK_MODULE 1
#define CONFIG_EEPROM_93CX6_MODULE 1
#define CONFIG_X86_CHECK_BIOS_CORRUPTION 1
#define CONFIG_MMC_BLOCK_BOUNCE 1
#define CONFIG_MLX4_CORE_MODULE 1
#define CONFIG_SND_MIA_MODULE 1
#define CONFIG_VIDEO_STK1160_AC97 1
#define CONFIG_GENERIC_CLOCKEVENTS 1
#define CONFIG_IOSCHED_CFQ 1
#define CONFIG_OID_REGISTRY 1
#define CONFIG_SGI_GRU_MODULE 1
#define CONFIG_DVB_USB_DTT200U_MODULE 1
#define CONFIG_CIFS_UPCALL 1
#define CONFIG_RWSEM_XCHGADD_ALGORITHM 1
#define CONFIG_LIB80211_MODULE 1
#define CONFIG_MFD_CORE 1
#define CONFIG_HAVE_KERNEL_XZ 1
#define CONFIG_USB_CXACRU_MODULE 1
#define CONFIG_DRM_GMA3600 1
#define CONFIG_RAID_ATTRS_MODULE 1
#define CONFIG_RFKILL_LEDS 1
#define CONFIG_BT_HCIBTUSB_BCM 1
#define CONFIG_CONSOLE_TRANSLATIONS 1
#define CONFIG_PATA_CMD64X_MODULE 1
#define CONFIG_TCG_CRB_MODULE 1
#define CONFIG_PUBLIC_KEY_ALGO_RSA 1
#define CONFIG_STOP_MACHINE 1
#define CONFIG_RAID6_PQ_MODULE 1
#define CONFIG_SBC_FITPC2_WATCHDOG_MODULE 1
#define CONFIG_HW_RANDOM_TIMERIOMEM_MODULE 1
#define CONFIG_NET_IPGRE_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_MODULE 1
#define CONFIG_FUSION 1
#define CONFIG_SWIOTLB_XEN 1
#define CONFIG_BRIDGE_EBT_IP6_MODULE 1
#define CONFIG_NF_NAT_SNMP_BASIC_MODULE 1
#define CONFIG_CLS_U32_MARK 1
#define CONFIG_SND_ICE1712_MODULE 1
#define CONFIG_CRYPTO_AKCIPHER_MODULE 1
#define CONFIG_LEDS_TRIGGER_BACKLIGHT_MODULE 1
#define CONFIG_CPU_FREQ 1
#define CONFIG_USB_OHCI_HCD 1
#define CONFIG_USB_GSPCA_MODULE 1
#define CONFIG_VHOST_RING_MODULE 1
#define CONFIG_DM_MIRROR_MODULE 1
#define CONFIG_CRYPTO_BLOWFISH_MODULE 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_MODULE_FORCE_LOAD 1
#define CONFIG_NLS_ASCII 1
#define CONFIG_MEDIA_ALTERA_CI_MODULE 1
#define CONFIG_NF_REJECT_IPV4_MODULE 1
#define CONFIG_IP1000_MODULE 1
#define CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE 1
#define CONFIG_INTEL_MEI_ME_MODULE 1
#define CONFIG_INFINIBAND_QIB_MODULE 1
#define CONFIG_6LOWPAN_NHC_MOBILITY_MODULE 1
#define CONFIG_SATA_SVW_MODULE 1
#define CONFIG_TRACE_IRQFLAGS_SUPPORT 1
#define CONFIG_NFS_V3_ACL 1
#define CONFIG_SENSORS_ADT7462_MODULE 1
#define CONFIG_DETECT_HUNG_TASK 1
#define CONFIG_CRYPTO_CCM_MODULE 1
#define CONFIG_TCP_CONG_ADVANCED 1
#define CONFIG_NET_CLS_RSVP6_MODULE 1
#define CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT 1
#define CONFIG_USB_NET_CDC_SUBSET_MODULE 1
#define CONFIG_BT_RTL_MODULE 1
#define CONFIG_KVM_GUEST 1
#define CONFIG_QFMT_V2 1
#define CONFIG_USB_S2255_MODULE 1
#define CONFIG_INET_DCCP_DIAG_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNMARK_MODULE 1
#define CONFIG_ATH9K_HW_MODULE 1
#define CONFIG_BLK_CGROUP 1
#define CONFIG_USB_SERIAL_MCT_U232_MODULE 1
#define CONFIG_UIO_PDRV_GENIRQ_MODULE 1
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_CRYPTO_RNG 1
#define CONFIG_MEMCG_SWAP_ENABLED 1
#define CONFIG_USB_SERIAL_GARMIN_MODULE 1
#define CONFIG_RAW_DRIVER 1
#define CONFIG_XFS_QUOTA 1
#define CONFIG_ATH10K_MODULE 1
#define CONFIG_NET_SCH_ATM_MODULE 1
#define CONFIG_WINBOND_840_MODULE 1
#define CONFIG_SCSI_3W_9XXX_MODULE 1
#define CONFIG_MVMDIO_MODULE 1
#define CONFIG_SND_USB 1
#define CONFIG_VIDEOBUF2_MEMOPS_MODULE 1
#define CONFIG_KVM_MMU_AUDIT 1
#define CONFIG_RD_GZIP 1
#define CONFIG_ARCH_HAS_CPU_RELAX 1
#define CONFIG_HAVE_REGS_AND_STACK_ACCESS_API 1
#define CONFIG_BCMA_HOST_PCI_POSSIBLE 1
#define CONFIG_SENSORS_LTC4261_MODULE 1
#define CONFIG_MISDN_W6692_MODULE 1
#define CONFIG_MLX5_CORE_EN_VXLAN 1
#define CONFIG_USB_SERIAL_KEYSPAN_MODULE 1
#define CONFIG_LEDS_DELL_NETBOOKS_MODULE 1
#define CONFIG_TREE_RCU 1
#define CONFIG_PWM_SYSFS 1
#define CONFIG_SWIOTLB 1
#define CONFIG_SND_USB_CAIAQ_MODULE 1
#define CONFIG_USB_STORAGE_CYPRESS_ATACB_MODULE 1
#define CONFIG_EXT4_FS_SECURITY 1
#define CONFIG_ATH9K_HWRNG 1
#define CONFIG_SCSI_MVUMI_MODULE 1
#define CONFIG_NET_TEAM_MODE_ACTIVEBACKUP_MODULE 1
#define CONFIG_SND_ALI5451_MODULE 1
#define CONFIG_INFINIBAND_USER_MAD_MODULE 1
#define CONFIG_HID_ROCCAT_MODULE 1
#define CONFIG_F71808E_WDT_MODULE 1
#define CONFIG_INET_XFRM_MODE_TRANSPORT_MODULE 1
#define CONFIG_CRYPTO_MD5 1
#define CONFIG_VIDEO_CS53L32A_MODULE 1
#define CONFIG_IR_REDRAT3_MODULE 1
#define CONFIG_USB_GSPCA_VICAM_MODULE 1
#define CONFIG_TRANSPARENT_HUGEPAGE 1
#define CONFIG_CLOCKSOURCE_VALIDATE_LAST_CYCLE 1
#define CONFIG_ISCSI_TCP_MODULE 1
#define CONFIG_ATA_ACPI 1
#define CONFIG_NFSD_V3 1
#define CONFIG_PATA_ALI_MODULE 1
#define CONFIG_X86_EXTENDED_PLATFORM 1
#define CONFIG_ISDN_MPP 1
#define CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE 1
#define CONFIG_RT2800USB_RT53XX 1
#define CONFIG_HAVE_ARCH_KMEMCHECK 1
#define CONFIG_SND_ECHO3G_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0011_MODULE 1
#define CONFIG_ACPI_PROCESSOR 1
#define CONFIG_XEN_SCRUB_PAGES 1
#define CONFIG_DVB_TDA10023_MODULE 1
#define CONFIG_MEDIA_TUNER_TEA5767_MODULE 1
#define CONFIG_NFT_REDIR_IPV6_MODULE 1
#define CONFIG_HAVE_KVM 1
#define CONFIG_SND_FIREWIRE 1
#define CONFIG_VIDEOBUF_DVB_MODULE 1
#define CONFIG_PCCARD 1
#define CONFIG_HAVE_GENERIC_HARDIRQS 1
#define CONFIG_USB_GSPCA_OV519_MODULE 1
#define CONFIG_BINFMT_ELF 1
#define CONFIG_RTC_DRV_RX4581_MODULE 1
#define CONFIG_SCSI_PROC_FS 1
#define CONFIG_I2C_HID_MODULE 1
#define CONFIG_MD_RAID456_MODULE 1
#define CONFIG_SCHED_TRACER 1
#define CONFIG_CICADA_PHY_MODULE 1
#define CONFIG_UDF_NLS 1
#define CONFIG_HAVE_PERF_REGS 1
#define CONFIG_CIFS_DEBUG 1
#define CONFIG_LEDS_LP55XX_COMMON_MODULE 1
#define CONFIG_USB_SISUSBVGA_CON 1
#define CONFIG_HAVE_KVM_MSI 1
#define CONFIG_MEDIA_ANALOG_TV_SUPPORT 1
#define CONFIG_IP_PIMSM_V1 1
#define CONFIG_INET6_AH_MODULE 1
#define CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT 1
#define CONFIG_SENSORS_MAX197_MODULE 1
#define CONFIG_TARGET_CORE_MODULE 1
#define CONFIG_NFS_V4_SECURITY_LABEL 1
#define CONFIG_USB_SERIAL 1
#define CONFIG_VIDEO_CX88_ALSA_MODULE 1
#define CONFIG_NFT_DUP_IPV4_MODULE 1
#define CONFIG_SENSORS_GL518SM_MODULE 1
#define CONFIG_USB_MON 1
#define CONFIG_VIDEO_SAA717X_MODULE 1
#define CONFIG_IP_NF_TARGET_ULOG_MODULE 1
#define CONFIG_KEYS 1
#define CONFIG_BE2ISCSI_MODULE 1
#define CONFIG_INET_XFRM_TUNNEL_MODULE 1
#define CONFIG_RTC_DRV_FM3130_MODULE 1
#define CONFIG_MFD_RTSX_USB_MODULE 1
#define CONFIG_IPMI_POWEROFF_MODULE 1
#define CONFIG_SND_VMASTER 1
#define CONFIG_NETFILTER_XT_MARK_MODULE 1
#define CONFIG_NETFILTER_XTABLES 1
#define CONFIG_IP_VS_LBLC_MODULE 1
#define CONFIG_HAVE_KVM_IRQ_BYPASS 1
#define CONFIG_SYSTEM_BLACKLIST_KEYRING 1
#define CONFIG_BLK_DEV_NULL_BLK_MODULE 1
#define CONFIG_DP83640_PHY_MODULE 1
#define CONFIG_DVB_USB_OPERA1_MODULE 1
#define CONFIG_SLABINFO 1
#define CONFIG_KEYS_DEBUG_PROC_KEYS 1
#define CONFIG_IPMI_SI_MODULE 1
#define CONFIG_USB_STORAGE_DATAFAB_MODULE 1
#define CONFIG_DVB_USB_AF9005_MODULE 1
#define CONFIG_NFT_RBTREE_MODULE 1
#define CONFIG_TCP_CONG_VEGAS_MODULE 1
#define CONFIG_CRYPTO_USER_API_HASH 1
#define CONFIG_TIMER_STATS 1
#define CONFIG_SENSORS_IBMPEX_MODULE 1
#define CONFIG_BOOT_PRINTK_DELAY 1
#define CONFIG_IWLMVM_MODULE 1
#define CONFIG_SENSORS_ADM1026_MODULE 1
#define CONFIG_PATA_NINJA32_MODULE 1
#define CONFIG_SENSORS_ADT7470_MODULE 1
#define CONFIG_PM_SLEEP_SMP 1
#define CONFIG_CRYPTO_HW 1
#define CONFIG_MAC80211_RC_MINSTREL_HT 1
#define CONFIG_USB_STORAGE_KARMA_MODULE 1
#define CONFIG_TTPCI_EEPROM_MODULE 1
#define CONFIG_PCSPKR_PLATFORM 1
#define CONFIG_CARDBUS 1
#define CONFIG_ATH9K_AHB 1
#define CONFIG_HID_GREENASIA_MODULE 1
#define CONFIG_XEN_ACPI_PROCESSOR_MODULE 1
#define CONFIG_INTEGRITY_ASYMMETRIC_KEYS 1
#define CONFIG_INTEL_POWERCLAMP_MODULE 1
#define CONFIG_BIG_KEYS 1
#define CONFIG_SMS_USB_DRV_MODULE 1
#define CONFIG_ACPI_AC 1
#define CONFIG_HID_STEELSERIES_MODULE 1
#define CONFIG_SPI_MASTER 1
#define CONFIG_USB_SERIAL_OPTICON_MODULE 1
#define CONFIG_LWTUNNEL 1
#define CONFIG_DVB_NXT200X_MODULE 1
#define CONFIG_SENSORS_LM87_MODULE 1
#define CONFIG_SND_SST_IPC_ACPI_MODULE 1
#define CONFIG_BLK_DEV_THROTTLING 1
#define CONFIG_VT_HW_CONSOLE_BINDING 1
#define CONFIG_NET_TEAM_MODE_BROADCAST_MODULE 1
#define CONFIG_CHARGER_SMB347_MODULE 1
#define CONFIG_NET_ACT_GACT_MODULE 1
#define CONFIG_RTL8192E_MODULE 1
#define CONFIG_SND_SEQUENCER_OSS 1
#define CONFIG_HID_GYRATION_MODULE 1
#define CONFIG_NFT_MASQ_IPV4_MODULE 1
#define CONFIG_USB_WDM_MODULE 1
#define CONFIG_PATA_TOSHIBA_MODULE 1
#define CONFIG_BT_HCIBCM203X_MODULE 1
#define CONFIG_THERMAL_HWMON 1
#define CONFIG_SND_USB_HIFACE_MODULE 1
#define CONFIG_VIDEO_EM28XX_DVB_MODULE 1
#define CONFIG_USB_SERIAL_KOBIL_SCT_MODULE 1
#define CONFIG_HDLC_FR_MODULE 1
#define CONFIG_OPROFILE_EVENT_MULTIPLEX 1
#define CONFIG_GENEVE_MODULE 1
#define CONFIG_XZ_DEC_X86 1
#define CONFIG_VIRT_CPU_ACCOUNTING 1
#define CONFIG_MLX5_INFINIBAND_MODULE 1
#define CONFIG_MAC80211_LEDS 1
#define CONFIG_NETFILTER_XT_TARGET_TPROXY_MODULE 1
#define CONFIG_HIBERNATE_CALLBACKS 1
#define CONFIG_SERIAL_8250_DW 1
#define CONFIG_IP_DCCP_MODULE 1
#define CONFIG_FIREWIRE_OHCI_MODULE 1
#define CONFIG_USB_ACM_MODULE 1
#define CONFIG_USB_RTL8150_MODULE 1
#define CONFIG_CRC16 1
#define CONFIG_DEBUG_SHIRQ 1
#define CONFIG_USB_NET_AX8817X_MODULE 1
#define CONFIG_SND_EMU10K1_MODULE 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_CRYPTO_GF128MUL_MODULE 1
#define CONFIG_NLS_ISO8859_6_MODULE 1
#define CONFIG_NET_CLS 1
#define CONFIG_SND_INDIGO_MODULE 1
#define CONFIG_EFI_SIGNATURE_LIST_PARSER 1
#define CONFIG_UIO_PDRV_MODULE 1
#define CONFIG_TMPFS 1
#define CONFIG_NFT_CT_MODULE 1
#define CONFIG_ANON_INODES 1
#define CONFIG_VIDEO_EM28XX_MODULE 1
#define CONFIG_NLS_CODEPAGE_936_MODULE 1
#define CONFIG_IR_ITE_CIR_MODULE 1
#define CONFIG_DVB_BUDGET_MODULE 1
#define CONFIG_FUTEX 1
#define CONFIG_CRYPTO_ANUBIS_MODULE 1
#define CONFIG_VIRTIO_PCI_MODULE 1
#define CONFIG_MISDN_HFCMULTI_MODULE 1
#define CONFIG_HISAX_AVM_A1_PCMCIA 1
#define CONFIG_USB_GSPCA_SQ930X_MODULE 1
#define CONFIG_RTL8192SE_MODULE 1
#define CONFIG_REGMAP_I2C_MODULE 1
#define CONFIG_ATH9K_DEBUGFS 1
#define CONFIG_SND_SOC_INTEL_SST_MATCH_MODULE 1
#define CONFIG_NET_VENDOR_REALTEK 1
#define CONFIG_MFD_SM501_GPIO 1
#define CONFIG_DVB_DM1105_MODULE 1
#define CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG 1
#define CONFIG_NETFILTER_XT_TARGET_HL_MODULE 1
#define CONFIG_MEGARAID_SAS_MODULE 1
#define CONFIG_PATA_HPT3X2N_MODULE 1
#define CONFIG_DVB_CORE_MODULE 1
#define CONFIG_NFSD_V2_ACL 1
#define CONFIG_ISL29003_MODULE 1
#define CONFIG_CRYPTO_USER_API 1
#define CONFIG_RTC_HCTOSYS 1
#define CONFIG_SECURITY_NETWORK 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_HUGETLB_PAGE 1
#define CONFIG_HW_RANDOM_TPM_MODULE 1
#define CONFIG_CIFS_WEAK_PW_HASH 1
#define CONFIG_SENSORS_LM78_MODULE 1
#define CONFIG_NET_VENDOR_EMULEX 1
#define CONFIG_SENSORS_K10TEMP_MODULE 1
#define CONFIG_USB_HID 1
#define CONFIG_DVB_USB_AF9015_MODULE 1
#define CONFIG_RTL8192CU_MODULE 1
#define CONFIG_CRYPTO_TGR192_MODULE 1
#define CONFIG_BLK_DEV_RBD_MODULE 1
#define CONFIG_USER_STACKTRACE_SUPPORT 1
#define CONFIG_NF_TABLES_MODULE 1
#define CONFIG_IT8712F_WDT_MODULE 1
#define CONFIG_SLUB_DEBUG 1
#define CONFIG_RTC_DRV_M41T80_WDT 1
#define CONFIG_BLK_DEV_MD 1
#define CONFIG_UCS2_STRING 1
#define CONFIG_MMC_VUB300_MODULE 1
#define CONFIG_USB_SERIAL_AIRCABLE_MODULE 1
#define CONFIG_IP_SET_BITMAP_IP_MODULE 1
#define CONFIG_MAC_EMUMOUSEBTN 1
#define CONFIG_NET_SCH_INGRESS_MODULE 1
#define CONFIG_BCMA_MODULE 1
#define CONFIG_DMADEVICES 1
#define CONFIG_XENFS_MODULE 1
#define CONFIG_SCSI_AACRAID_MODULE 1
#define CONFIG_MISDN_HFCUSB_MODULE 1
#define CONFIG_ACPI_APEI_MEMORY_FAILURE 1
#define CONFIG_NF_CONNTRACK_EVENTS 1
#define CONFIG_MOUSE_PS2_ELANTECH 1
#define CONFIG_PINCTRL 1
#define CONFIG_IPV6_NDISC_NODETYPE 1
#define CONFIG_RTC_DRV_MSM6242_MODULE 1
#define CONFIG_DVB_USB_TECHNISAT_USB2_MODULE 1
#define CONFIG_PCI_LABEL 1
#define CONFIG_CRYPTO_ZLIB_MODULE 1
#define CONFIG_NLS_CODEPAGE_1251_MODULE 1
#define CONFIG_EDAC_X38_MODULE 1
#define CONFIG_FANOTIFY 1
#define CONFIG_ISDN_CAPI_CAPIDRV_MODULE 1
#define CONFIG_SONYPI_COMPAT 1
#define CONFIG_IP_VS_PROTO_SCTP 1
#define CONFIG_SP5100_TCO_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLABEL_MODULE 1
#define CONFIG_BLK_DEV_SR_VENDOR 1
#define CONFIG_SATA_SIL_MODULE 1
#define CONFIG_ALTERA_STAPL_MODULE 1
#define CONFIG_USERFAULTFD 1
#define CONFIG_CGROUP_SCHED 1
#define CONFIG_SND_HDA_RECONFIG 1
#define CONFIG_SYSVIPC 1
#define CONFIG_CRYPTO_PCOMP2 1
#define CONFIG_HAVE_DEBUG_KMEMLEAK 1
#define CONFIG_DVB_TDA10071_MODULE 1
#define CONFIG_HDLC_CISCO_MODULE 1
#define CONFIG_MLX4_INFINIBAND_MODULE 1
#define CONFIG_DVB_OR51211_MODULE 1
#define CONFIG_RT2X00_MODULE 1
#define CONFIG_NLS_CODEPAGE_863_MODULE 1
#define CONFIG_SENSORS_ADT7X10_MODULE 1
#define CONFIG_NF_CONNTRACK_FTP_MODULE 1
#define CONFIG_CHELSIO_T4_MODULE 1
#define CONFIG_MODULES 1
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#define CONFIG_EEPROM_LEGACY_MODULE 1
#define CONFIG_INFINIBAND_NES_MODULE 1
#define CONFIG_USB_GSPCA_SPCA506_MODULE 1
#define CONFIG_CAN_CC770_PLATFORM_MODULE 1
#define CONFIG_PATA_ARTOP_MODULE 1
#define CONFIG_CONTEXT_TRACKING 1
#define CONFIG_HARDLOCKUP_DETECTOR 1
#define CONFIG_VIDEO_CX88_DVB_MODULE 1
#define CONFIG_VIDEO_EM28XX_ALSA_MODULE 1
#define CONFIG_MEDIA_TUNER_MXL5005S_MODULE 1
#define CONFIG_USB_HIDDEV 1
#define CONFIG_IOMMU_IOVA 1
#define CONFIG_INFINIBAND_IPOIB_MODULE 1
#define CONFIG_SENSORS_APDS990X_MODULE 1
#define CONFIG_DVB_SI21XX_MODULE 1
#define CONFIG_SOUND_MODULE 1
#define CONFIG_NFT_MASQ_MODULE 1
#define CONFIG_JOLIET 1
#define CONFIG_DVB_USB_VP7045_MODULE 1
#define CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_KPROBES_ON_FTRACE 1
#define CONFIG_BNX2X_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA9887_MODULE 1
#define CONFIG_AUDIT_WATCH 1
#define CONFIG_CRYPTO_TEA_MODULE 1
#define CONFIG_ARCH_HIBERNATION_POSSIBLE 1
#define CONFIG_KVM_APIC_ARCHITECTURE 1
#define CONFIG_DVB_USB_LME2510_MODULE 1
#define CONFIG_PDC_ADMA_MODULE 1
#define CONFIG_SND_USB_LINE6_MODULE 1
#define CONFIG_UNIX 1
#define CONFIG_USB_CATC_MODULE 1
#define CONFIG_USB_NET_DRIVERS 1
#define CONFIG_SCSI_SRP_MODULE 1
#define CONFIG_VIDEO_TLG2300_MODULE 1
#define CONFIG_NO_HZ_COMMON 1
#define CONFIG_DRM_MIPI_DSI 1
#define CONFIG_BRCMSMAC_MODULE 1
#define CONFIG_XEN_DEV_EVTCHN_MODULE 1
#define CONFIG_HAVE_CLK 1
#define CONFIG_CRYPTO_HASH2 1
#define CONFIG_CARL9170_MODULE 1
#define CONFIG_SND_HDA_CODEC_CONEXANT_MODULE 1
#define CONFIG_THERMAL_GOV_STEP_WISE 1
#define CONFIG_SND_RME9652_MODULE 1
#define CONFIG_DEFAULT_HOSTNAME "(none)"
#define CONFIG_NLS_KOI8_R_MODULE 1
#define CONFIG_SENSORS_ADT7410_MODULE 1
#define CONFIG_USB_GSPCA_SONIXB_MODULE 1
#define CONFIG_DVB_USB_RTL28XXU_MODULE 1
#define CONFIG_MMC_REALTEK_PCI_MODULE 1
#define CONFIG_USB_STORAGE_ISD200_MODULE 1
#define CONFIG_CPU_FREQ_GOV_POWERSAVE 1
#define CONFIG_USB_GSPCA_OV534_9_MODULE 1
#define CONFIG_NFS_FS_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_X86_64_MODULE 1
#define CONFIG_USB_NET_SMSC95XX_MODULE 1
#define CONFIG_CRASH_DUMP 1
#define CONFIG_INFINIBAND_ADDR_TRANS 1
#define CONFIG_BLK_DEV_IO_TRACE 1
#define CONFIG_XPS 1
#define CONFIG_CRYPTO_DEV_QAT_DH895xCC_MODULE 1
#define CONFIG_NET_ACT_SKBEDIT_MODULE 1
#define CONFIG_INET_ESP_MODULE 1
#define CONFIG_SECURITY_SELINUX_DEVELOP 1
#define CONFIG_HPET_TIMER 1
#define CONFIG_NF_CONNTRACK_ZONES 1
#define CONFIG_EFI_RUNTIME_MAP 1
#define CONFIG_NF_CONNTRACK_IPV6_MODULE 1
#define CONFIG_MD 1
#define CONFIG_CRYPTO_ALGAPI 1
#define CONFIG_SENSORS_VT8231_MODULE 1
#define CONFIG_DVB_BUDGET_CI_MODULE 1
#define CONFIG_EDAC_I3200_MODULE 1
#define CONFIG_BSD_PROCESS_ACCT_V3 1
#define CONFIG_BRIDGE_MODULE 1
#define CONFIG_MEDIA_TUNER_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CGROUP_MODULE 1
#define CONFIG_TABLET_USB_GTCO_MODULE 1
#define CONFIG_RD_BZIP2 1
#define CONFIG_MFD_VIPERBOARD_MODULE 1
#define CONFIG_WANT_DEV_COREDUMP 1
#define CONFIG_INPUT_UINPUT_MODULE 1
#define CONFIG_SERIAL_ARC_NR_PORTS 1
#define CONFIG_NETFILTER_XT_TARGET_CHECKSUM_MODULE 1
#define CONFIG_LEDS_TRIGGER_GPIO_MODULE 1
#define CONFIG_RTLWIFI_USB_MODULE 1
#define CONFIG_TCG_ATMEL_MODULE 1
#define CONFIG_DVB_MB86A16_MODULE 1
#define CONFIG_MEDIA_TUNER_SIMPLE_MODULE 1
#define CONFIG_SND_OXYGEN_MODULE 1
#define CONFIG_PCH_GBE_MODULE 1
#define CONFIG_KEYBOARD_ATKBD 1
#define CONFIG_SCSI_QLA_ISCSI_MODULE 1
#define CONFIG_HAVE_MEMBLOCK_NODE_MAP 1
#define CONFIG_X86_PLATFORM_DEVICES 1
#define CONFIG_LIBNVDIMM_MODULE 1
#define CONFIG_NET_IP_TUNNEL_MODULE 1
#define CONFIG_INFINIBAND_ADDR_TRANS_CONFIGFS 1
#define CONFIG_MTD_CFI_I1 1
#define CONFIG_NF_NAT_MODULE 1
#define CONFIG_MAX_RAW_DEVS 8192
#define CONFIG_W83877F_WDT_MODULE 1
#define CONFIG_VIDEO_UPD64031A_MODULE 1
#define CONFIG_USB_SERIAL_XIRCOM_MODULE 1
#define CONFIG_BLK_DEV_INTEGRITY 1
#define CONFIG_DVB_USB_AZ6027_MODULE 1
#define CONFIG_NET_VENDOR_OKI 1
#define CONFIG_MOUSE_BCM5974_MODULE 1
#define CONFIG_CPU_IDLE 1
#define CONFIG_NTB_MODULE 1
#define CONFIG_IP6_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_NF_TABLES_INET_MODULE 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_CHR_DEV_SCH_MODULE 1
#define CONFIG_6LOWPAN_NHC_IPV6_MODULE 1
#define CONFIG_NF_TABLES_IPV6_MODULE 1
#define CONFIG_FAIR_GROUP_SCHED 1
#define CONFIG_RT2800USB_MODULE 1
#define CONFIG_ARCH_HAS_ATOMIC64_DEC_IF_POSITIVE 1
#define CONFIG_CRYPTO_HASH 1
#define CONFIG_HAVE_STACK_VALIDATION 1
#define CONFIG_EFI_PARTITION 1
#define CONFIG_PROBE_EVENTS 1
#define CONFIG_TRACE_CLOCK 1
#define CONFIG_TCG_TIS_I2C_INFINEON_MODULE 1
#define CONFIG_SND_HDA_CODEC_HDMI_MODULE 1
#define CONFIG_MODULE_SIG_HASH "sha256"
#define CONFIG_PCI_BUS_ADDR_T_64BIT 1
#define CONFIG_LOG_BUF_SHIFT 20
#define CONFIG_PATA_IT8213_MODULE 1
#define CONFIG_MEMORY_HOTREMOVE 1
#define CONFIG_SND_CMIPCI_MODULE 1
#define CONFIG_WLAN_VENDOR_ATH 1
#define CONFIG_HZ_1000 1
#define CONFIG_ACPI_WMI_MODULE 1
#define CONFIG_HPET 1
#define CONFIG_NLS_CODEPAGE_857_MODULE 1
#define CONFIG_SOUND_OSS_CORE_PRECLAIM 1
#define CONFIG_NETFILTER_XT_TARGET_DSCP_MODULE 1
#define CONFIG_SND_EMU10K1X_MODULE 1
#define CONFIG_EXTRA_FIRMWARE ""
#define CONFIG_TCG_TPM 1
#define CONFIG_LEDS_LP5562_MODULE 1
#define CONFIG_IPV6_MROUTE 1
#define CONFIG_PROC_EVENTS 1
#define CONFIG_ACPI_VIDEO_MODULE 1
#define CONFIG_VIRT_TO_BUS 1
#define CONFIG_VFAT_FS_MODULE 1
#define CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE 1
#define CONFIG_EDAC_I5000_MODULE 1
#define CONFIG_PID_NS 1
#define CONFIG_SND_SOC_DMIC_MODULE 1
#define CONFIG_MD_RAID1_MODULE 1
#define CONFIG_CRYPTO_VMAC_MODULE 1
#define CONFIG_SENSORS_ACPI_POWER_MODULE 1
#define CONFIG_KEXEC 1
#define CONFIG_ACPI_CMPC_MODULE 1
#define CONFIG_CRC32_SLICEBY8 1
#define CONFIG_SCSI_MPT2SAS_MODULE 1
#define CONFIG_HVC_XEN 1
#define CONFIG_UWB_WHCI_MODULE 1
#define CONFIG_NET_SCH_FQ_MODULE 1
#define CONFIG_VIDEO_HDPVR_MODULE 1
#define CONFIG_EDAC_AMD64_MODULE 1
#define CONFIG_BLK_DEV_SR_MODULE 1
#define CONFIG_CPU_RMAP 1
#define CONFIG_SND_HWDEP_MODULE 1
#define CONFIG_PANIC_ON_OOPS 1
#define CONFIG_GENERIC_CPU 1
#define CONFIG_GIGASET_M101_MODULE 1
#define CONFIG_SND_LAYLA20_MODULE 1
#define CONFIG_BLK_DEV_LOOP_MODULE 1
#define CONFIG_DVB_BT8XX_MODULE 1
#define CONFIG_IPMI_HANDLER_MODULE 1
#define CONFIG_B44_MODULE 1
#define CONFIG_DEFAULT_HUNG_TASK_TIMEOUT 120
#define CONFIG_VIRTIO_PCI_LEGACY 1
#define CONFIG_SENSORS_THMC50_MODULE 1
#define CONFIG_ARCH_HIBERNATION_HEADER 1
#define CONFIG_HAVE_OPTPROBES 1
#define CONFIG_HAVE_FENTRY 1
#define CONFIG_L2TP_ETH_MODULE 1
#define CONFIG_PATA_ATIIXP_MODULE 1
#define CONFIG_I8K_MODULE 1
#define CONFIG_HYPERV_UTILS_MODULE 1
#define CONFIG_SYNCLINK_GT_MODULE 1
#define CONFIG_CFQ_GROUP_IOSCHED 1
#define CONFIG_NF_NAT_IRC_MODULE 1
#define CONFIG_MEDIA_TUNER_XC2028_MODULE 1
#define CONFIG_INPUT_MISC 1
#define CONFIG_SND_COMPRESS_OFFLOAD_MODULE 1
#define CONFIG_IR_NUVOTON_MODULE 1
#define CONFIG_SENSORS_SCH5627_MODULE 1
#define CONFIG_I2C_AMD756_MODULE 1
#define CONFIG_E1000E_MODULE 1
#define CONFIG_DNET_MODULE 1
#define CONFIG_CRYPTO_CAST6_AVX_X86_64_MODULE 1
#define CONFIG_DVB_STV0288_MODULE 1
#define CONFIG_SUSPEND 1
#define CONFIG_SUNRPC_XPRT_RDMA_MODULE 1
#define CONFIG_SND_SOC_INTEL_SST_ACPI_MODULE 1
#define CONFIG_CROSS_MEMORY_ATTACH 1
#define CONFIG_CRYPTO_CBC 1
#define CONFIG_SENSORS_LM93_MODULE 1
#define CONFIG_BT_CMTP_MODULE 1
#define CONFIG_KS0108_DELAY 2
#define CONFIG_VIDEO_CX88_VP3054_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_HMARK_MODULE 1
#define CONFIG_MRP_MODULE 1
#define CONFIG_I8253_LOCK 1
#define CONFIG_SMSC_SCH311X_WDT_MODULE 1
#define CONFIG_AIC79XX_CMDS_PER_DEVICE 4
#define CONFIG_IP6_NF_MATCH_RT_MODULE 1
#define CONFIG_SERIAL_8250_RUNTIME_UARTS 4
#define CONFIG_KPROBES 1
#define CONFIG_FS_MBCACHE_MODULE 1
#define CONFIG_GFS2_FS_MODULE 1
#define CONFIG_MEDIA_TUNER_TUA9001_MODULE 1
#define CONFIG_RTC_CLASS 1
#define CONFIG_DVB_TUNER_DIB0070_MODULE 1
#define CONFIG_DRM_MGAG200_MODULE 1
#define CONFIG_SENSORS_LTC4215_MODULE 1
#define CONFIG_KVM_AMD_MODULE 1
#define CONFIG_NET_CLS_TCINDEX_MODULE 1
#define CONFIG_USB_EMI26_MODULE 1
#define CONFIG_IP_VS_PROTO_ESP 1
#define CONFIG_HAVE_LATENCYTOP_SUPPORT 1
#define CONFIG_MEDIA_TUNER_IT913X_MODULE 1
#define CONFIG_MWIFIEX_USB_MODULE 1
#define CONFIG_SAMSUNG_Q10_MODULE 1
#define CONFIG_TMPFS_XATTR 1
#define CONFIG_EDAC_I82975X_MODULE 1
#define CONFIG_NET_TEAM_MODULE 1
#define CONFIG_SND_RME96_MODULE 1
#define CONFIG_DCA_MODULE 1
#define CONFIG_CAN_KVASER_USB_MODULE 1
#define CONFIG_I2C_I801_MODULE 1
#define CONFIG_DLM_DEBUG 1
#define CONFIG_VIDEO_SAA7134_ALSA_MODULE 1
#define CONFIG_RT2800PCI_MODULE 1
#define CONFIG_USB_GSPCA_VC032X_MODULE 1
#define CONFIG_OPENVSWITCH_GRE_MODULE 1
#define CONFIG_IOMMU_HELPER 1
#define CONFIG_DVB_ISL6421_MODULE 1
#define CONFIG_RTC_DRV_DS1374_MODULE 1
#define CONFIG_MICROCODE_OLD_INTERFACE 1
#define CONFIG_RTC_DRV_BQ4802_MODULE 1
#define CONFIG_PATA_ACPI_MODULE 1
#define CONFIG_GENERIC_TRACER 1
#define CONFIG_NLS_ISO8859_5_MODULE 1
#define CONFIG_IP_VS_WLC_MODULE 1
#define CONFIG_FM10K_VXLAN 1
#define CONFIG_HAVE_FUNCTION_TRACER 1
#define CONFIG_NF_NAT_TFTP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MULTIPORT_MODULE 1
#define CONFIG_STACK_VALIDATION 1
#define CONFIG_NET_SCH_NETEM_MODULE 1
#define CONFIG_ACPI_PROCESSOR_AGGREGATOR_MODULE 1
#define CONFIG_USB_STORAGE_REALTEK_MODULE 1
#define CONFIG_CRYPTO_CAMELLIA_MODULE 1
#define CONFIG_SND_EMU10K1_SEQ_MODULE 1
#define CONFIG_RTC_DRV_DS1307_MODULE 1
#define CONFIG_ARCH_SELECT_MEMORY_MODEL 1
#define CONFIG_NFSD_V4 1
#define CONFIG_PMBUS_MODULE 1
#define CONFIG_EFI_MIXED 1
#define CONFIG_TCP_CONG_ILLINOIS_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_REDIRECT_MODULE 1
#define CONFIG_CRYPTO_MANAGER2 1
#define CONFIG_INFINIBAND_QIB_DCA 1
#define CONFIG_NET_VENDOR_MYRI 1
#define CONFIG_KEXEC_FILE 1
#define CONFIG_CLZ_TAB 1
#define CONFIG_BRIDGE_EBT_DNAT_MODULE 1
#define CONFIG_GENERIC_PCI_IOMAP 1
#define CONFIG_NETFILTER_XT_TARGET_LOG_MODULE 1
#define CONFIG_SLUB 1
#define CONFIG_SENSORS_AD7418_MODULE 1
#define CONFIG_CONFIGFS_FS 1
#define CONFIG_CRYPTO_TEST_MODULE 1
#define CONFIG_MTD_UBI_MODULE 1
#define CONFIG_XZ_DEC_BCJ 1
#define CONFIG_SLIP_MODULE 1
#define CONFIG_PM_SLEEP 1
#define CONFIG_SENSORS_FAM15H_POWER_MODULE 1
#define CONFIG_I2C_MODULE 1
#define CONFIG_COMPAL_LAPTOP_MODULE 1
#define CONFIG_EDAC_DECODE_MCE_MODULE 1
#define CONFIG_SENSORS_VT1211_MODULE 1
#define CONFIG_B44_PCI 1
#define CONFIG_PPP_MULTILINK 1
#define CONFIG_INFINIBAND_RDMAVT_MODULE 1
#define CONFIG_X86_UV 1
#define CONFIG_BINFMT_SCRIPT 1
#define CONFIG_HMM 1
#define CONFIG_EFI_STUB 1
#define CONFIG_SATA_PROMISE_MODULE 1
#define CONFIG_PARPORT_1284 1
#define CONFIG_MOUSE_PS2_CYPRESS 1
#define CONFIG_VIDEO_CX25840_MODULE 1
#define CONFIG_GENERIC_PENDING_IRQ 1
#define CONFIG_I2C_AMD756_S4882_MODULE 1
#define CONFIG_PARPORT_PC_MODULE 1
#define CONFIG_NET_TEAM_MODE_LOADBALANCE_MODULE 1
#define CONFIG_PPS_CLIENT_GPIO_MODULE 1
#define CONFIG_EARLY_PRINTK_DBGP 1
#define CONFIG_SCSI_SRP_ATTRS_MODULE 1
#define CONFIG_FRAME_POINTER 1
#define CONFIG_NET_IPGRE_BROADCAST 1
#define CONFIG_BT_HIDP_MODULE 1
#define CONFIG_VIDEO_CX231XX_RC 1
#define CONFIG_MOUSE_PS2_LOGIPS2PP 1
#define CONFIG_SND_PCXHR_MODULE 1
#define CONFIG_VM_EVENT_COUNTERS 1
#define CONFIG_MEDIA_COMMON_OPTIONS 1
#define CONFIG_RELAY 1
#define CONFIG_IWLDVM_MODULE 1
#define CONFIG_HAVE_MMIOTRACE_SUPPORT 1
#define CONFIG_ASUS_NB_WMI_MODULE 1
#define CONFIG_USB_GSPCA_FINEPIX_MODULE 1
#define CONFIG_HISAX_NETJET 1
#define CONFIG_CRYPTO_ECB 1
#define CONFIG_USB_GSPCA_ETOMS_MODULE 1
#define CONFIG_CRYPTO_SHA512_SSSE3_MODULE 1
#define CONFIG_WLAN_VENDOR_BROADCOM 1
#define CONFIG_PM_STD_PARTITION ""
#define CONFIG_SQUASHFS_LZO 1
#define CONFIG_SND_DYNAMIC_MINORS 1
#define CONFIG_FUJITSU_LAPTOP_MODULE 1
#define CONFIG_TCM_FILEIO_MODULE 1
#define CONFIG_GENERIC_FIND_FIRST_BIT 1
#define CONFIG_SCSI_STEX_MODULE 1
#define CONFIG_6LOWPAN_NHC_HOP_MODULE 1
#define CONFIG_BT_HCIUART_ATH3K 1
#define CONFIG_NF_CONNTRACK_AMANDA_MODULE 1
#define CONFIG_SND_ATIIXP_MODEM_MODULE 1
#define CONFIG_DEBUG_FS 1
#define CONFIG_ACPI_EXTLOG_MODULE 1
#define CONFIG_NET_PKTGEN_MODULE 1
#define CONFIG_HP_WMI_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_MODULE 1
#define CONFIG_DRM_TTM_MODULE 1
#define CONFIG_BASE_FULL 1
#define CONFIG_FB_CFB_IMAGEBLIT 1
#define CONFIG_ZLIB_DEFLATE_MODULE 1
#define CONFIG_NFT_REJECT_INET_MODULE 1
#define CONFIG_SUNRPC_MODULE 1
#define CONFIG_SOLARIS_X86_PARTITION 1
#define CONFIG_ARCH_DISCARD_MEMBLOCK 1
#define CONFIG_SCSI_DH_RDAC 1
#define CONFIG_SENSORS_W83795_MODULE 1
#define CONFIG_X86_P4_CLOCKMOD_MODULE 1
#define CONFIG_INPUT_ATI_REMOTE2_MODULE 1
#define CONFIG_CNIC_MODULE 1
#define CONFIG_OSF_PARTITION 1
#define CONFIG_NLS_CODEPAGE_864_MODULE 1
#define CONFIG_IWL3945_MODULE 1
#define CONFIG_IP_VS_LBLCR_MODULE 1
#define CONFIG_GPIO_SYSFS 1
#define CONFIG_HP_WIRELESS_MODULE 1
#define CONFIG_FW_LOADER 1
#define CONFIG_MODULE_SIG_SHA256 1
#define CONFIG_IP6_NF_NAT_MODULE 1
#define CONFIG_SENSORS_ADS7828_MODULE 1
#define CONFIG_KALLSYMS 1
#define CONFIG_COMMON_CLK 1
#define CONFIG_USB_GSPCA_SPCA501_MODULE 1
#define CONFIG_HOTPLUG_PCI_PCIE 1
#define CONFIG_PCI 1
#define CONFIG_RTC_HCTOSYS_DEVICE "rtc0"
#define CONFIG_CRYPTO_XTS_MODULE 1
#define CONFIG_SENSORS_ZL6100_MODULE 1
#define CONFIG_SND_SOC_RL6231_MODULE 1
#define CONFIG_PWM 1
#define CONFIG_NETFILTER_XT_MATCH_RECENT_MODULE 1
#define CONFIG_DECOMPRESS_XZ 1
#define CONFIG_BT_BCM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_PKTTYPE_MODULE 1
#define CONFIG_PCI_QUIRKS 1
#define CONFIG_INFINIBAND_USNIC_MODULE 1
#define CONFIG_MII_MODULE 1
#define CONFIG_SIGNALFD 1
#define CONFIG_NET_CORE 1
#define CONFIG_MOUSE_PS2_ALPS 1
#define CONFIG_HAVE_UNSTABLE_SCHED_CLOCK 1
#define CONFIG_EXT4_FS_MODULE 1
#define CONFIG_MAC80211_DEBUGFS 1
#define CONFIG_NET_SCH_DRR_MODULE 1
#define CONFIG_SENSORS_LTC4151_MODULE 1
#define CONFIG_BRIDGE_EBT_802_3_MODULE 1
#define CONFIG_MEMORY_BALLOON 1
#define CONFIG_UNINLINE_SPIN_UNLOCK 1
#define CONFIG_VIDEO_CX88_BLACKBIRD_MODULE 1
#define CONFIG_HAVE_HW_BREAKPOINT 1
#define CONFIG_ARCH_SUPPORTS_DEFERRED_STRUCT_PAGE_INIT 1
#define CONFIG_KRETPROBES 1
#define CONFIG_SND_JACK_INPUT_DEV 1
#define CONFIG_CRYPTO_SHA1 1
#define CONFIG_EDAC_MM_EDAC_MODULE 1
#define CONFIG_TRACK_DIRTY_PAGES 1
#define CONFIG_QUOTACTL_COMPAT 1
#define CONFIG_IPMI_WATCHDOG_MODULE 1
#define CONFIG_INFINIBAND_USER_ACCESS_MODULE 1
#define CONFIG_VMWARE_VMCI_MODULE 1
#define CONFIG_USB_ADUTUX_MODULE 1
#define CONFIG_KGDB_LOW_LEVEL_TRAP 1
#define CONFIG_CAN_C_CAN_PLATFORM_MODULE 1
#define CONFIG_ARCH_WANT_GENERAL_HUGETLB 1
#define CONFIG_SENSORS_SMSC47M192_MODULE 1
#define CONFIG_CRC8_MODULE 1
#define CONFIG_NLS_KOI8_U_MODULE 1
#define CONFIG_SENSORS_SCH5636_MODULE 1
#define CONFIG_XZ_DEC 1
#define CONFIG_USB_BELKIN 1
#define CONFIG_SATA_PMP 1
#define CONFIG_QLA3XXX_MODULE 1
#define CONFIG_CAN_VCAN_MODULE 1
#define CONFIG_ATH_COMMON_MODULE 1
#define CONFIG_NET_VENDOR_TI 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_DUMMY_MODULE 1
#define CONFIG_LEDS_LM3530_MODULE 1
#define CONFIG_DVB_TUNER_CX24113_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_T_MODULE 1
#define CONFIG_WATCHDOG 1
#define CONFIG_DVB_B2C2_FLEXCOP_PCI_MODULE 1
#define CONFIG_HAS_IOMEM 1
#define CONFIG_RING_BUFFER_ALLOW_SWAP 1
#define CONFIG_SND_RAWMIDI_MODULE 1
#define CONFIG_HOTPLUG_PCI_ACPI_IBM_MODULE 1
#define CONFIG_NF_LOG_IPV6_MODULE 1
#define CONFIG_DE4X5_MODULE 1
#define CONFIG_IEEE802154_SOCKET_MODULE 1
#define CONFIG_8139TOO_8129 1
#define CONFIG_SND_HDA_INPUT_BEEP_MODE 0
#define CONFIG_GPIO_DEVRES 1
#define CONFIG_IR_FINTEK_MODULE 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_FUSION_LOGGING 1
#define CONFIG_USB_NET_CDC_EEM_MODULE 1
#define CONFIG_USB_STORAGE_SDDR09_MODULE 1
#define CONFIG_SND_SCS1X_MODULE 1
#define CONFIG_HYPERV_STORAGE_MODULE 1
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#define CONFIG_ASYNC_RAID6_RECOV_MODULE 1
#define CONFIG_NET_CLS_IND 1
#define CONFIG_PATA_CS5536_MODULE 1
#define CONFIG_GART_IOMMU 1
#define CONFIG_PCI_MMCONFIG 1
#define CONFIG_NETFILTER_XT_TARGET_TRACE_MODULE 1
#define CONFIG_HVC_IRQ 1
#define CONFIG_ACPI_NFIT_MODULE 1
#define CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND 1
#define CONFIG_SND_RME32_MODULE 1
#define CONFIG_PROC_KCORE 1
#define CONFIG_RTC_DRV_X1205_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_1 1
#define CONFIG_LPC_ICH_MODULE 1
#define CONFIG_NUMA 1
#define CONFIG_IP6_NF_MATCH_FRAG_MODULE 1
#define CONFIG_USB_SERIAL_CYBERJACK_MODULE 1
#define CONFIG_NET_SCH_PRIO_MODULE 1
#define CONFIG_SCHED_HRTICK 1
#define CONFIG_SATA_ULI_MODULE 1
#define CONFIG_DVB_DRXK_MODULE 1
#define CONFIG_USB_SERIAL_IUU_MODULE 1
#define CONFIG_EPOLL 1
#define CONFIG_SCSI_AIC79XX_MODULE 1
#define CONFIG_CRYPTO_LZO 1
#define CONFIG_SND_PCM_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_AVX_X86_64_MODULE 1
#define CONFIG_TCM_USER2_MODULE 1
#define CONFIG_PM_RUNTIME 1
#define CONFIG_BRIDGE_EBT_SNAT_MODULE 1
#define CONFIG_SCSI_MVSAS_TASKLET 1
#define CONFIG_ARCH_HWEIGHT_CFLAGS "-fcall-saved-rdi -fcall-saved-rsi -fcall-saved-rdx -fcall-saved-rcx -fcall-saved-r8 -fcall-saved-r9 -fcall-saved-r10 -fcall-saved-r11"
#define CONFIG_SND_AU8820_MODULE 1
#define CONFIG_INFINIBAND_OCRDMA_MODULE 1
#define CONFIG_SDIO_UART_MODULE 1
#define CONFIG_PARTITION_ADVANCED 1
#define CONFIG_SENSORS_SCH56XX_COMMON_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DCCP_MODULE 1
#define CONFIG_ICPLUS_PHY_MODULE 1
#define CONFIG_CGROUP_HUGETLB 1
#define CONFIG_DEBUG_SECTION_MISMATCH 1
#define CONFIG_UNIXWARE_DISKLABEL 1
#define CONFIG_SCTP_DEFAULT_COOKIE_HMAC_SHA1 1
#define CONFIG_BT_BNEP_MC_FILTER 1
#define CONFIG_CRYPTO_CRC32_MODULE 1
#define CONFIG_SCSI_ISCSI_ATTRS_MODULE 1
#define CONFIG_HAVE_NET_DSA 1
#define CONFIG_USB_SERIAL_EMPEG_MODULE 1
#define CONFIG_IR_SONY_DECODER_MODULE 1
#define CONFIG_NLS_CODEPAGE_852_MODULE 1
#define CONFIG_TCG_TIS 1
#define CONFIG_VIDEO_PVRUSB2_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_COMMENT_MODULE 1
#define CONFIG_I2C_ISCH_MODULE 1
#define CONFIG_USB_NET_RNDIS_HOST_MODULE 1
#define CONFIG_NET 1
#define CONFIG_USB_OHCI_HCD_PCI 1
#define CONFIG_INPUT_EVDEV 1
#define CONFIG_CMPXCHG_LOCKREF 1
#define CONFIG_SND_JACK 1
#define CONFIG_IDEAPAD_LAPTOP_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TCPMSS_MODULE 1
#define CONFIG_BE2NET_VXLAN 1
#define CONFIG_ACPI_SLEEP 1
#define CONFIG_TABLET_USB_WACOM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DSCP_MODULE 1
#define CONFIG_CRYPTO_WP512_MODULE 1
#define CONFIG_CFAG12864B_RATE 20
#define CONFIG_HID_DRAGONRISE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNTRACK_MODULE 1
#define CONFIG_VIDEO_BT848_MODULE 1
#define CONFIG_BLOCK_COMPAT 1
#define CONFIG_ITCO_WDT_MODULE 1
#define CONFIG_IR_IGUANA_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_RATEEST_MODULE 1
#define CONFIG_SND_ALOOP_MODULE 1
#define CONFIG_USB_LD_MODULE 1
#define CONFIG_BOOTPARAM_HARDLOCKUP_PANIC 1
#define CONFIG_QUOTA_TREE 1
#define CONFIG_INPUT_PCSPKR_MODULE 1
#define CONFIG_PNFS_OBJLAYOUT_MODULE 1
#define CONFIG_HVC_XEN_FRONTEND 1
#define CONFIG_DVB_AV7110_OSD 1
#define CONFIG_MPILIB 1
#define CONFIG_USB_NET_CDCETHER_MODULE 1
#define CONFIG_PACKET 1
#define CONFIG_ARCH_BINFMT_ELF_RANDOMIZE_PIE 1
#define CONFIG_MODULE_SRCVERSION_ALL 1
#define CONFIG_FIREWIRE_SERIAL_MODULE 1
#define CONFIG_XFRM_ALGO 1
#define CONFIG_ARCH_HAS_CPU_AUTOPROBE 1
#define CONFIG_NF_CONNTRACK_TIMESTAMP 1
#define CONFIG_HAVE_CLK_PREPARE 1
#define CONFIG_VIDEO_CX88_MPEG_MODULE 1
#define CONFIG_CRYPTO_AKCIPHER2 1
#define CONFIG_NODES_SHIFT 10
#define CONFIG_MWIFIEX_SDIO_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPRANGE_MODULE 1
#define CONFIG_INTEL_IOATDMA_MODULE 1
#define CONFIG_NET_CLS_BASIC_MODULE 1
#define CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE 1
#define CONFIG_SND_HDA_GENERIC_MODULE 1
#define CONFIG_I2C_TINY_USB_MODULE 1
#define CONFIG_FUSION_SPI_MODULE 1
#define CONFIG_BTRFS_FS_POSIX_ACL 1
#define CONFIG_SND_HDA_CORE_MODULE 1
#define CONFIG_USB_GSPCA_OV534_MODULE 1
#define CONFIG_FRONTSWAP 1
#define CONFIG_DVB_USB_GL861_MODULE 1
#define CONFIG_IMA_APPRAISE 1
#define CONFIG_NF_CONNTRACK_TFTP_MODULE 1
#define CONFIG_NFS_V3_MODULE 1
#define CONFIG_DVB_USB_ANYSEE_MODULE 1
#define CONFIG_HISAX_HFC_SX 1
#define CONFIG_HAVE_KVM_IRQFD 1
#define CONFIG_NLS_CODEPAGE_949_MODULE 1
#define CONFIG_DVB_CX24110_MODULE 1
#define CONFIG_SENSORS_TMP102_MODULE 1
#define CONFIG_NOP_TRACER 1
#define CONFIG_BACKLIGHT_LCD_SUPPORT 1
#define CONFIG_LOOPBACK_TARGET_MODULE 1
#define CONFIG_ISL29020_MODULE 1
#define CONFIG_SND_HDA_PATCH_LOADER 1
#define CONFIG_XEN_XENBUS_FRONTEND 1
#define CONFIG_INET 1
#define CONFIG_CRYPTO_PCRYPT_MODULE 1
#define CONFIG_IP_ROUTE_VERBOSE 1
#define CONFIG_XZ_DEC_POWERPC 1
#define CONFIG_DVB_RTL2832_MODULE 1
#define CONFIG_VIRTIO_NET_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ADDRTYPE_MODULE 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_SERIAL_8250_PNP 1
#define CONFIG_USB_NET_MCS7830_MODULE 1
#define CONFIG_SND_ENS1371_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_MODULE 1
#define CONFIG_FREEZER 1
#define CONFIG_FIREWIRE_NET_MODULE 1
#define CONFIG_BT_MODULE 1
#define CONFIG_BT_HCIVHCI_MODULE 1
#define CONFIG_INPUT_CM109_MODULE 1
#define CONFIG_PCI_DOMAINS 1
#define CONFIG_EFI_VARS 1
#define CONFIG_NFT_QUEUE_MODULE 1
#define CONFIG_LCD_PLATFORM_MODULE 1
#define CONFIG_DVB_USB_MXL111SF_MODULE 1
#define CONFIG_SENSORS_IT87_MODULE 1
#define CONFIG_LPC_SCH_MODULE 1
#define CONFIG_NET_CLS_ACT 1
#define CONFIG_REED_SOLOMON_MODULE 1
#define CONFIG_CIFS_DFS_UPCALL 1
#define CONFIG_NET_VENDOR_CHELSIO 1
#define CONFIG_EFIVAR_FS 1
#define CONFIG_BRIDGE_EBT_BROUTE_MODULE 1
#define CONFIG_USB_NET_SMSC75XX_MODULE 1
#define CONFIG_BE2NET_MODULE 1
#define CONFIG_PARPORT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPVS_MODULE 1
#define CONFIG_VMWARE_VMCI_VSOCKETS_MODULE 1
#define CONFIG_X86_DEBUGCTLMSR 1
#define CONFIG_HEADERS_CHECK 1
#define CONFIG_HDLC_MODULE 1
#define CONFIG_NET_CLS_BPF_MODULE 1
#define CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN "kernel.org"
#define CONFIG_IP_SET_MAX 256
#define CONFIG_HID_WACOM_MODULE 1
#define CONFIG_QLCNIC_DCB 1
#define CONFIG_USB_SERIAL_CP210X_MODULE 1
#define CONFIG_HMM_MIRROR 1
#define CONFIG_NET_SCH_SFQ_MODULE 1
#define CONFIG_RTC_LIB 1
#define CONFIG_NVDIMM_DAX 1
#define CONFIG_X86_LOCAL_APIC 1
#define CONFIG_USB_UEAGLEATM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_POLICY_MODULE 1
#define CONFIG_MWL8K_MODULE 1
#define CONFIG_KGDB_TESTS 1
#define CONFIG_HAVE_KPROBES 1
#define CONFIG_NUMA_BALANCING_DEFAULT_ENABLED 1
#define CONFIG_IP_ROUTE_CLASSID 1
#define CONFIG_MOUSE_SYNAPTICS_I2C_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TEE_MODULE 1
#define CONFIG_SND_USB_VARIAX_MODULE 1
#define CONFIG_HPWDT_NMI_DECODING 1
#define CONFIG_USB_SERIAL_XSENS_MT_MODULE 1
#define CONFIG_VIDEO_CX88_MODULE 1
#define CONFIG_CRYPTO_AES 1
#define CONFIG_BACKLIGHT_LP855X_MODULE 1
#define CONFIG_DVB_DIB7000P_MODULE 1
#define CONFIG_GPIOLIB 1
#define CONFIG_SSB_MODULE 1
#define CONFIG_ZONE_DEVICE 1
#define CONFIG_I2C_STUB_MODULE 1
#define CONFIG_DM_BIO_PRISON_MODULE 1
#define CONFIG_VIDEO_EM28XX_RC_MODULE 1
#define CONFIG_NFT_LIMIT_MODULE 1
#define CONFIG_KEYS_COMPAT 1
#define CONFIG_USB_GSPCA_SPCA1528_MODULE 1
#define CONFIG_BUILD_DOCSRC 1
#define CONFIG_EXT4_USE_FOR_EXT23 1
#define CONFIG_HID_PID 1
#define CONFIG_NV_TCO_MODULE 1
#define CONFIG_USB_SERIAL_QT2_MODULE 1
#define CONFIG_SMSC9420_MODULE 1
#define CONFIG_SENSORS_MAX6639_MODULE 1
#define CONFIG_ISO9660_FS_MODULE 1
#define CONFIG_SKY2_MODULE 1
#define CONFIG_NETFILTER_XT_NAT_MODULE 1
#define CONFIG_BT_HCIUART_H4 1
#define CONFIG_RTC_DRV_DS3232_MODULE 1
#define CONFIG_SND_PCM_ELD 1
#define CONFIG_XEN_WDT_MODULE 1
#define CONFIG_DVB_USB_M920X_MODULE 1
#define CONFIG_UIO_MODULE 1
#define CONFIG_HID_WALTOP_MODULE 1
#define CONFIG_SCSI_VIRTIO_MODULE 1
#define CONFIG_NF_CONNTRACK_MARK 1
#define CONFIG_HVC_DRIVER 1
#define CONFIG_BLK_DEV_PCIESSD_MTIP32XX_MODULE 1
#define CONFIG_NETFILTER 1
#define CONFIG_NFT_REJECT_IPV4_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_T1PCI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HASHLIMIT_MODULE 1
#define CONFIG_MODULE_SIG 1
#define CONFIG_BRIDGE_EBT_AMONG_MODULE 1
#define CONFIG_ATH9K_WOW 1
#define CONFIG_X86_DEV_DMA_OPS 1
#define CONFIG_X86_MSR 1
#define CONFIG_NET_VENDOR_SMSC 1
#define CONFIG_NETFILTER_NETLINK_ACCT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CLUSTER_MODULE 1
#define CONFIG_USB_KC2190 1
#define CONFIG_USE_GENERIC_SMP_HELPERS 1
#define CONFIG_USB_MDC800_MODULE 1
#define CONFIG_6LOWPAN_MODULE 1
#define CONFIG_HWMON_VID_MODULE 1
#define CONFIG_SERIO_SERPORT 1
#define CONFIG_FB_BOOT_VESA_SUPPORT 1
#define CONFIG_ISDN_PPP_VJ 1
#define CONFIG_NLS_CODEPAGE_950_MODULE 1
#define CONFIG_DVB_STV0297_MODULE 1
#define CONFIG_DVB_TTUSB_DEC_MODULE 1
#define CONFIG_LEDS_TRIGGER_ONESHOT_MODULE 1
#define CONFIG_HT_IRQ 1
#define CONFIG_LIRC_MODULE 1
#define CONFIG_BT_BNEP_MODULE 1
#define CONFIG_NET_SCH_QFQ_MODULE 1
#define CONFIG_DVB_TDA826X_MODULE 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_IXGBEVF_MODULE 1
#define CONFIG_SND_AC97_POWER_SAVE_DEFAULT 5
#define CONFIG_DVB_NGENE_MODULE 1
#define CONFIG_RD_XZ 1
#define CONFIG_IP_MROUTE 1
#define CONFIG_INET_XFRM_MODE_TUNNEL_MODULE 1
#define CONFIG_X86_SMAP 1
#define CONFIG_VGA_CONSOLE 1
#define CONFIG_NF_NAT_NEEDED 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS 1
#define CONFIG_USB_SERIAL_SAFE_PADDED 1
#define CONFIG_HID_RMI_MODULE 1
#define CONFIG_ATA_VERBOSE_ERROR 1
#define CONFIG_XEN_BLKDEV_FRONTEND_MODULE 1
#define CONFIG_NF_CONNTRACK_SNMP_MODULE 1
#define CONFIG_SND_DRIVERS 1
#define CONFIG_HISAX_S0BOX 1
#define CONFIG_USB_SERIAL_BELKIN_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2266_MODULE 1
#define CONFIG_NLS_MAC_GREEK_MODULE 1
#define CONFIG_XFS_FS_MODULE 1
#define CONFIG_SENSORS_DME1737_MODULE 1
#define CONFIG_INPUT_KEYSPAN_REMOTE_MODULE 1
#define CONFIG_USB_GSPCA_PAC7302_MODULE 1
#define CONFIG_LOCKDEP_SUPPORT 1
#define CONFIG_X86_MCE_INJECT_MODULE 1
#define CONFIG_TOUCHSCREEN_ELO_MODULE 1
#define CONFIG_NLS_CODEPAGE_869_MODULE 1
#define CONFIG_SND_FIREWIRE_SPEAKERS_MODULE 1
#define CONFIG_CRASH 1
#define CONFIG_SND_AC97_POWER_SAVE 1
#define CONFIG_IP6_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_PCH_DMA_MODULE 1
#define CONFIG_NFT_REDIR_MODULE 1
#define CONFIG_SATA_VIA_MODULE 1
#define CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION 1
#define CONFIG_NO_HZ 1
#define CONFIG_ARCH_WANT_HUGE_PMD_SHARE 1
#define CONFIG_POSIX_MQUEUE 1
#define CONFIG_NOUVEAU_DEBUG 5
#define CONFIG_SND_SOC_TOPOLOGY 1
#define CONFIG_SENSORS_LM83_MODULE 1
#define CONFIG_USB_NET_CDC_MBIM_MODULE 1
#define CONFIG_PSTORE_RAM_MODULE 1
#define CONFIG_LEDS_BLINKM_MODULE 1
#define CONFIG_CPU_FREQ_STAT_MODULE 1
#define CONFIG_ISCSI_IBFT_MODULE 1
#define CONFIG_TIFM_CORE_MODULE 1
#define CONFIG_XEN_PRIVCMD_MODULE 1
#define CONFIG_FUSION_SAS_MODULE 1
#define CONFIG_GENERIC_STRNCPY_FROM_USER 1
#define CONFIG_CHR_DEV_OSST_MODULE 1
#define CONFIG_MTD_BLKDEVS_MODULE 1
#define CONFIG_DVB_TDA10086_MODULE 1
#define CONFIG_MEMSTICK_R592_MODULE 1
#define CONFIG_NET_SCH_MQPRIO_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NETMAP_MODULE 1
#define CONFIG_MLX5_CORE_EN_DCB 1
#define CONFIG_APDS9802ALS_MODULE 1
#define CONFIG_DVB_NXT6000_MODULE 1
#define CONFIG_MANTIS_CORE_MODULE 1
#define CONFIG_PATA_MARVELL_MODULE 1
#define CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_SCTP_MODULE 1
#define CONFIG_SATA_SIL24_MODULE 1
#define CONFIG_SMS_SIANO_RC 1
#define CONFIG_NET_VENDOR_DEC 1
#define CONFIG_NLS_ISO8859_15_MODULE 1
#define CONFIG_SENSORS_VIA686A_MODULE 1
#define CONFIG_INET6_ESP_MODULE 1
#define CONFIG_IP_VS_WRR_MODULE 1
#define CONFIG_AUTOFS4_FS 1
#define CONFIG_NETLINK_MMAP 1
#define CONFIG_VIDEO_FB_IVTV_MODULE 1
#define CONFIG_ACPI_BUTTON 1
#define CONFIG_ILLEGAL_POINTER_VALUE 0xdead000000000000
#define CONFIG_NETFILTER_XT_SET_MODULE 1
#define CONFIG_NLS_MAC_CROATIAN_MODULE 1
#define CONFIG_SFC_MTD 1
#define CONFIG_SND_SOC_MAX98090_MODULE 1
#define CONFIG_TASKSTATS 1
#define CONFIG_NLS_CODEPAGE_932_MODULE 1
#define CONFIG_PTP_1588_CLOCK_PCH_MODULE 1
#define CONFIG_RT2X00_LIB_MMIO_MODULE 1
#define CONFIG_CRYPTO_CRC32C_INTEL_MODULE 1
#define CONFIG_NLS_MAC_ICELAND_MODULE 1
#define CONFIG_MEDIA_SUBDRV_AUTOSELECT 1
#define CONFIG_CAN_PLX_PCI_MODULE 1
#define CONFIG_SND_SOC_INTEL_BYTCR_RT5651_MACH_MODULE 1
#define CONFIG_IP6_NF_FILTER_MODULE 1
#define CONFIG_INPUT_MOUSEDEV_SCREEN_X 1024
#define CONFIG_NEED_DMA_MAP_STATE 1
#define CONFIG_SND_HDA_MODULE 1
#define CONFIG_SND_HDA_PREALLOC_SIZE 512
#define CONFIG_GARP_MODULE 1
#define CONFIG_YENTA_ENE_TUNE 1
#define CONFIG_MOUSE_PS2_LIFEBOOK 1
#define CONFIG_SERIO_LIBPS2 1
#define CONFIG_IP_VS_PROTO_TCP 1
#define CONFIG_ISCSI_BOOT_SYSFS_MODULE 1
#define CONFIG_X86_CPUID 1
#define CONFIG_CRYPTO_DEV_QAT_C3XXXVF_MODULE 1
#define CONFIG_NET_SCH_RED_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_NFACCT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNBYTES_MODULE 1
#define CONFIG_KDB_CONTINUE_CATASTROPHIC 0
#define CONFIG_USB_PRINTER_MODULE 1
#define CONFIG_HISAX_DIEHLDIVA 1
#define CONFIG_FONT_8x8 1
#define CONFIG_SSB_SPROM 1
#define CONFIG_USB_GSPCA_PAC207_MODULE 1
#define CONFIG_NET_VENDOR_ATHEROS 1
#define CONFIG_USB_SERIAL_IR_MODULE 1
#define CONFIG_SKGE_MODULE 1
#define CONFIG_HMC_DRV_MODULE 1
#define CONFIG_TCM_PSCSI_MODULE 1
#define CONFIG_RELOCATABLE 1
#define CONFIG_XOR_BLOCKS_MODULE 1
#define CONFIG_HID_TWINHAN_MODULE 1
#define CONFIG_SENSORS_NTC_THERMISTOR_MODULE 1
#define CONFIG_MISDN_L1OIP_MODULE 1
#define CONFIG_DVB_PT1_MODULE 1
#define CONFIG_DMIID 1
#define CONFIG_PANIC_TIMEOUT 0
#define CONFIG_ASUS_WMI_MODULE 1
#define CONFIG_SENSORS_DS1621_MODULE 1
#define CONFIG_QUOTA_NETLINK_INTERFACE 1
#define CONFIG_NET_ACT_SIMP_MODULE 1
#define CONFIG_RT2X00_LIB_MODULE 1
#define CONFIG_HID_BATTERY_STRENGTH 1
#define CONFIG_DM_VERITY_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ECN_MODULE 1
#define CONFIG_USB_GSPCA_STV0680_MODULE 1
#define CONFIG_ATH9K_PCOEM 1
#define CONFIG_USB_STORAGE_SDDR55_MODULE 1
#define CONFIG_PPDEV_MODULE 1
#define CONFIG_IP_NF_TARGET_TTL_MODULE 1
#define CONFIG_AMILO_RFKILL_MODULE 1
#define CONFIG_NF_NAT_MASQUERADE_IPV4_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_B1PCI_MODULE 1
#define CONFIG_CFG80211_DEFAULT_PS 1
#define CONFIG_NFT_META_MODULE 1
#define CONFIG_USB_LED_MODULE 1
#define CONFIG_BUILD_BIN2C 1
#define CONFIG_GENERIC_IOMAP 1
#define CONFIG_IEEE802154_FAKELB_MODULE 1
#define CONFIG_TOUCHSCREEN_WACOM_W8001_MODULE 1
#define CONFIG_DVB_PLUTO2_MODULE 1
#define CONFIG_KEXEC_AUTO_RESERVE 1
#define CONFIG_RTL8723AE_MODULE 1
#define CONFIG_SPARSEMEM_MANUAL 1
#define CONFIG_DVB_AV7110_MODULE 1
#define CONFIG_DMI_SCAN_MACHINE_NON_EFI_FALLBACK 1
#define CONFIG_DVB_OR51132_MODULE 1
#define CONFIG_RT2X00_LIB_FIRMWARE 1
#define CONFIG_SMP 1
#define CONFIG_DVB_ZL10353_MODULE 1
#define CONFIG_MFD_INTEL_LPSS_ACPI 1
#define CONFIG_NETFILTER_XT_MATCH_TIME_MODULE 1
#define CONFIG_TTY 1
#define CONFIG_IP_VS_MODULE 1
#define CONFIG_HAVE_KERNEL_GZIP 1
#define CONFIG_ZSMALLOC 1
#define CONFIG_DM_UEVENT 1
#define CONFIG_CAN_ESD_USB2_MODULE 1
#define CONFIG_HMM_MIGRATE 1
#define CONFIG_USB_XUSBATM_MODULE 1
#define CONFIG_PNP 1
#define CONFIG_RTC_DRV_RP5C01_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MAC_MODULE 1
#define CONFIG_I2C_NFORCE2_S4985_MODULE 1
#define CONFIG_SENSORS_NCT6775_MODULE 1
#define CONFIG_NET_ACT_PEDIT_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFLOG_MODULE 1
#define CONFIG_GENERIC_ALLOCATOR 1
#define CONFIG_OPENVSWITCH_MODULE 1
#define CONFIG_L2TP_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_USB_MODULE 1
#define CONFIG_TCP_CONG_WESTWOOD_MODULE 1
#define CONFIG_KALLSYMS_ALL 1
#define CONFIG_HID_AUREAL_MODULE 1
#define CONFIG_USB_GSPCA_SPCA561_MODULE 1
#define CONFIG_IPMI_SSIF_MODULE 1
#define CONFIG_X86_DECODER_SELFTEST 1
#define CONFIG_DRM_GMA600 1
#define CONFIG_GENERIC_IO 1
#define CONFIG_LIBCRC32C_MODULE 1
#define CONFIG_HAVE_BOOTMEM_INFO_NODE 1
#define CONFIG_GENERIC_BUG 1
#define CONFIG_CRYPTO_SHA256 1
#define CONFIG_HAVE_FTRACE_MCOUNT_RECORD 1
#define CONFIG_BRIDGE_VLAN_FILTERING 1
#define CONFIG_VIDEO_AU0828_MODULE 1
#define CONFIG_INET_TCP_DIAG_MODULE 1
#define CONFIG_HID_SONY_MODULE 1
#define CONFIG_VIDEO_PVRUSB2_DVB 1
#define CONFIG_MEMSTICK_REALTEK_PCI_MODULE 1
#define CONFIG_PCI_PASID 1
#define CONFIG_CRYPTO_BLOWFISH_X86_64_MODULE 1
#define CONFIG_HW_CONSOLE 1
#define CONFIG_MDIO_BITBANG_MODULE 1
#define CONFIG_NET_ACT_IPT_MODULE 1
#define CONFIG_HAVE_KVM_IRQ_ROUTING 1
#define CONFIG_DM_DEBUG 1
#define CONFIG_SCSI_BNX2X_FCOE_MODULE 1
#define CONFIG_RAS 1
#define CONFIG_HYPERV_NET_MODULE 1
#define CONFIG_SMSC_PHY_MODULE 1
#define CONFIG_HP_ACCEL_MODULE 1
#define CONFIG_CAN_EMS_PCI_MODULE 1
#define CONFIG_SCSI_BNX2_ISCSI_MODULE 1
#define CONFIG_TCG_TIS_I2C_NUVOTON_MODULE 1
#define CONFIG_USB_GSPCA_ZC3XX_MODULE 1
#define CONFIG_SND_ES1968_MODULE 1
#define CONFIG_MLX5_CORE_MODULE 1
#define CONFIG_NFT_LOG_MODULE 1
#define CONFIG_BRIDGE_EBT_IP_MODULE 1
#define CONFIG_HID_MONTEREY 1
#define CONFIG_USB_SERIAL_CYPRESS_M8_MODULE 1
#define CONFIG_HID_EZKEY 1
#define CONFIG_PADATA 1
#define CONFIG_IOSCHED_NOOP 1
#define CONFIG_DVB_S5H1409_MODULE 1
#define CONFIG_DM_THIN_PROVISIONING_MODULE 1
#define CONFIG_HAVE_UID16 1
#define CONFIG_SERIAL_NONSTANDARD 1
#define CONFIG_RT61PCI_MODULE 1
#define CONFIG_COMPAT_OLD_SIGACTION 1
#define CONFIG_PATA_JMICRON_MODULE 1
#define CONFIG_SCSI_OSD_ULD_MODULE 1
#define CONFIG_BT_MRVL_MODULE 1
#define CONFIG_QUOTACTL 1
#define CONFIG_RTC_DRV_RX8581_MODULE 1
#define CONFIG_PARAVIRT 1
#define CONFIG_ISDN_CAPI_CAPI20_MODULE 1
#define CONFIG_CRYPTO_CRYPTD_MODULE 1
#define CONFIG_SPARSEMEM_ALLOC_MEM_MAP_TOGETHER 1
#define CONFIG_HAVE_IOREMAP_PROT 1
#define CONFIG_GENERIC_ACL 1
#define CONFIG_DEBUG_KERNEL 1
#define CONFIG_RTL8192DE_MODULE 1
#define CONFIG_ACPI_TOSHIBA_MODULE 1
#define CONFIG_VIDEO_CX2341X_MODULE 1
#define CONFIG_I2C_VIPERBOARD_MODULE 1
#define CONFIG_LOCALVERSION ""
#define CONFIG_DVB_STV6110x_MODULE 1
#define CONFIG_PATA_IT821X_MODULE 1
#define CONFIG_ACERHDF_MODULE 1
#define CONFIG_HAVE_PCSPKR_PLATFORM 1
#define CONFIG_NFS_FSCACHE 1
#define CONFIG_ARCH_HAS_DEBUG_STRICT_USER_COPY_CHECKS 1
#define CONFIG_USB_GSPCA_TOPRO_MODULE 1
#define CONFIG_USB_GSPCA_MARS_MODULE 1
#define CONFIG_CAN_RAW_MODULE 1
#define CONFIG_CRYPTO 1
#define CONFIG_FUNCTION_TRACER 1
#define CONFIG_SENSORS_EMC6W201_MODULE 1
#define CONFIG_SCHED_DEBUG 1
#define CONFIG_NFT_CHAIN_NAT_IPV4_MODULE 1
#define CONFIG_USB_STKWEBCAM_MODULE 1
#define CONFIG_NET_VENDOR_BROCADE 1
#define CONFIG_BTRFS_FS_MODULE 1
#define CONFIG_DEFAULT_MMAP_MIN_ADDR 4096
#define CONFIG_SND_USB_6FIRE_MODULE 1
#define CONFIG_SND_HDA_HWDEP 1
#define CONFIG_I2C_SIS96X_MODULE 1
#define CONFIG_MMC_TIFM_SD_MODULE 1
#define CONFIG_GFS2_FS_LOCKING_DLM 1
#define CONFIG_MEDIA_TUNER_TDA18218_MODULE 1
#define CONFIG_IP_NF_IPTABLES_MODULE 1
#define CONFIG_HISAX_HFC4S8S_MODULE 1
#define CONFIG_VSOCKETS_MODULE 1
#define CONFIG_BT_BNEP_PROTO_FILTER 1
#define CONFIG_DYNAMIC_FTRACE_WITH_REGS 1
#define CONFIG_IWLWIFI_LEDS 1
#define CONFIG_NET_VENDOR_QLOGIC 1
#define CONFIG_USB_GSPCA_CPIA1_MODULE 1
#define CONFIG_USB_XHCI_HCD 1
#define CONFIG_VIRTIO_MODULE 1
#define CONFIG_HAVE_DMA_API_DEBUG 1
#define CONFIG_HISAX_16_3 1
#define CONFIG_DEFAULT_CUBIC 1
#define CONFIG_CAN_KVASER_PCI_MODULE 1
#define CONFIG_YENTA_TI 1
#define CONFIG_MFD_SM501_MODULE 1
#define CONFIG_HID_SAMSUNG_MODULE 1
#define CONFIG_SFC_MCDI_LOGGING 1
#define CONFIG_IP_SET_LIST_SET_MODULE 1
#define CONFIG_TCM_IBLOCK_MODULE 1
#define CONFIG_IP_PIMSM_V2 1
#define CONFIG_CFS_BANDWIDTH 1
#define CONFIG_SND_HDA_CODEC_CA0132_DSP 1
#define CONFIG_XFRM_STATISTICS 1
#define CONFIG_X86_MCE_THRESHOLD 1
#define CONFIG_USB_ISIGHTFW_MODULE 1
#define CONFIG_JME_MODULE 1
#define CONFIG_SND_HDA_CODEC_CMEDIA_MODULE 1
#define CONFIG_DMA_VIRTUAL_CHANNELS_MODULE 1
#define CONFIG_YENTA_O2 1
#define CONFIG_SND_SEQ_HRTIMER_DEFAULT 1
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_NFT_CHAIN_ROUTE_IPV6_MODULE 1
#define CONFIG_DVB_DIB3000MC_MODULE 1
#define CONFIG_STRICT_DEVMEM 1
#define CONFIG_CACHEFILES_MODULE 1
#define CONFIG_PATA_OLDPIIX_MODULE 1
#define CONFIG_GENERIC_IRQ_SHOW 1
#define CONFIG_SND_HDA_CODEC_SI3054_MODULE 1
#define CONFIG_NET_CALXEDA_XGMAC_MODULE 1
#define CONFIG_IPV6_OPTIMISTIC_DAD 1
#define CONFIG_MD_AUTODETECT 1
#define CONFIG_PANIC_ON_OOPS_VALUE 1
#define CONFIG_SENSORS_ATK0110_MODULE 1
#define CONFIG_SFC_SRIOV 1
#define CONFIG_TCP_CONG_HSTCP_MODULE 1
#define CONFIG_SCSI_MOD 1
#define CONFIG_SCSI_SMARTPQI_MODULE 1
#define CONFIG_AUDIT_TREE 1
#define CONFIG_GIGASET_M105_MODULE 1
#define CONFIG_HISAX_HFC_PCI 1
#define CONFIG_USB_SERIAL_SPCP8X5_MODULE 1
#define CONFIG_RC_DECODERS 1
#define CONFIG_USB_NET_HUAWEI_CDC_NCM_MODULE 1
#define CONFIG_OPROFILE_MODULE 1
#define CONFIG_CRYPTO_CRC32C 1
#define CONFIG_SERIAL_CORE 1
#define CONFIG_FUSE_FS_MODULE 1
#define CONFIG_BUILDTIME_EXTABLE_SORT 1
#define CONFIG_UID16 1
#define CONFIG_DW_DMAC_MODULE 1
#define CONFIG_ETHOC_MODULE 1
#define CONFIG_ACPI_HED 1
#define CONFIG_HID_MICROSOFT 1
#define CONFIG_RTLLIB_MODULE 1
#define CONFIG_ARCH_PHYS_ADDR_T_64BIT 1
#define CONFIG_HAVE_KRETPROBES 1
#define CONFIG_HYPERV_BALLOON_MODULE 1
#define CONFIG_SENSORS_LM25066_MODULE 1
#define CONFIG_ASSOCIATIVE_ARRAY 1
#define CONFIG_HSA_AMD_MODULE 1
#define CONFIG_AGP_VIA 1
#define CONFIG_NF_DEFRAG_IPV6_MODULE 1
#define CONFIG_USB_GSPCA_CONEX_MODULE 1
#define CONFIG_MICREL_PHY_MODULE 1
#define CONFIG_DRM_LOAD_EDID_FIRMWARE 1
#define CONFIG_VIDEO_DEV_MODULE 1
#define CONFIG_KS0108_MODULE 1
#define CONFIG_SGI_IOC4_MODULE 1
#define CONFIG_NFS_V4_MODULE 1
#define CONFIG_PPP_FILTER 1
#define CONFIG_DYNAMIC_FTRACE 1
#define CONFIG_INLINE_READ_UNLOCK 1
#define CONFIG_PATA_PDC2027X_MODULE 1
#define CONFIG_SENSORS_LTC2978_MODULE 1
#define CONFIG_HAS_DMA 1
#define CONFIG_INTEL_IPS_MODULE 1
#define CONFIG_EDAC 1
#define CONFIG_NF_CT_PROTO_SCTP_MODULE 1
#define CONFIG_USB_SERIAL_VISOR_MODULE 1
#define CONFIG_BROADCOM_PHY_MODULE 1
#define CONFIG_DEBUG_BOOT_PARAMS 1
#define CONFIG_IO_DELAY_TYPE_NONE 3
#define CONFIG_SCSI 1
#define CONFIG_FB_CFB_FILLRECT 1
#define CONFIG_RT2800_LIB_MMIO_MODULE 1
#define CONFIG_HYPERV_MODULE 1
#define CONFIG_FUNCTION_GRAPH_TRACER 1
#define CONFIG_NF_NAT_PPTP_MODULE 1
#define CONFIG_HID_CHICONY 1
#define CONFIG_NLS_MAC_ROMAN_MODULE 1
#define CONFIG_HID 1
#define CONFIG_HW_RANDOM_AMD_MODULE 1
#define CONFIG_SND_SST_IPC_MODULE 1
#define CONFIG_SLIP_SMART 1
#define CONFIG_NLS_ISO8859_9_MODULE 1
#define CONFIG_AMD_IOMMU_V2_MODULE 1
#define CONFIG_USB_ARMLINUX 1
#define CONFIG_I2C_SMBUS_MODULE 1
#define CONFIG_IP_VS_PE_SIP_MODULE 1
#define CONFIG_RTLWIFI_MODULE 1
#define CONFIG_TCG_TIS_ST33ZP24_MODULE 1
#define CONFIG_CLKDEV_LOOKUP 1
#define CONFIG_LEDS_TRIGGER_DEFAULT_ON_MODULE 1
#define CONFIG_MXM_WMI_MODULE 1
#define CONFIG_FONT_8x16 1
#define CONFIG_NET_VENDOR_MELLANOX 1
#define CONFIG_DVB_LGDT330X_MODULE 1
#define CONFIG_SERIAL_8250_MANY_PORTS 1
#define CONFIG_VT_CONSOLE_SLEEP 1
#define CONFIG_LIBFC_MODULE 1
#define CONFIG_X86_MCE_INTEL 1
#define CONFIG_X86_64 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG 1
#define CONFIG_RTC_DRV_CMOS 1
#define CONFIG_PTP_1588_CLOCK_MODULE 1
#define CONFIG_IEEE802154_DRIVERS_MODULE 1
#define CONFIG_PATA_AMD_MODULE 1
#define CONFIG_USB_PWC_MODULE 1
#define CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE 3
#define CONFIG_SENSORS_AD7414_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA8290_MODULE 1
#define CONFIG_RT2800PCI_RT53XX 1
#define CONFIG_BONDING_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA18212_MODULE 1
#define CONFIG_RTC_DRV_EM3027_MODULE 1
#define CONFIG_ARCH_HAS_CACHE_LINE_SIZE 1
#define CONFIG_6LOWPAN_NHC_DEST_MODULE 1
#define CONFIG_ARM_AT91_ETHER_MODULE 1
#define CONFIG_VIDEO_SAA7134_RC 1
#define CONFIG_JBD2_MODULE 1
#define CONFIG_SENSORS_ASB100_MODULE 1
#define CONFIG_SND_INTEL8X0_MODULE 1
#define CONFIG_ATM_BR2684_MODULE 1
#define CONFIG_SPARSEMEM_VMEMMAP 1
#define CONFIG_CRYPTO_CAMELLIA_X86_64_MODULE 1
#define CONFIG_IB700_WDT_MODULE 1
#define CONFIG_MMC_USHC_MODULE 1
#define CONFIG_INET6_IPCOMP_MODULE 1
#define CONFIG_SONY_LAPTOP_MODULE 1
#define CONFIG_QLCNIC_MODULE 1
#define CONFIG_MEMCG_KMEM 1
#define CONFIG_HISAX_W6692 1
#define CONFIG_NET_VENDOR_MARVELL 1
#define CONFIG_PHYLIB 1
#define CONFIG_IGB_DCA 1
#define CONFIG_CRYPTO_SHA1_SSSE3 1
#define CONFIG_IPV6_TUNNEL_MODULE 1
#define CONFIG_SENSORS_LM77_MODULE 1
#define CONFIG_ARCH_MEMORY_PROBE 1
#define CONFIG_X86_AMD_FREQ_SENSITIVITY_MODULE 1
#define CONFIG_DVB_TDA665x_MODULE 1
#define CONFIG_VIDEO_SAA7164_MODULE 1
#define CONFIG_NLS_CODEPAGE_874_MODULE 1
#define CONFIG_GIGASET_CAPI 1
#define CONFIG_OPTIMIZE_INLINING 1
#define CONFIG_IRQ_DOMAIN 1
#define CONFIG_VIRTIO_BALLOON_MODULE 1
#define CONFIG_IMA 1
#define CONFIG_LSM_MMAP_MIN_ADDR 65535
#define CONFIG_SCSI_ARCMSR_MODULE 1
#define CONFIG_NET_DMA_RH_KABI 1
#define CONFIG_PVPANIC 1
#define CONFIG_CAN_PEAK_PCI_MODULE 1
#define CONFIG_PPS_CLIENT_LDISC_MODULE 1
#define CONFIG_MEDIA_TUNER_MT20XX_MODULE 1
#define CONFIG_NET_TULIP 1
#define CONFIG_IPC_NS 1
#define CONFIG_CRYPTO_GLUE_HELPER_X86_MODULE 1
#define CONFIG_HISAX_FRITZ_PCIPNP_MODULE 1
#define CONFIG_MISC_FILESYSTEMS 1
#define CONFIG_FTRACE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLIMIT_MODULE 1
#define CONFIG_X86_THERMAL_VECTOR 1
#define CONFIG_IP_NF_SECURITY_MODULE 1
#define CONFIG_IP_NF_RAW_MODULE 1
#define CONFIG_HAVE_CC_STACKPROTECTOR 1
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_SOCKET_MODULE 1
#define CONFIG_PPPOL2TP_MODULE 1
#define CONFIG_SYNCLINK_MODULE 1
#define CONFIG_R8712U_MODULE 1
#define CONFIG_HID_TOPSEED_MODULE 1
#define CONFIG_HISAX_MAX_CARDS 8
#define CONFIG_DECOMPRESS_BZIP2 1
#define CONFIG_RT2800PCI_RT33XX 1
#define CONFIG_CORDIC_MODULE 1
#define CONFIG_ATH9K_RFKILL 1
#define CONFIG_SENSORS_ADM1029_MODULE 1
#define CONFIG_KSM 1
#define CONFIG_GENERIC_PAGE_TABLE 1
#define CONFIG_ARCH_SUPPORTS_UPROBES 1
#define CONFIG_EDAC_I3000_MODULE 1
#define CONFIG_TOPSTAR_LAPTOP_MODULE 1
#define CONFIG_AGP_SIS 1
#define CONFIG_NF_NAT_H323_MODULE 1
#define CONFIG_IMA_LSM_RULES 1
#define CONFIG_SND_SOC_INTEL_SKYLAKE_MODULE 1
#define CONFIG_ARCH_SPARSEMEM_DEFAULT 1
#define CONFIG_USB_NET_QMI_WWAN_MODULE 1
#define CONFIG_NET_TEAM_MODE_ROUNDROBIN_MODULE 1
#define CONFIG_EDAC_IE31200_MODULE 1
#define CONFIG_IR_ENE_MODULE 1
#define CONFIG_ALIM1535_WDT_MODULE 1
#define CONFIG_GIGASET_BASE_MODULE 1
#define CONFIG_INLINE_READ_UNLOCK_IRQ 1
#define CONFIG_HID_HYPERV_MOUSE_MODULE 1
#define CONFIG_GACT_PROB 1
#define CONFIG_MISDN_ISAR_MODULE 1
#define CONFIG_REALTEK_PHY_MODULE 1
#define CONFIG_PROC_VMCORE 1
#define CONFIG_HID_A4TECH 1
#define CONFIG_MEDIA_TUNER_MC44S803_MODULE 1
#define CONFIG_NLS_CODEPAGE_860_MODULE 1
#define CONFIG_SND_MONA_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ESP_MODULE 1
#define CONFIG_PRINT_QUOTA_WARNING 1
#define CONFIG_ACPI_PROCFS 1
#define CONFIG_MOUSE_PS2_VMMOUSE 1
#define CONFIG_IP_NF_TARGET_NETMAP_MODULE 1
#define CONFIG_DST_CACHE 1
#define CONFIG_USB_GSPCA_SPCA505_MODULE 1
#define CONFIG_NF_REJECT_IPV6_MODULE 1
#define CONFIG_RCU_CPU_STALL_TIMEOUT 60
#define CONFIG_USB_GSPCA_SQ905C_MODULE 1
#define CONFIG_SATA_VITESSE_MODULE 1
#define CONFIG_USB_ZR364XX_MODULE 1
#define CONFIG_CHECKPOINT_RESTORE 1
#define CONFIG_PRINTER_MODULE 1
#define CONFIG_RTC_DRV_ISL1208_MODULE 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#define CONFIG_SND_FIREWIRE_LIB_MODULE 1
#define CONFIG_INT340X_THERMAL_MODULE 1
#define CONFIG_IP_ROUTE_MULTIPATH 1
#define CONFIG_DVB_LNBP21_MODULE 1
#define CONFIG_XEN_NETDEV_FRONTEND_MODULE 1
#define CONFIG_DVB_TDA10048_MODULE 1
#define CONFIG_INPUT_FF_MEMLESS_MODULE 1
#define CONFIG_PARAVIRT_CLOCK 1
#define CONFIG_SENSORS_W83627HF_MODULE 1
#define CONFIG_CHR_DEV_SG_MODULE 1
#define CONFIG_IP_SET_HASH_NET_MODULE 1
#define CONFIG_NET_SCH_DSMARK_MODULE 1
#define CONFIG_SND_AD1889_MODULE 1
#define CONFIG_SSB_DRIVER_PCICORE_POSSIBLE 1
#define CONFIG_MISDN_AVMFRITZ_MODULE 1
#define CONFIG_X86_RESERVE_LOW 64
#define CONFIG_SMS_SDIO_DRV_MODULE 1
#define CONFIG_NFSD_PNFS 1
#define CONFIG_NEED_SG_DMA_LENGTH 1
#define CONFIG_SND_MPU401_MODULE 1
#define CONFIG_DVB_CX24116_MODULE 1
#define CONFIG_POWER_RESET 1
#define CONFIG_CRYPTO_XCBC_MODULE 1
#define CONFIG_NF_NAT_AMANDA_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_MODULE 1
#define CONFIG_SENSORS_ADT7411_MODULE 1
#define CONFIG_IXGBE_DCA 1
#define CONFIG_IR_GPIO_CIR_MODULE 1
#define CONFIG_IP6_NF_MATCH_IPV6HEADER_MODULE 1
#define CONFIG_MACVLAN_MODULE 1
#define CONFIG_PATA_PDC_OLD_MODULE 1
#define CONFIG_L2TP_V3 1
#define CONFIG_RTL8723_COMMON_MODULE 1
#define CONFIG_BPF_JIT 1
#define CONFIG_SENSORS_INA2XX_MODULE 1
#define CONFIG_PCIEASPM_DEFAULT 1
#define CONFIG_PROFILING 1
#define CONFIG_INTERVAL_TREE 1
#define CONFIG_IOSF_MBI_MODULE 1
#define CONFIG_SPARSEMEM 1
#define CONFIG_INET6_XFRM_MODE_TRANSPORT_MODULE 1
#define CONFIG_LEDS_LP5523_MODULE 1
#define CONFIG_CRYPTO_ARC4_MODULE 1
#define CONFIG_SND_TEA575X_MODULE 1
#define CONFIG_IEEE802154_6LOWPAN_MODULE 1
#define CONFIG_VHOST_NET_MODULE 1
#define CONFIG_DVB_STV0900_MODULE 1
#define CONFIG_I2C_NFORCE2_MODULE 1
#define CONFIG_USB_SERIAL_DIGI_ACCELEPORT_MODULE 1
#define CONFIG_USB_GL860_MODULE 1
#define CONFIG_GRACE_PERIOD_MODULE 1
#define CONFIG_SLHC_MODULE 1
#define CONFIG_SCSI_UFSHCD_PCI_MODULE 1
#define CONFIG_E1000E_HWTS 1
#define CONFIG_SCSI_TGT_MODULE 1
#define CONFIG_CRYPTO_MANAGER 1
#define CONFIG_NET_SCH_HTB_MODULE 1
#define CONFIG_EEPROM_AT24_MODULE 1
#define CONFIG_UIO_SERCOS3_MODULE 1
#define CONFIG_PPP_BSDCOMP_MODULE 1
#define CONFIG_SCHED_SMT 1
#define CONFIG_DVB_USB_TTUSB2_MODULE 1
#define CONFIG_CIFS_STATS 1
#define CONFIG_RT_MUTEXES 1
#define CONFIG_HID_ORTEK_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_MARK_MODULE 1
#define CONFIG_MEDIA_TUNER_MXL5007T_MODULE 1
#define CONFIG_DRM_I2C_SIL164_MODULE 1
#define CONFIG_MD_LINEAR_MODULE 1
#define CONFIG_HUGETLBFS 1
#define CONFIG_CHECK_SIGNATURE 1
#define CONFIG_DVB_TDA10021_MODULE 1
#define CONFIG_VIDEO_CX231XX_DVB_MODULE 1
#define CONFIG_X86_INTEL_MPX 1
#define CONFIG_I2C_ALGOBIT_MODULE 1
#define CONFIG_MMC_BLOCK_MODULE 1
#define CONFIG_NET_CLS_FW_MODULE 1
#define CONFIG_KVM_MODULE 1
#define CONFIG_PAGE_COUNTER 1
#define CONFIG_SND_PCI 1
#define CONFIG_VIDEO_SAA7134_DVB_MODULE 1
#define CONFIG_ISDN_DRV_HISAX_MODULE 1
#define CONFIG_ATL1C_MODULE 1
#define CONFIG_IR_SANYO_DECODER_MODULE 1
#define CONFIG_DMAR_TABLE 1
#define CONFIG_MFD_INTEL_LPSS_PCI 1
#define CONFIG_HW_RANDOM_INTEL_MODULE 1
#define CONFIG_LXT_PHY_MODULE 1
#define CONFIG_CFG80211_CRDA_SUPPORT 1
#define CONFIG_VIDEO_MT9V011_MODULE 1
#define CONFIG_WIRELESS 1
#define CONFIG_WEXT_PROC 1
#define CONFIG_BCMA_DRIVER_PCI 1
#define CONFIG_SQUASHFS_MODULE 1
#define CONFIG_6LOWPAN_NHC_MODULE 1
#define CONFIG_EDAC_I7CORE_MODULE 1
#define CONFIG_X86_IO_APIC 1
#define CONFIG_NFT_DUP_IPV6_MODULE 1
#define CONFIG_DELL_WMI_AIO_MODULE 1
#define CONFIG_USB_GSPCA_KONICA_MODULE 1
#define CONFIG_TCG_TIS_I2C_ATMEL_MODULE 1
#define CONFIG_NET_SCH_TBF_MODULE 1
#define CONFIG_PKCS7_MESSAGE_PARSER 1
#define CONFIG_BT_HCIBTUSB_MODULE 1
#define CONFIG_DVB_CX22702_MODULE 1
#define CONFIG_KGDB 1
#define CONFIG_SERIO_RAW_MODULE 1
#define CONFIG_TASK_IO_ACCOUNTING 1
#define CONFIG_FAT_DEFAULT_IOCHARSET "ascii"
#define CONFIG_UWB_MODULE 1
#define CONFIG_ASYNC_XOR_MODULE 1
#define CONFIG_ISDN_CAPI_MIDDLEWARE 1
#define CONFIG_NET_CLS_RSVP_MODULE 1
#define CONFIG_MEMORY_HOTPLUG_SPARSE 1
#define CONFIG_DVB_STB6100_MODULE 1
#define CONFIG_W83977F_WDT_MODULE 1
#define CONFIG_MD_RAID0_MODULE 1
#define CONFIG_FRAME_WARN 2048
#define CONFIG_USB_NET_CDC_NCM_MODULE 1
#define CONFIG_HID_GENERIC 1
#define CONFIG_HP_WATCHDOG_MODULE 1
#define CONFIG_BCM87XX_PHY_MODULE 1
#define CONFIG_ASYNC_RAID6_TEST_MODULE 1
#define CONFIG_PATA_SCH_MODULE 1
#define CONFIG_GENERIC_HWEIGHT 1
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_RTL_CARDS_MODULE 1
#define CONFIG_PATA_NETCELL_MODULE 1
#define CONFIG_ARCH_WANTS_PROT_NUMA_PROT_NONE 1
#define CONFIG_ATM_CLIP_MODULE 1
#define CONFIG_SND_HDA_CODEC_SIGMATEL_MODULE 1
#define CONFIG_CGROUPS 1
#define CONFIG_SND_SOC_RT5670_MODULE 1
#define CONFIG_SND_USB_CAIAQ_INPUT 1
#define CONFIG_MMC_MODULE 1
#define CONFIG_LZO_COMPRESS 1
#define CONFIG_VIRTIO_INPUT_MODULE 1
#define CONFIG_CRYPTO_SEQIV 1
#define CONFIG_DM_CACHE_CLEANER_MODULE 1
#define CONFIG_BRCMFMAC_MODULE 1
#define CONFIG_SND_HDA_POWER_SAVE_DEFAULT 0
#define CONFIG_HID_LOGITECH 1
#define CONFIG_SND_INDIGODJX_MODULE 1
#define CONFIG_ISDN_I4L_MODULE 1
#define CONFIG_USB_SERIAL_CONSOLE 1
#define CONFIG_DM_LOG_USERSPACE_MODULE 1
#define CONFIG_SCSI_ENCLOSURE_MODULE 1
#define CONFIG_DVB_SP887X_MODULE 1
#define CONFIG_STACKTRACE 1
#define CONFIG_SENSORS_LM92_MODULE 1
#define CONFIG_SCSI_SAS_LIBSAS_MODULE 1
#define CONFIG_ISCSI_TARGET_MODULE 1
#define CONFIG_IMA_MEASURE_PCR_IDX 10
#define CONFIG_NETFILTER_NETLINK_QUEUE_CT 1
#define CONFIG_OPROFILE_NMI_TIMER 1
#define CONFIG_IPV6_GRE_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_IDLETIMER_MODULE 1
#define CONFIG_VFIO_PCI_INTX 1
#define CONFIG_UIO_AEC_MODULE 1
#define CONFIG_SCSI_PM8001_MODULE 1
#define CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC 1
#define CONFIG_VIDEO_TUNER_MODULE 1
#define CONFIG_IFB_MODULE 1
#define CONFIG_HAS_IOPORT 1
#define CONFIG_LEDS_LP3944_MODULE 1
#define CONFIG_USB_SEVSEG_MODULE 1
#define CONFIG_SND_MPU401_UART_MODULE 1
#define CONFIG_IPV6_VTI_MODULE 1
#define CONFIG_CRYPTO_DRBG_MODULE 1
#define CONFIG_RTC_DRV_PCF8563_MODULE 1
#define CONFIG_SND_MAX_CARDS 32
#define CONFIG_PPTP_MODULE 1
#define CONFIG_DVB_USB_V2_MODULE 1
#define CONFIG_SENSORS_SMSC47M1_MODULE 1
#define CONFIG_SND_USB_US122L_MODULE 1
#define CONFIG_ISCSI_IBFT_FIND 1
#define CONFIG_KGDB_KDB 1
#define CONFIG_DCB 1
#define CONFIG_PCIPCWATCHDOG_MODULE 1
#define CONFIG_GPIO_LANGWELL 1
#define CONFIG_CGROUP_CPUACCT 1
#define CONFIG_USB_SERIAL_OTI6858_MODULE 1
#define CONFIG_CAN_BCM_MODULE 1
#define CONFIG_X86_CMPXCHG64 1
#define CONFIG_VIDEO_SAA7146_VV_MODULE 1
#define CONFIG_NLMON_MODULE 1
#define CONFIG_ATH10K_PCI_MODULE 1
#define CONFIG_USB_ATM_MODULE 1
#define CONFIG_ISA_DMA_API 1
#define CONFIG_HZ 1000
#define CONFIG_SERIAL_8250_SHARE_IRQ 1
#define CONFIG_IXGBE_HWMON 1
#define CONFIG_USB_RTL8152_MODULE 1
#define CONFIG_NEED_MULTIPLE_NODES 1
#define CONFIG_I2C_HELPER_AUTO 1
#define CONFIG_NETFILTER_XT_MATCH_U32_MODULE 1
#define CONFIG_SQUASHFS_ZLIB 1
#define CONFIG_VIDEO_CX23885_MODULE 1
#define CONFIG_AGP_INTEL 1
#define CONFIG_INLINE_SPIN_UNLOCK_IRQ 1
#define CONFIG_NLS_ISO8859_4_MODULE 1
#define CONFIG_INTEL_OAKTRAIL_MODULE 1
#define CONFIG_DIRECT_GBPAGES 1
#define CONFIG_FB_BACKLIGHT 1
#define CONFIG_RTC_DRV_RX8025_MODULE 1
#define CONFIG_SERIAL_8250_NR_UARTS 32
#define CONFIG_TCP_CONG_DCTCP_MODULE 1
#define CONFIG_NET_EMATCH_IPSET_MODULE 1
#define CONFIG_INFINIBAND_SRPT_MODULE 1
#define CONFIG_CRYPTO_RMD160_MODULE 1
#define CONFIG_IR_IMON_MODULE 1
#define CONFIG_ACPI_CUSTOM_METHOD_MODULE 1
#define CONFIG_PATA_HPT366_MODULE 1
#define CONFIG_INFINIBAND_IPATH_MODULE 1
#define CONFIG_INET_AH_MODULE 1
#define CONFIG_SENSORS_ATXP1_MODULE 1
#define CONFIG_HAVE_USER_RETURN_NOTIFIER 1
#define CONFIG_MTD_UBI_BEB_LIMIT 20
#define CONFIG_DEFAULT_IOSCHED "deadline"
#define CONFIG_DRM_I2C_CH7006_MODULE 1
#define CONFIG_TABLET_USB_KBTAB_MODULE 1
#define CONFIG_UDF_FS_MODULE 1
#define CONFIG_SND_SOC_INTEL_BYTCR_RT5640_MACH_MODULE 1
#define CONFIG_IPV6_MIP6_MODULE 1
#define CONFIG_MARVELL_PHY_MODULE 1
#define CONFIG_HAVE_PERF_USER_STACK_DUMP 1
#define CONFIG_ACPI_EC_DEBUGFS_MODULE 1
#define CONFIG_CGROUP_PERF 1
#define CONFIG_NLATTR 1
#define CONFIG_SND_LOLA_MODULE 1
#define CONFIG_ISDN_CAPI_MODULE 1
#define CONFIG_HOTPLUG_PCI 1
#define CONFIG_TCP_CONG_CUBIC 1
#define CONFIG_CEPH_FS_MODULE 1
#define CONFIG_SGI_XP_MODULE 1
#define CONFIG_SCSI_NETLINK 1
#define CONFIG_TCG_TIS_ST33ZP24_I2C_MODULE 1
#define CONFIG_NR_CPUS 5120
#define CONFIG_IXGBE_MODULE 1
#define CONFIG_SUSPEND_FREEZER 1
#define CONFIG_MMC_SDHCI_MODULE 1
#define CONFIG_DVB_DIB7000M_MODULE 1
#define CONFIG_NETFILTER_XT_CONNMARK_MODULE 1
#define CONFIG_LEDS_LT3593_MODULE 1
#define CONFIG_NO_HZ_FULL 1
#define CONFIG_DVB_AF9033_MODULE 1
#define CONFIG_HID_KYE_MODULE 1
#define CONFIG_MOUSE_PS2_TRACKPOINT 1
#define CONFIG_MOUSE_VSXXXAA_MODULE 1
#define CONFIG_IP_MROUTE_MULTIPLE_TABLES 1
#define CONFIG_VIDEO_TM6000_ALSA_MODULE 1
#define CONFIG_NFT_COMPAT_MODULE 1
#define CONFIG_IDMA64_MODULE 1
#define CONFIG_DRM_NOUVEAU_BACKLIGHT 1
#define CONFIG_SOFT_WATCHDOG_MODULE 1
#define CONFIG_SYSFS 1
#define CONFIG_IP_SET_BITMAP_IPMAC_MODULE 1
#define CONFIG_ISCSI_TARGET_CXGB4_MODULE 1
#define CONFIG_USB_DEFAULT_PERSIST 1
#define CONFIG_DELL_WMI_MODULE 1
#define CONFIG_SENSORS_W83791D_MODULE 1
#define CONFIG_INPUT_TOUCHSCREEN 1
#define CONFIG_RT2800USB_UNKNOWN 1
#define CONFIG_EDAC_LEGACY_SYSFS 1
#define CONFIG_I2C_VIAPRO_MODULE 1
#define CONFIG_FB_HYPERV_MODULE 1
#define CONFIG_USB_GSPCA_NW80X_MODULE 1
#define CONFIG_NF_CONNTRACK_LABELS 1
#define CONFIG_IP_NF_MATCH_AH_MODULE 1
#define CONFIG_INFINIBAND_SRP_MODULE 1
#define CONFIG_CARL9170_WPC 1
#define CONFIG_TCP_CONG_VENO_MODULE 1
#define CONFIG_DVB_S5H1420_MODULE 1
#define CONFIG_INFINIBAND_MODULE 1
#define CONFIG_DVB_NET 1
#define CONFIG_ASN1 1
#define CONFIG_NF_LOG_COMMON_MODULE 1
#define CONFIG_I2C_PARPORT_LIGHT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_LIMIT_MODULE 1
#define CONFIG_CRYPTO_AES_NI_INTEL_MODULE 1
#define CONFIG_ULI526X_MODULE 1
#define CONFIG_CRYPTO_SHA1_MB_MODULE 1
#define CONFIG_NET_KEY_MIGRATE 1
#define CONFIG_CC_STACKPROTECTOR 1
#define CONFIG_I2C_SIMTEC_MODULE 1
#define CONFIG_DEFAULT_IO_DELAY_TYPE 0
#define CONFIG_NLS_CODEPAGE_775_MODULE 1
#define CONFIG_RTLLIB_CRYPTO_TKIP_MODULE 1
#define CONFIG_MOUSE_SERIAL_MODULE 1
#define CONFIG_CRYPTO_HASH_INFO 1
#define CONFIG_FB_SYS_FOPS_MODULE 1
#define CONFIG_MISDN_HFCPCI_MODULE 1
#define CONFIG_HAVE_SYSCALL_TRACEPOINTS 1
#define CONFIG_MEDIA_TUNER_XC4000_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DEVGROUP_MODULE 1
#define CONFIG_ACPI_BATTERY 1
#define CONFIG_DVB_LGDT3305_MODULE 1
#define CONFIG_MEMSTICK_MODULE 1
#define CONFIG_FUJITSU_TABLET_MODULE 1
#define CONFIG_HISAX_ELSA 1
#define CONFIG_VIDEO_SAA7146_MODULE 1
#define CONFIG_FB 1
#define CONFIG_TRACING 1
#define CONFIG_IP_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_NLS_CODEPAGE_865_MODULE 1
#define CONFIG_I2C_COMPAT 1
#define CONFIG_INET_SCTP_DIAG_MODULE 1
#define CONFIG_NFSD_V3_ACL 1
#define CONFIG_SND_SOC_SSM4567_MODULE 1
#define CONFIG_USB_GSPCA_SPCA500_MODULE 1
#define CONFIG_SPARSEMEM_VMEMMAP_ENABLE 1
#define CONFIG_NET_ACT_NAT_MODULE 1
#define CONFIG_FTRACE_MCOUNT_RECORD 1
#define CONFIG_VIRTUALIZATION 1
#define CONFIG_ND_CLAIM 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_MYRI10GE_DCA 1
#define CONFIG_BT_HCIUART_MODULE 1
#define CONFIG_BOOTPARAM_HARDLOCKUP_PANIC_VALUE 1
#define CONFIG_RT2800USB_RT33XX 1
#define CONFIG_DVB_LNBP22_MODULE 1
#define CONFIG_SENSORS_TMP421_MODULE 1
#define CONFIG_USB_GSPCA_SN9C2028_MODULE 1
#define CONFIG_HAVE_OPROFILE 1
#define CONFIG_IR_STREAMZAP_MODULE 1
#define CONFIG_SND_HDSPM_MODULE 1
#define CONFIG_CAN_PEAK_PCIEC 1
#define CONFIG_EFI_VARS_PSTORE 1
#define CONFIG_X86_INTEL_LPSS 1
#define CONFIG_LEDS_CLEVO_MAIL_MODULE 1
#define CONFIG_IP_SET_MODULE 1
#define CONFIG_THERMAL 1
#define CONFIG_DVB_BUDGET_PATCH_MODULE 1
#define CONFIG_USB_XHCI_PCI 1
#define CONFIG_AMD_IOMMU 1
#define CONFIG_I2C_AMD8111_MODULE 1
#define CONFIG_INPUT_POWERMATE_MODULE 1
#define CONFIG_NET_FC 1
#define CONFIG_BRCMUTIL_MODULE 1
#define CONFIG_DVB_TTUSB_BUDGET_MODULE 1
#define CONFIG_VETH_MODULE 1
#define CONFIG_RTC_DRV_PCF8583_MODULE 1
#define CONFIG_DVB_MT312_MODULE 1
#define CONFIG_MLX5_CORE_EN 1
#define CONFIG_HID_PETALYNX_MODULE 1
#define CONFIG_AMD_NUMA 1
#define CONFIG_IRQ_BYPASS_MANAGER_MODULE 1
#define CONFIG_TLAN_MODULE 1
#define CONFIG_ARCH_ENABLE_SPLIT_PMD_PTLOCK 1
#define CONFIG_SND_HDA_CODEC_VIA_MODULE 1
#define CONFIG_MEMSTICK_TIFM_MS_MODULE 1
#define CONFIG_ATM_LANE_MODULE 1
#define CONFIG_SENSORS_W83L786NG_MODULE 1
#define CONFIG_NET_ACT_MIRRED_MODULE 1
#define CONFIG_HAVE_ARCH_KGDB 1
#define CONFIG_VGACON_SOFT_SCROLLBACK_SIZE 64
#define CONFIG_INPUT_APANEL_MODULE 1
#define CONFIG_NF_CONNTRACK_IPV4_MODULE 1
#define CONFIG_QLCNIC_SRIOV 1
#define CONFIG_MYRI10GE_MODULE 1
#define CONFIG_X86_PM_TIMER 1
#define CONFIG_USB_VL600_MODULE 1
#define CONFIG_ZONE_DMA_FLAG 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_RT5672_MACH_MODULE 1
#define CONFIG_ATH9K_BTCOEX_SUPPORT 1
#define CONFIG_CAN_SOFTING_MODULE 1
#define CONFIG_RT2X00_LIB_PCI_MODULE 1
#define CONFIG_SND_DUMMY_MODULE 1
#define CONFIG_SCSI_MVSAS_MODULE 1
#define CONFIG_NET_VENDOR_INTEL 1
#define CONFIG_USB_WUSB_CBAF_MODULE 1
#define CONFIG_RPS 1
#define CONFIG_PACKET_DIAG_MODULE 1
#define CONFIG_DVB_AU8522_DTV_MODULE 1
#define CONFIG_HISAX_ST5481_MODULE 1
#define CONFIG_USB_NET_ZAURUS_MODULE 1
#define CONFIG_INET6_XFRM_TUNNEL_MODULE 1
#define CONFIG_DRM_AST_MODULE 1
#define CONFIG_DM_MULTIPATH_ST_MODULE 1
#define CONFIG_NET_TEAM_MODE_RANDOM_MODULE 1
#define CONFIG_SENSORS_LM95241_MODULE 1
#define CONFIG_PROC_PID_CPUSET 1
#define CONFIG_REALTEK_AUTOPM 1
#define CONFIG_USB_NET_AX88179_178A_MODULE 1
#define CONFIG_NF_TABLES_BRIDGE_MODULE 1
#define CONFIG_MEDIA_TUNER_E4000_MODULE 1
#define CONFIG_INPUT_ATLAS_BTNS_MODULE 1
#define CONFIG_VIDEO_SAA6588_MODULE 1
#define CONFIG_DVB_ZL10039_MODULE 1
#define CONFIG_CAPI_AVM 1
#define CONFIG_MTD_MAP_BANK_WIDTH_2 1
#define CONFIG_NFT_REJECT_MODULE 1
#define CONFIG_WDTPCI_MODULE 1
#define CONFIG_USB_SERIAL_DEBUG_MODULE 1
#define CONFIG_SENSORS_MAX16064_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORTIP_MODULE 1
#define CONFIG_MLX4_EN_MODULE 1
#define CONFIG_TABLET_USB_ACECAD_MODULE 1
#define CONFIG_HYPERVISOR_GUEST 1
#define CONFIG_NET_EMATCH_NBYTE_MODULE 1
#define CONFIG_SENSORS_BH1770_MODULE 1
#define CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS 1
#define CONFIG_TCG_NSC_MODULE 1
#define CONFIG_ZISOFS 1
#define CONFIG_CUSE_MODULE 1
#define CONFIG_NF_TABLES_IPV4_MODULE 1
#define CONFIG_IP_MULTICAST 1
#define CONFIG_DM_CACHE_SMQ_MODULE 1
#define CONFIG_CRYPTO_RMD256_MODULE 1
#define CONFIG_DVB_MT352_MODULE 1
#define CONFIG_RC_ATI_REMOTE_MODULE 1
#define CONFIG_W83627HF_WDT_MODULE 1
#define CONFIG_SQUASHFS_XZ 1
#define CONFIG_USB_NET_CX82310_ETH_MODULE 1
#define CONFIG_GENERIC_CMOS_UPDATE 1
#define CONFIG_NET_VENDOR_CISCO 1
#define CONFIG_EEPROM_MAX6875_MODULE 1
#define CONFIG_DRM_CIRRUS_QEMU_MODULE 1
#define CONFIG_MOUSE_APPLETOUCH_MODULE 1
#define CONFIG_HID_LOGITECH_DJ_MODULE 1
#define CONFIG_DEFAULT_SECURITY "selinux"
#define CONFIG_VIDEO_STK1160_MODULE 1
#define CONFIG_TICK_ONESHOT 1
#define CONFIG_NF_NAT_PROTO_UDPLITE_MODULE 1
#define CONFIG_USB_SERIAL_SIERRAWIRELESS_MODULE 1
#define CONFIG_NETPRIO_CGROUP 1
#define CONFIG_CRYPTO_CTR 1
#define CONFIG_COMPAT_FOR_U64_ALIGNMENT 1
#define CONFIG_MTRR_SANITIZER 1
#define CONFIG_DVB_STV090x_MODULE 1
#define CONFIG_SCSI_HPTIOP_MODULE 1
#define CONFIG_NATIONAL_PHY_MODULE 1
#define CONFIG_ORE_MODULE 1
#define CONFIG_USB_SERIAL_KEYSPAN_PDA_MODULE 1
#define CONFIG_DE_AOC 1
#define CONFIG_WIRELESS_EXT 1
#define CONFIG_MEDIA_TUNER_MT2060_MODULE 1
#define CONFIG_HID_PICOLCD_BACKLIGHT 1
#define CONFIG_SND_SOC_RT5640_MODULE 1
#define CONFIG_I40E_VXLAN 1
#define CONFIG_SND_HDA_CODEC_CA0110_MODULE 1
#define CONFIG_MODVERSIONS 1
#define CONFIG_HW_RANDOM 1
#define CONFIG_MUTEX_SPIN_ON_OWNER 1
#define CONFIG_CRYPTO_ABLK_HELPER_X86_MODULE 1
#define CONFIG_IO_DELAY_TYPE_0X80 0
#define CONFIG_DVB_USB_AU6610_MODULE 1
#define CONFIG_CAN_LEDS 1
#define CONFIG_X86_SPEEDSTEP_LIB_MODULE 1
#define CONFIG_IE6XX_WDT_MODULE 1
#define CONFIG_BT_HCIBTUSB_RTL 1
#define CONFIG_SYS_HYPERVISOR 1
#define CONFIG_HAVE_DMA_ATTRS 1
#define CONFIG_TOUCHSCREEN_WACOM_I2C_MODULE 1
#define CONFIG_SND_VIRTUOSO_MODULE 1
#define CONFIG_AMIGA_PARTITION 1
#define CONFIG_EARLY_PRINTK 1
#define CONFIG_THINKPAD_ACPI_ALSA_SUPPORT 1
#define CONFIG_MEMCG_SWAP 1
#define CONFIG_NETFILTER_SYNPROXY_MODULE 1
#define CONFIG_FS_DAX 1
#define CONFIG_NLS_CODEPAGE_737_MODULE 1
#define CONFIG_NF_NAT_IPV4_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_TRACER 1
#define CONFIG_HW_RANDOM_VIA_MODULE 1
#define CONFIG_SENSORS_W83781D_MODULE 1
#define CONFIG_I2C_DESIGNWARE_PLATFORM_MODULE 1
#define CONFIG_HAVE_CMPXCHG_LOCAL 1
#define CONFIG_NVDIMM_PFN 1
#define CONFIG_VIDEOBUF2_CORE_MODULE 1
#define CONFIG_SSB_DRIVER_GPIO 1
#define CONFIG_RH_KABI_SIZE_ALIGN_CHECKS 1
#define CONFIG_EEEPC_WMI_MODULE 1
#define CONFIG_VIDEO_AU0828_V4L2 1
#define CONFIG_ACPI_THERMAL 1
#define CONFIG_RT2X00_LIB_CRYPTO 1
#define CONFIG_SCSI_DH_HP_SW 1
#define CONFIG_IP_SCTP_MODULE 1
#define CONFIG_DVB_STB0899_MODULE 1
#define CONFIG_SERIAL_8250_DMA 1
#define CONFIG_BASE_SMALL 0
#define CONFIG_IWLEGACY_DEBUGFS 1
#define CONFIG_CRYPTO_BLKCIPHER2 1
#define CONFIG_SCSI_SAS_ATTRS_MODULE 1
#define CONFIG_SECURITY_SELINUX_AVC_STATS 1
#define CONFIG_RTL8187_MODULE 1
#define CONFIG_DEVPTS_MULTIPLE_INSTANCES 1
#define CONFIG_X86_PMEM_LEGACY_DEVICE 1
#define CONFIG_SND_SEQ_DUMMY_MODULE 1
#define CONFIG_CRYPTO_AES_X86_64 1
#define CONFIG_DM_RAID_MODULE 1
#define CONFIG_COMPACTION 1
#define CONFIG_SCSI_MPT3SAS_MAX_SGE 128
#define CONFIG_DVB_TDA18271C2DD_MODULE 1
#define CONFIG_QLGE_MODULE 1
#define CONFIG_HAVE_TEXT_POKE_SMP 1
#define CONFIG_VIDEO_TM6000_MODULE 1
#define CONFIG_DVB_CXD2820R_MODULE 1
#define CONFIG_VIDEO_TDA7432_MODULE 1
#define CONFIG_NF_DUP_IPV6_MODULE 1
#define CONFIG_RTL8723BE_MODULE 1
#define CONFIG_RTC_DRV_DS2404_MODULE 1
#define CONFIG_DM_ERA_MODULE 1
#define CONFIG_USB_GSPCA_SONIXJ_MODULE 1
#define CONFIG_THINKPAD_ACPI_HOTKEY_POLL 1
#define CONFIG_DRM_AMDGPU_MODULE 1
#define CONFIG_RTC_DRV_DS1553_MODULE 1
#define CONFIG_CRYPTO_KHAZAD_MODULE 1
#define CONFIG_PROC_FS 1
#define CONFIG_MMC_CB710_MODULE 1
#define CONFIG_NET_PACKET_ENGINE 1
#define CONFIG_MTD_BLOCK_MODULE 1
#define CONFIG_W83697HF_WDT_MODULE 1
#define CONFIG_ACPI_HOTPLUG_MEMORY 1
#define CONFIG_VIDEOBUF2_VMALLOC_MODULE 1
#define CONFIG_NFT_BRIDGE_REJECT_MODULE 1
#define CONFIG_GENERIC_BUG_RELATIVE_POINTERS 1
#define CONFIG_6LOWPAN_NHC_FRAGMENT_MODULE 1
#define CONFIG_RC_MAP_MODULE 1
#define CONFIG_WEXT_PRIV 1
#define CONFIG_THINKPAD_ACPI_VIDEO 1
#define CONFIG_SCSI_LOWLEVEL 1
#define CONFIG_INPUT_GPIO_ROTARY_ENCODER_MODULE 1
#define CONFIG_IP_VS_PROTO_AH_ESP 1
#define CONFIG_SND_SOC_NAU8825_MODULE 1
#define CONFIG_IP_DCCP_CCID3 1
#define CONFIG_IRQ_FORCED_THREADING 1
#define CONFIG_ATH9K_PCI 1
#define CONFIG_HID_WIIMOTE_EXT 1
#define CONFIG_NLS_ISO8859_3_MODULE 1
#define CONFIG_XEN_SYS_HYPERVISOR 1
#define CONFIG_CRYPTO_CMAC_MODULE 1
#define CONFIG_HID_PANTHERLORD_MODULE 1
#define CONFIG_DRM_FBDEV_EMULATION 1
#define CONFIG_X86_HT 1
#define CONFIG_TEST_KSTRTOX 1
#define CONFIG_SND_MODULE 1
#define CONFIG_SND_SOC_INTEL_SST_MODULE 1
#define CONFIG_NET_SCH_TEQL_MODULE 1
#define CONFIG_MEMSTICK_JMICRON_38X_MODULE 1
#define CONFIG_SENSORS_MCP3021_MODULE 1
#define CONFIG_CRYPTO_SALSA20_X86_64_MODULE 1
#define CONFIG_IR_RC6_DECODER_MODULE 1
#define CONFIG_IWLEGACY_MODULE 1
#define CONFIG_IP_VS_SH_MODULE 1
#define CONFIG_XEN_BALLOON 1
#define CONFIG_VIDEO_MSP3400_MODULE 1
#define CONFIG_CRYPTO_SERPENT_AVX_X86_64_MODULE 1
#define CONFIG_USB_PEGASUS_MODULE 1
#define CONFIG_USB_TMC_MODULE 1
#define CONFIG_HISAX_NO_KEYPAD 1
#define CONFIG_DEBUG_STACKOVERFLOW 1
#define CONFIG_PAGEFLAGS_EXTENDED 1
#define CONFIG_BLK_DEV_FD_MODULE 1
#define CONFIG_IPPP_FILTER 1
#define CONFIG_EVM 1
#define CONFIG_SND_PCSP_MODULE 1
#define CONFIG_RFKILL_INPUT 1
#define CONFIG_BOOTPARAM_HOTPLUG_CPU0 1
#define CONFIG_BLK_DEV_BSGLIB 1
#define CONFIG_MEDIA_TUNER_FC2580_MODULE 1
#define CONFIG_ATH9K_COMMON_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_C62XVF_MODULE 1
#define CONFIG_DVB_STB6000_MODULE 1
#define CONFIG_USB_SERIAL_QCAUX_MODULE 1
#define CONFIG_SATA_ACARD_AHCI_MODULE 1
#define CONFIG_DEBUG_LIST 1
#define CONFIG_NFS_USE_KERNEL_DNS 1
#define CONFIG_MISDN_SPEEDFAX_MODULE 1
#define CONFIG_SENSORS_IBMAEM_MODULE 1
#define CONFIG_SND_HDA_I915 1
#define CONFIG_SYSCTL 1
#define CONFIG_BRIDGE_IGMP_SNOOPING 1
#define CONFIG_IP_NF_TARGET_CLUSTERIP_MODULE 1
#define CONFIG_CAN_SLCAN_MODULE 1
#define CONFIG_PHYS_ADDR_T_64BIT 1
#define CONFIG_NOZOMI_MODULE 1
#define CONFIG_MLX4_EN_DCB 1
#define CONFIG_NETFILTER_XT_TARGET_AUDIT_MODULE 1
#define CONFIG_HAVE_C_RECORDMCOUNT 1
#define CONFIG_MEDIA_TUNER_MT2131_MODULE 1
#define CONFIG_INFINIBAND_I40IW_MODULE 1
#define CONFIG_HID_THINGM_MODULE 1
#define CONFIG_USB_NET_KALMIA_MODULE 1
#define CONFIG_IR_TTUSBIR_MODULE 1
#define CONFIG_USB_NET_DM9601_MODULE 1
#define CONFIG_HAVE_ARCH_TRACEHOOK 1
#define CONFIG_SSB_PCIHOST 1
#define CONFIG_IR_MCEUSB_MODULE 1
#define CONFIG_BLK_DEV_OSD_MODULE 1
#define CONFIG_CIFS_MODULE 1
#define CONFIG_XFRM_USER 1
#define CONFIG_HISAX_1TR6 1
#define CONFIG_TCP_CONG_BIC_MODULE 1
#define CONFIG_TASK_DELAY_ACCT 1
#define CONFIG_SCSI_DH_EMC 1
#define CONFIG_NET_NS 1
#define CONFIG_SENSORS_TMP401_MODULE 1
#define CONFIG_SENSORS_ADT7475_MODULE 1
#define CONFIG_HAVE_PERF_EVENTS 1
#define CONFIG_PCMCIA_XIRCOM_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_C62X_MODULE 1
#define CONFIG_HISAX_SCT_QUADRO 1
#define CONFIG_DVB_MANTIS_MODULE 1
#define CONFIG_SENSORS_LIS3_I2C_MODULE 1
#define CONFIG_RT2800PCI_RT35XX 1
#define CONFIG_CAN_C_CAN_MODULE 1
#define CONFIG_BTT 1
#define CONFIG_ATA_SFF 1
#define CONFIG_CRYPTO_LRW_MODULE 1
#define CONFIG_IWLWIFI_OPMODE_MODULAR 1
#define CONFIG_NET_EMATCH_CMP_MODULE 1
#define CONFIG_UV_MMTIMER_MODULE 1
#define CONFIG_USB_GSPCA_T613_MODULE 1
#define CONFIG_SND_VIA82XX_MODEM_MODULE 1
#define CONFIG_SND_MTPAV_MODULE 1
#define CONFIG_PPP_ASYNC_MODULE 1
#define CONFIG_MD_RAID10_MODULE 1
#define CONFIG_NFSD_SCSILAYOUT 1
#define CONFIG_GENERIC_IRQ_LEGACY_ALLOC_HWIRQ 1
#define CONFIG_HAVE_ALIGNED_STRUCT_PAGE 1
#define CONFIG_NO_BOOTMEM 1
#define CONFIG_SSB_SDIOHOST_POSSIBLE 1
#define CONFIG_SENSORS_APPLESMC_MODULE 1
#define CONFIG_CAN_GW_MODULE 1
#define CONFIG_NLS_CODEPAGE_866_MODULE 1
#define CONFIG_SENSORS_ABITUGURU3_MODULE 1
#define CONFIG_CRAMFS_MODULE 1
#define CONFIG_SKGE_GENESIS 1
#define CONFIG_LEDS_TRIGGER_TRANSIENT_MODULE 1
#define CONFIG_CYCLADES_MODULE 1
#define CONFIG_NFSD_V4_SECURITY_LABEL 1
#define CONFIG_CEPH_FS_POSIX_ACL 1
#define CONFIG_BLK_DEV_PMEM_MODULE 1
#define CONFIG_DEBUG_MEMORY_INIT 1
#define CONFIG_AUDIT 1
#define CONFIG_CHR_DEV_ST_MODULE 1
#define CONFIG_INTEL_IOMMU 1
#define CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE 1
#define CONFIG_DM_MULTIPATH_MODULE 1
#define CONFIG_CRYPTO_USER_API_SKCIPHER 1
#define CONFIG_SCSI_3W_SAS_MODULE 1
#define CONFIG_SENSORS_LM80_MODULE 1
#define CONFIG_DVB_IT913X_FE_MODULE 1
#define CONFIG_PCI_HYPERV_MODULE 1
#define CONFIG_PCIEASPM 1
#define CONFIG_ATA_PIIX_MODULE 1
#define CONFIG_HID_MULTITOUCH_MODULE 1
#define CONFIG_ISDN_HDLC_MODULE 1
#define CONFIG_FB_DEFERRED_IO 1
#define CONFIG_SATA_AHCI_MODULE 1
#define CONFIG_DVB_USB_A800_MODULE 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_RT5645_MACH_MODULE 1
#define CONFIG_SECURITY 1
#define CONFIG_DVB_A8293_MODULE 1
#define CONFIG_SENSORS_ASC7621_MODULE 1
#define CONFIG_OPTPROBES 1
#define CONFIG_HISAX_NETJET_U 1
#define CONFIG_NETXEN_NIC_MODULE 1
#define CONFIG_BNX2X_SRIOV 1
#define CONFIG_ACPI_NUMA 1
#define CONFIG_HID_ELECOM_MODULE 1
#define CONFIG_SND_TIMER_MODULE 1
#define CONFIG_KVM_MMIO 1
#define CONFIG_USB_EHCI_TT_NEWSCHED 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_TCM_FC_MODULE 1
#define CONFIG_IPV6_MROUTE_MULTIPLE_TABLES 1
#define CONFIG_BLK_DEV 1
#define CONFIG_DVB_USB_IT913X_MODULE 1
#define CONFIG_SERIO_I8042 1
#define CONFIG_MAC80211_RC_DEFAULT "minstrel_ht"
#define CONFIG_RTL8187_LEDS 1
#define CONFIG_NFS_ACL_SUPPORT_MODULE 1
#define CONFIG_RT2800USB_RT55XX 1
#define CONFIG_ATL1_MODULE 1
#define CONFIG_HISAX_NI1 1
#define CONFIG_USB_SERIAL_OMNINET_MODULE 1
#define CONFIG_HDLC_PPP_MODULE 1
#define CONFIG_BRIDGE_NETFILTER_MODULE 1
#define CONFIG_TCP_CONG_SCALABLE_MODULE 1
#define CONFIG_DVB_MB86A20S_MODULE 1
#define CONFIG_IOMMU_API 1
#define CONFIG_TRACING_SUPPORT 1
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_CDROM_PKTCDVD_MODULE 1
#define CONFIG_VFIO_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CONNMARK_MODULE 1
#define CONFIG_MINIX_SUBPARTITION 1
#define CONFIG_NET_RX_BUSY_POLL 1
#define CONFIG_SENSORS_SMSC47B397_MODULE 1
#define CONFIG_CRYPTO_MICHAEL_MIC_MODULE 1
#define CONFIG_CRYPTO_ANSI_CPRNG_MODULE 1
#define CONFIG_RCU_USER_QS 1
#define CONFIG_SECURITY_SELINUX 1
#define CONFIG_ZONE_DMA32 1
#define CONFIG_NET_SCHED 1
#define CONFIG_NETFILTER_XT_TARGET_CONNSECMARK_MODULE 1
#define CONFIG_UWB_I1480U_MODULE 1
#define CONFIG_DRM_PANEL 1
#define CONFIG_DVB_PLL_MODULE 1
#define CONFIG_PRINTK_TIME 1
#define CONFIG_SERIAL_JSM_MODULE 1
#define CONFIG_INPUT_MOUSEDEV_SCREEN_Y 768
#define CONFIG_SECCOMP_FILTER 1
#define CONFIG_PATA_HPT37X_MODULE 1
#define CONFIG_UIO_PCI_GENERIC_MODULE 1
#define CONFIG_PPP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_QUOTA_MODULE 1
#define CONFIG_ARCH_MAY_HAVE_PC_FDC 1
#define CONFIG_HAVE_KERNEL_LZO 1
#define CONFIG_ASYNC_CORE_MODULE 1
#define CONFIG_NET_SCH_MULTIQ_MODULE 1
#define CONFIG_INET_DIAG_MODULE 1
#define CONFIG_CRYPTO_GHASH_MODULE 1
#define CONFIG_SYNCLINKMP_MODULE 1
#define CONFIG_PSTORE 1
#define CONFIG_SCSI_LPFC_MODULE 1
#define CONFIG_NF_NAT_FTP_MODULE 1
#define CONFIG_MAC80211_RC_MINSTREL 1
#define CONFIG_CRYPTO_RMD320_MODULE 1
#define CONFIG_NF_CT_PROTO_UDPLITE_MODULE 1
#define CONFIG_RCU_NOCB_CPU_NONE 1
#define CONFIG_IO_DELAY_TYPE_UDELAY 2
#define CONFIG_IP6_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_HANGCHECK_TIMER_MODULE 1
#define CONFIG_SENSORS_W83627EHF_MODULE 1
#define CONFIG_ELF_CORE 1
#define CONFIG_DEV_COREDUMP 1
#define CONFIG_SENSORS_LM73_MODULE 1
#define CONFIG_SENSORS_PC87360_MODULE 1
#define CONFIG_TEXTSEARCH 1
#define CONFIG_VIDEO_IVTV_MODULE 1
#define CONFIG_ACPI_DOCK 1
#define CONFIG_XEN_HAVE_PVMMU 1
#define CONFIG_NF_CT_NETLINK_HELPER_MODULE 1
#define CONFIG_INFINIBAND_ON_DEMAND_PAGING 1
#define CONFIG_USB_SUPPORT 1
#define CONFIG_I2C_SCMI_MODULE 1
#define CONFIG_I2C_VIA_MODULE 1
#define CONFIG_INPUT_POLLDEV_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_C3XXX_MODULE 1
#define CONFIG_SND_INTEL8X0M_MODULE 1
#define CONFIG_UPROBE_EVENT 1
#define CONFIG_MEDIA_RC_SUPPORT 1
#define CONFIG_RTC_DRV_BQ32K_MODULE 1
#define CONFIG_USB_GSPCA_PAC7311_MODULE 1
#define CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS 1
#define CONFIG_VIA_WDT_MODULE 1
#define CONFIG_BLK_DEV_NVME_MODULE 1
#define CONFIG_BRCMFMAC_PROTO_BCDC 1
#define CONFIG_USB_HWA_HCD_MODULE 1
#define CONFIG_STAGING 1
#define CONFIG_SND_SOC_RL6347A_MODULE 1
#define CONFIG_SENSORS_LIS3LV02D_MODULE 1
#define CONFIG_INET_LRO 1
#define CONFIG_SND_SOC_RT5645_MODULE 1
#define CONFIG_FIREWIRE_MODULE 1
#define CONFIG_ATM_MODULE 1
#define CONFIG_HFI1_VERBS_31BIT_PSN 1
#define CONFIG_SCSI_FC_ATTRS_MODULE 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_EDAC_SBRIDGE_MODULE 1
#define CONFIG_HID_UCLOGIC_MODULE 1
#define CONFIG_HW_RANDOM_VIRTIO_MODULE 1
#define CONFIG_ACPI_APEI 1
#define CONFIG_SND_ES1968_RADIO 1
#define CONFIG_SND_CS46XX_MODULE 1
#define CONFIG_SCHED_INFO 1
#define CONFIG_USB_GSPCA_STK014_MODULE 1
#define CONFIG_IP_VS_FTP_MODULE 1
#define CONFIG_FANOTIFY_ACCESS_PERMISSIONS 1
#define CONFIG_VIDEO_CX18_MODULE 1
#define CONFIG_VMWARE_PVSCSI_MODULE 1
#define CONFIG_CFG80211_WEXT 1
#define CONFIG_WLAN_VENDOR_MARVELL 1
#define CONFIG_HISAX_EURO 1
#define CONFIG_DEFERRED_STRUCT_PAGE_INIT 1
#define CONFIG_I2C_PARPORT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_PHYSDEV_MODULE 1
#define CONFIG_BRCMFMAC_PCIE 1
#define CONFIG_SND_VIA82XX_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MB_MODULE 1
#define CONFIG_SND_DARLA20_MODULE 1
#define CONFIG_BLK_DEV_RAM_MODULE 1
#define CONFIG_SENSORS_HDAPS_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATE_MODULE 1
#define CONFIG_DVB_L64781_MODULE 1
#define CONFIG_SND_INDIGOIOX_MODULE 1
#define CONFIG_SND_ASIHPI_MODULE 1
#define CONFIG_BSD_DISKLABEL 1
#define CONFIG_RTC_DRV_M48T35_MODULE 1
#define CONFIG_CRYPTO_CAST_COMMON_MODULE 1
#define CONFIG_USB_STORAGE_FREECOM_MODULE 1
#define CONFIG_BRIDGE_EBT_LOG_MODULE 1
#define CONFIG_OPENVSWITCH_VXLAN_MODULE 1
#define CONFIG_IR_RC5_DECODER_MODULE 1
#define CONFIG_NET_SCH_GRED_MODULE 1
#define CONFIG_PCI_DIRECT 1
#define CONFIG_MMC_VIA_SDMMC_MODULE 1
#define CONFIG_DRM_MODULE 1
#define CONFIG_FUSION_MAX_SGE 128
#define CONFIG_INET6_XFRM_MODE_BEET_MODULE 1
#define CONFIG_MEDIA_RADIO_SUPPORT 1
#define CONFIG_IWL4965_MODULE 1
#define CONFIG_POSIX_MQUEUE_SYSCTL 1
#define CONFIG_RTC_DRV_MAX6900_MODULE 1
#define CONFIG_CRYPTO_DEV_PADLOCK_AES_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_B1PCIV4 1
#define CONFIG_SAMSUNG_LAPTOP_MODULE 1
#define CONFIG_BE2NET_HWMON 1
#define CONFIG_USB_USS720_MODULE 1
#define CONFIG_FB_CFB_COPYAREA 1
#define CONFIG_FB_EFI 1
#define CONFIG_USB_SISUSBVGA_MODULE 1
#define CONFIG_DVB_RTL2830_MODULE 1
#define CONFIG_I40E_MODULE 1
#define CONFIG_HAVE_KVM_IRQCHIP 1
#define CONFIG_BRIDGE_EBT_STP_MODULE 1
#define CONFIG_RT73USB_MODULE 1
#define CONFIG_DE2104X_DSL 0
#define CONFIG_BRIDGE_EBT_ARP_MODULE 1
#define CONFIG_BALLOON_COMPACTION 1
#define CONFIG_IP6_NF_MATCH_EUI64_MODULE 1
#define CONFIG_BINARY_PRINTF 1
#define CONFIG_MWIFIEX_MODULE 1
#define CONFIG_HP_ILO_MODULE 1
#define CONFIG_USB_STORAGE_JUMPSHOT_MODULE 1
#define CONFIG_SENSORS_MAX6642_MODULE 1
#define CONFIG_NET_SCH_PLUG_MODULE 1
#define CONFIG_SND_GINA20_MODULE 1
#define CONFIG_CPU_FREQ_STAT_DETAILS 1
#define CONFIG_GENERIC_CLOCKEVENTS_BUILD 1
#define CONFIG_TRACER_MAX_TRACE 1
#define CONFIG_VIDEOBUF_GEN_MODULE 1
#define CONFIG_SGI_PARTITION 1
#define CONFIG_INPUT_SPARSEKMAP_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_X86_64_3WAY_MODULE 1
#define CONFIG_RTL8192EE_MODULE 1
#define CONFIG_VIDEO_V4L2_MODULE 1
#define CONFIG_SND_PCM_TIMER 1
#define CONFIG_DVB_STV6110_MODULE 1
#define CONFIG_AC97_BUS_MODULE 1
#define CONFIG_SYSVIPC_SYSCTL 1
#define CONFIG_HID_NTRIG 1
#define CONFIG_IP_VS_IPV6 1
#define CONFIG_X86_64_ACPI_NUMA 1
#define CONFIG_DMA_SHARED_BUFFER 1
#define CONFIG_DVB_USB_NOVA_T_USB2_MODULE 1
#define CONFIG_CIFS_POSIX 1
#define CONFIG_PATA_RDC_MODULE 1
#define CONFIG_USB_EPSON2888 1
#define CONFIG_SND_INDIGODJ_MODULE 1
#define CONFIG_SENSORS_W83L785TS_MODULE 1
#define CONFIG_DECOMPRESS_GZIP 1
#define CONFIG_RT2X00_LIB_DEBUGFS 1
#define CONFIG_NLS_MAC_CELTIC_MODULE 1
#define CONFIG_SND_AU8830_MODULE 1
#define CONFIG_RTLLIB_CRYPTO_WEP_MODULE 1
#define CONFIG_XFRM_SUB_POLICY 1
#define CONFIG_VIRTIO_BLK_MODULE 1
#define CONFIG_DECOMPRESS_LZO 1
#define CONFIG_USB_SERIAL_ARK3116_MODULE 1
#define CONFIG_64BIT 1
#define CONFIG_SND_MIXART_MODULE 1
#define CONFIG_ACPI_INITRD_TABLE_OVERRIDE 1
#define CONFIG_QUOTA 1
#define CONFIG_SND_BT87X_MODULE 1
#define CONFIG_EARLY_PRINTK_EFI 1
#define CONFIG_DM9102_MODULE 1
#define CONFIG_SENSORS_LINEAGE_MODULE 1
#define CONFIG_SCSI_MPT2SAS_MAX_SGE 128
#define CONFIG_ZBUD 1
#define CONFIG_MMC_SDHCI_PLTFM_MODULE 1
#define CONFIG_I2C_CHARDEV_MODULE 1
#define CONFIG_RCU_NOCB_CPU 1
#define CONFIG_W83697UG_WDT_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0013_MODULE 1
#define CONFIG_LLC_MODULE 1
#define CONFIG_CROSS_COMPILE ""
#define CONFIG_MEDIA_TUNER_TEA5761_MODULE 1
#define CONFIG_NFT_REDIR_IPV4_MODULE 1
#define CONFIG_SND_TRIDENT_MODULE 1
#define CONFIG_NETWORK_SECMARK 1
#define CONFIG_SND_CTXFI_MODULE 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST 1
#define CONFIG_VIDEO_TVAUDIO_MODULE 1
#define CONFIG_HID_HOLTEK_MODULE 1
#define CONFIG_ARCH_RANDOM 1
#define CONFIG_SERIAL_8250_PCI 1
#define CONFIG_HAVE_MIXED_BREAKPOINTS_REGS 1
#define CONFIG_RTC_DRV_DS1672_MODULE 1
#define CONFIG_INTEL_MEI_MODULE 1
#define CONFIG_USB_SERIAL_SSU100_MODULE 1
#define CONFIG_MOUSE_PS2_SYNAPTICS 1
#define CONFIG_ATA_BMDMA 1
#define CONFIG_MEMORY_FAILURE 1
#define CONFIG_NFS_V4_1 1
#define CONFIG_ARCH_USE_CMPXCHG_LOCKREF 1
#define CONFIG_ARCH_WANT_FRAME_POINTERS 1
#define CONFIG_REGMAP 1
#define CONFIG_SFC_MCDI_MON 1
#define CONFIG_NLS_UTF8_MODULE 1
#define CONFIG_PCIE_PME 1
#define CONFIG_VIDEO_TM6000_DVB_MODULE 1
#define CONFIG_SPARSE_RCU_POINTER 1
#define CONFIG_INFINIBAND_ISERT_MODULE 1
#define CONFIG_CAN_DEV_MODULE 1
#define CONFIG_INPUT_YEALINK_MODULE 1
#define CONFIG_DVB_DIB3000MB_MODULE 1
#define CONFIG_SCSI_SRP_TGT_ATTRS 1
#define CONFIG_RTC_DRV_M41T80_MODULE 1
#define CONFIG_USB_USBNET_MODULE 1
#define CONFIG_SCSI_MULTI_LUN 1
#define CONFIG_NET_DEVLINK_MODULE 1
#define CONFIG_CPU_SUP_CENTAUR 1
#define CONFIG_CB710_CORE_MODULE 1
#define CONFIG_USB_SERIAL_PL2303_MODULE 1
#define CONFIG_NET_ACT_POLICE_MODULE 1
#define CONFIG_AIC79XX_DEBUG_MASK 0
#define CONFIG_UEFI_CPER 1
#define CONFIG_NODES_SPAN_OTHER_NODES 1
#define CONFIG_HAVE_INTEL_TXT 1
#define CONFIG_SYSCTL_EXCEPTION_TRACE 1
#define CONFIG_SYSVIPC_COMPAT 1
#define CONFIG_INPUT_XEN_KBDDEV_FRONTEND_MODULE 1
#define CONFIG_HOTPLUG_PCI_SHPC_MODULE 1
#define CONFIG_DVB_USB_CINERGY_T2_MODULE 1
#define CONFIG_FHANDLE 1
#define CONFIG_USB_MICROTEK_MODULE 1
#define CONFIG_PANASONIC_LAPTOP_MODULE 1
#define CONFIG_HISAX_BKM_A4T 1
#define CONFIG_HISAX_ENTERNOW_PCI 1
#define CONFIG_HID_SMARTJOYPLUS_MODULE 1
#define CONFIG_ATA_GENERIC_MODULE 1
#define CONFIG_NEW_LEDS 1
#define CONFIG_SWAP 1
#define CONFIG_NFT_BRIDGE_META_MODULE 1
#define CONFIG_MICROCODE_INTEL 1
#define CONFIG_RTC_DRV_DS1511_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET_ENABLE_MODULE 1
#define CONFIG_IP_FIB_TRIE_STATS 1
#define CONFIG_CRYPTO_SHA256_SSSE3 1
#define CONFIG_NET_SCH_HFSC_MODULE 1
#define CONFIG_RTC_DRV_RV3029C2_MODULE 1
#define CONFIG_WIL6210_MODULE 1
#define CONFIG_SND_ISIGHT_MODULE 1
#define CONFIG_VIDEOBUF_DMA_SG_MODULE 1
#define CONFIG_MAC80211_MODULE 1
#define CONFIG_SND_SOC_INTEL_SKL_NAU88L25_SSM4567_MACH_MODULE 1
#define CONFIG_ARCH_USES_PG_UNCACHED 1
#define CONFIG_CRC_CCITT_MODULE 1
#define CONFIG_SND_SOC_TS3A227E_MODULE 1
#define CONFIG_DVB_TDA8261_MODULE 1
#define CONFIG_SND_HDA_EXT_CORE_MODULE 1
#define CONFIG_IGBVF_MODULE 1
#define CONFIG_BLK_DEV_SD_MODULE 1
#define CONFIG_PHYSICAL_ALIGN 0x1000000
#define CONFIG_NETFILTER_NETLINK_MODULE 1
#define CONFIG_VITESSE_PHY_MODULE 1
#define CONFIG_MODULE_UNLOAD 1
#define CONFIG_KEXEC_BZIMAGE_VERIFY_SIG 1
#define CONFIG_FSCACHE_STATS 1
#define CONFIG_INFINIBAND_MTHCA_MODULE 1
#define CONFIG_SENSORS_MAX6650_MODULE 1
#define CONFIG_USB_GSPCA_BENQ_MODULE 1
#define CONFIG_BT_LE 1
#define CONFIG_SND_AC97_CODEC_MODULE 1
#define CONFIG_ARCH_WANT_OLD_COMPAT_IPC 1
#define CONFIG_DVB_USB_CXUSB_MODULE 1
#define CONFIG_CMA 1
#define CONFIG_SENSORS_LM85_MODULE 1
#define CONFIG_SND_ATIIXP_MODULE 1
#define CONFIG_TRACER_SNAPSHOT 1
#define CONFIG_INFINIBAND_IPOIB_CM 1
#define CONFIG_HID_PICOLCD_LCD 1
#define CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST 1
#define CONFIG_RCU_FANOUT 64
#define CONFIG_ARCH_USES_NUMA_PROT_NONE 1
#define CONFIG_BITREVERSE 1
#define CONFIG_NFT_MASQ_IPV6_MODULE 1
#define CONFIG_DEVPORT 1
#define CONFIG_X509_CERTIFICATE_PARSER 1
#define CONFIG_BLK_DEV_RAM_SIZE 16384
#define CONFIG_USB_SERIAL_WWAN_MODULE 1
#define CONFIG_SND_ICE1724_MODULE 1
#define CONFIG_MAC_PARTITION 1
#define CONFIG_CONSOLE_POLL 1
#define CONFIG_XFS_POSIX_ACL 1
#define CONFIG_CRYPTO_PCOMP_MODULE 1
#define CONFIG_ND_BLK_MODULE 1
#define CONFIG_MSI_LAPTOP_MODULE 1
#define CONFIG_BRCMFMAC_USB 1
#define CONFIG_NLS_ISO8859_13_MODULE 1
#define CONFIG_PCI_PRI 1
#define CONFIG_BLK_DEV_SX8_MODULE 1
#define CONFIG_CRYPTO_BLKCIPHER 1
#define CONFIG_X86_L1_CACHE_SHIFT 6
#define CONFIG_X86_PAT 1
#define CONFIG_USB_STORAGE_ONETOUCH_MODULE 1
#define CONFIG_NLS_ISO8859_8_MODULE 1
#define CONFIG_SND_SOC_INTEL_SKL_NAU88L25_MAX98357A_MACH_MODULE 1
#define CONFIG_NF_CONNTRACK_MODULE 1
#define CONFIG_RTC_DRV_PCF8523_MODULE 1
#define CONFIG_HID_PICOLCD_CIR 1
#define CONFIG_LCD_CLASS_DEVICE_MODULE 1
#define CONFIG_ARCH_DMA_ADDR_T_64BIT 1
#define CONFIG_FILE_LOCKING 1
#define CONFIG_PATA_HPT3X3_MODULE 1
#define CONFIG_USB_GSPCA_XIRLINK_CIT_MODULE 1
#define CONFIG_RTC_DRV_STK17TA8_MODULE 1
#define CONFIG_USB_GSPCA_SN9C20X_MODULE 1
#define CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST 1
#define CONFIG_KARMA_PARTITION 1
#define CONFIG_SND_SOC_I2C_AND_SPI_MODULE 1
#define CONFIG_NETPOLL 1
#define CONFIG_ZSWAP 1
#define CONFIG_SENSORS_F71882FG_MODULE 1
#define CONFIG_ACPI_APEI_GHES 1
#define CONFIG_AIO 1
#define CONFIG_SERIO_ARC_PS2_MODULE 1
#define CONFIG_SECURITY_SECURELEVEL 1
#define CONFIG_DVB_TDA8083_MODULE 1
#define CONFIG_NET_MPLS_GSO_MODULE 1
#define CONFIG_CLKEVT_I8253 1
#define CONFIG_RING_BUFFER_BENCHMARK_MODULE 1
#define CONFIG_DVB_USB_AZ6007_MODULE 1
#define CONFIG_NET_EMATCH 1
#define CONFIG_PERF_EVENTS 1
#define CONFIG_MMC_REALTEK_USB_MODULE 1
#define CONFIG_GENERIC_TIME_VSYSCALL 1
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#define CONFIG_NET_SCH_CHOKE_MODULE 1
#define CONFIG_LEDS_CLASS 1
#define CONFIG_GENERIC_HARDIRQS 1
#define CONFIG_DVB_USB_DIGITV_MODULE 1
#define CONFIG_IP6_NF_MATCH_HL_MODULE 1
#define CONFIG_IP_VS_TAB_BITS 12
#define CONFIG_IP6_NF_MATCH_OPTS_MODULE 1
#define CONFIG_SCSI_SAS_HOST_SMP 1
#define CONFIG_RTC_INTF_DEV 1
#define CONFIG_MTD_MAP_BANK_WIDTH_4 1
#define CONFIG_DCACHE_WORD_ACCESS 1
#define CONFIG_DVB_USB_CE6230_MODULE 1
#define CONFIG_DEFAULT_DEADLINE 1
#define CONFIG_INFINIBAND_CXGB3_MODULE 1
#define CONFIG_USB_SERIAL_SYMBOL_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_OSF_MODULE 1
#define CONFIG_SATA_QSTOR_MODULE 1
#define CONFIG_PATA_SIS_MODULE 1
#define CONFIG_AMD_NB 1
#define CONFIG_SND_VIRMIDI_MODULE 1
#define CONFIG_LOCKUP_DETECTOR 1
#define CONFIG_QSEMI_PHY_MODULE 1
#define CONFIG_IP_VS_PROTO_UDP 1
#define CONFIG_NLS_DEFAULT "utf8"
#define CONFIG_ACPI_CONTAINER 1
#define CONFIG_SND_DMA_SGBUF 1
#define CONFIG_UTS_NS 1
#define CONFIG_NF_CT_PROTO_GRE_MODULE 1
#define CONFIG_BT_HCIUART_BCSP 1
#define CONFIG_NF_CT_NETLINK_MODULE 1
#define CONFIG_AUXDISPLAY 1
#define CONFIG_NET_EMATCH_TEXT_MODULE 1
#define CONFIG_DMA_ENGINE 1
#define CONFIG_SND_HDA_CODEC_ANALOG_MODULE 1
#define CONFIG_X86_ACPI_CPUFREQ_MODULE 1
#define CONFIG_HID_WIIMOTE_MODULE 1
#define CONFIG_DEFAULT_SECURITY_SELINUX 1
#define CONFIG_CGROUP_PIDS 1
#define CONFIG_CRYPTO_AEAD2 1
#define CONFIG_DEBUG_INFO 1
#define CONFIG_CRYPTO_FCRYPT_MODULE 1
#define CONFIG_NF_NAT_MASQUERADE_IPV6_MODULE 1
#define CONFIG_TOSHIBA_BT_RFKILL_MODULE 1
#define CONFIG_MOUSE_PS2 1
#define CONFIG_NET_IPIP_MODULE 1
#define CONFIG_IP_VS_SH_TAB_BITS 8
#define CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC_VALUE 0
#define CONFIG_USB_SERIAL_IPAQ_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HL_MODULE 1
#define CONFIG_CHROMEOS_LAPTOP_MODULE 1
#define CONFIG_SND_USB_POD_MODULE 1
#define CONFIG_CRYPTO_ALGAPI2 1
#define CONFIG_EVM_HMAC_VERSION 2
#define CONFIG_SATA_SIS_MODULE 1
#define CONFIG_PHYSICAL_START 0x1000000
#define CONFIG_NETFILTER_XT_TARGET_LED_MODULE 1
#define CONFIG_ACPI_SBS_MODULE 1
#define CONFIG_HAVE_MEMBLOCK 1
#define CONFIG_X86_PMEM_LEGACY_MODULE 1
#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS 1
#define CONFIG_INPUT 1
#define CONFIG_PPPOATM_MODULE 1
#define CONFIG_PROC_SYSCTL 1
#define CONFIG_SND_HDA_CODEC_REALTEK_MODULE 1
#define CONFIG_HAVE_PERF_EVENTS_NMI 1
#define CONFIG_NETFILTER_XT_TARGET_CT_MODULE 1
#define CONFIG_MMU 1
#define CONFIG_DVB_CX24123_MODULE 1
#define CONFIG_USB_KAWETH_MODULE 1
#define CONFIG_USB_SIERRA_NET_MODULE 1
#define CONFIG_VMWARE_BALLOON_MODULE 1
#define CONFIG_HISAX_GAZEL 1
#define CONFIG_BRIDGE_EBT_NFLOG_MODULE 1
#define CONFIG_CAN_SJA1000_PLATFORM_MODULE 1
#define CONFIG_TABLET_USB_AIPTEK_MODULE 1
#define CONFIG_BNXT_SRIOV 1
#define CONFIG_VGACON_SOFT_SCROLLBACK 1
#define CONFIG_AGP 1
#define CONFIG_INLINE_WRITE_UNLOCK 1
#define CONFIG_ZPOOL 1
#define CONFIG_SENSORS_GL520SM_MODULE 1
#define CONFIG_E1000_MODULE 1
